@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -15,11 +14,9 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
 
 package org.apache.poi.contrib.poibrowser;
 
-import java.io.IOException;
 import java.util.HashMap;
 import java.util.Map;
 
@@ -36,7 +33,7 @@ import org.apache.poi.poifs.filesystem.POIFSDocumentPath;
  * <p>Organizes document information in a tree model in order to be
  * e.g. displayed in a Swing {@link javax.swing.JTree}. An instance of this
  * class is created with a root tree node ({@link MutableTreeNode}) and
- * registered as a {@link POIFSReaderListener} with a {@link 
+ * registered as a {@link POIFSReaderListener} with a {@link
  * org.apache.poi.poifs.eventfilesystem.POIFSReader}. While the latter processes
  * a POI filesystem it calls this class' {@link #processPOIFSReaderEvent} for
  * each document it has been registered for. This method appends the document it
@@ -59,8 +56,6 @@ import org.apache.poi.poifs.filesystem.POIFSDocumentPath;
  *
  * @author Rainer Klute <a
  * href="mailto:klute@rainer-klute.de">&lt;klute@rainer-klute.de&gt;</a>
- * @version $Id: TreeReaderListener.java 489730 2006-12-22 19:18:16Z bayard $
- * @since 2002-01-24
  */
 public class TreeReaderListener implements POIFSReaderListener
 {
@@ -160,17 +155,7 @@ public class TreeReaderListener implements POIFSReaderListener
             throw new RuntimeException(t.getMessage());
         }
 
-        try
-        {
-            is.close();
-        }
-        catch (IOException ex)
-        {
-            System.err.println
-                ("Unexpected exception while closing " +
-                event.getName() + " in " + event.getPath().toString());
-            ex.printStackTrace(System.err);
-        }
+        is.close();
 
         final MutableTreeNode parentNode = getNode(d.path, filename, rootNode);
         final MutableTreeNode nameNode = new DefaultMutableTreeNode(d.name);
@@ -219,20 +204,16 @@ public class TreeReaderListener implements POIFSReaderListener
             }
             return n;
         }
-        else
-        {
-            /* The path is somewhere down in the POI filesystem's
-             * hierarchy. We need the tree node of this path's parent
-             * and attach our new node to it. */
-            final String name = path.getComponent(path.length() - 1);
-            final POIFSDocumentPath parentPath = path.getParent();
-            final MutableTreeNode parentNode =
-                getNode(parentPath, fsName, root);
-            n = new DefaultMutableTreeNode(name);
-            pathToNode.put(path, n);
-            parentNode.insert(n, 0);
-            return n;
-        }
+        /* else - The path is somewhere down in the POI filesystem's
+         * hierarchy. We need the tree node of this path's parent
+         * and attach our new node to it. */
+        final String name = path.getComponent(path.length() - 1);
+        final POIFSDocumentPath parentPath = path.getParent();
+        final MutableTreeNode parentNode =
+            getNode(parentPath, fsName, root);
+        n = new DefaultMutableTreeNode(name);
+        pathToNode.put(path, n);
+        parentNode.insert(n, 0);
+        return n;
     }
-
 }
