@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -15,7 +14,7 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
+
 package org.apache.poi.ddf;
 
 import org.apache.poi.util.LittleEndian;
@@ -27,13 +26,11 @@ import org.apache.poi.util.HexDump;
  *
  * @author Glen Stampoultzis (glens at superlinksoftware.com)
  */
-public class EscherArrayProperty
-        extends EscherComplexProperty
-{
-	/**
-	 * The size of the header that goes at the
-	 *  start of the array, before the data
-	 */
+public final class EscherArrayProperty extends EscherComplexProperty {
+    /**
+     * The size of the header that goes at the
+     *  start of the array, before the data
+     */
     private static final int FIXED_SIZE = 3 * 2;
     /**
      * Normally, the size recorded in the simple data (for the complex
@@ -47,112 +44,95 @@ public class EscherArrayProperty
      */
     private boolean emptyComplexPart = false;
 
-    public EscherArrayProperty( short id, byte[] complexData )
-    {
-        super( id, checkComplexData(complexData) );
+    public EscherArrayProperty(short id, byte[] complexData) {
+        super(id, checkComplexData(complexData));
         emptyComplexPart = complexData.length == 0;
     }
 
-    public EscherArrayProperty( short propertyNumber, boolean isBlipId, byte[] complexData )
-    {
-        super( propertyNumber, isBlipId, checkComplexData(complexData) );
+    public EscherArrayProperty(short propertyNumber, boolean isBlipId, byte[] complexData) {
+        super(propertyNumber, isBlipId, checkComplexData(complexData));
     }
 
-    private static byte[] checkComplexData( byte[] complexData )
-    {
-        if (complexData == null || complexData.length == 0)
-            complexData = new byte[6];
+    private static byte[] checkComplexData(byte[] complexData) {
+        if (complexData == null || complexData.length == 0) {
+            return new byte[6];
+        }
 
         return complexData;
     }
 
-    public int getNumberOfElementsInArray()
-    {
-        return LittleEndian.getUShort( complexData, 0 );
+    public int getNumberOfElementsInArray() {
+        return LittleEndian.getUShort(_complexData, 0);
     }
 
-    public void setNumberOfElementsInArray( int numberOfElements )
-    {
+    public void setNumberOfElementsInArray(int numberOfElements) {
         int expectedArraySize = numberOfElements * getActualSizeOfElements(getSizeOfElements()) + FIXED_SIZE;
-        if ( expectedArraySize != complexData.length )
-        {
+        if (expectedArraySize != _complexData.length) {
             byte[] newArray = new byte[expectedArraySize];
-            System.arraycopy( complexData, 0, newArray, 0, complexData.length );
-            complexData = newArray;
+            System.arraycopy(_complexData, 0, newArray, 0, _complexData.length);
+            _complexData = newArray;
         }
-        LittleEndian.putShort( complexData, 0, (short) numberOfElements );
+        LittleEndian.putShort(_complexData, 0, (short) numberOfElements);
     }
 
-    public int getNumberOfElementsInMemory()
-    {
-        return LittleEndian.getUShort( complexData, 2 );
+    public int getNumberOfElementsInMemory() {
+        return LittleEndian.getUShort(_complexData, 2);
     }
 
-    public void setNumberOfElementsInMemory( int numberOfElements )
-    {
+    public void setNumberOfElementsInMemory(int numberOfElements) {
         int expectedArraySize = numberOfElements * getActualSizeOfElements(getSizeOfElements()) + FIXED_SIZE;
-        if ( expectedArraySize != complexData.length )
-        {
+        if (expectedArraySize != _complexData.length) {
             byte[] newArray = new byte[expectedArraySize];
-            System.arraycopy( complexData, 0, newArray, 0, expectedArraySize );
-            complexData = newArray;
+            System.arraycopy(_complexData, 0, newArray, 0, expectedArraySize);
+            _complexData = newArray;
         }
-        LittleEndian.putShort( complexData, 2, (short) numberOfElements );
+        LittleEndian.putShort(_complexData, 2, (short) numberOfElements);
     }
 
-    public short getSizeOfElements()
-    {
-        return LittleEndian.getShort( complexData, 4 );
+    public short getSizeOfElements() {
+        return LittleEndian.getShort( _complexData, 4 );
     }
 
-    public void setSizeOfElements( int sizeOfElements )
-    {
-        LittleEndian.putShort( complexData, 4, (short) sizeOfElements );
+    public void setSizeOfElements(int sizeOfElements) {
+        LittleEndian.putShort( _complexData, 4, (short) sizeOfElements );
 
         int expectedArraySize = getNumberOfElementsInArray() * getActualSizeOfElements(getSizeOfElements()) + FIXED_SIZE;
-        if ( expectedArraySize != complexData.length )
-        {
+        if (expectedArraySize != _complexData.length) {
             // Keep just the first 6 bytes.  The rest is no good to us anyway.
             byte[] newArray = new byte[expectedArraySize];
-            System.arraycopy( complexData, 0, newArray, 0, 6 );
-            complexData = newArray;
+            System.arraycopy( _complexData, 0, newArray, 0, 6 );
+            _complexData = newArray;
         }
     }
 
-    public byte[] getElement( int index )
-    {
+    public byte[] getElement(int index) {
         int actualSize = getActualSizeOfElements(getSizeOfElements());
         byte[] result = new byte[actualSize];
-        System.arraycopy(complexData, FIXED_SIZE + index * actualSize, result, 0, result.length );
+        System.arraycopy(_complexData, FIXED_SIZE + index * actualSize, result, 0, result.length );
         return result;
     }
 
-    public void setElement( int index, byte[] element )
-    {
+    public void setElement(int index, byte[] element) {
         int actualSize = getActualSizeOfElements(getSizeOfElements());
-        System.arraycopy( element, 0, complexData, FIXED_SIZE + index * actualSize, actualSize);
+        System.arraycopy( element, 0, _complexData, FIXED_SIZE + index * actualSize, actualSize);
     }
 
-    public String toString()
-    {
-        String nl = System.getProperty("line.separator");
-
+    public String toString() {
         StringBuffer results = new StringBuffer();
-        results.append("    {EscherArrayProperty:" + nl);
-        results.append("     Num Elements: " + getNumberOfElementsInArray() + nl);
-        results.append("     Num Elements In Memory: " + getNumberOfElementsInMemory() + nl);
-        results.append("     Size of elements: " + getSizeOfElements() + nl);
-        for (int i = 0; i < getNumberOfElementsInArray(); i++)
-        {
-            results.append("     Element " + i + ": " + HexDump.toHex(getElement(i)) + nl);
+        results.append("    {EscherArrayProperty:" + '\n');
+        results.append("     Num Elements: " + getNumberOfElementsInArray() + '\n');
+        results.append("     Num Elements In Memory: " + getNumberOfElementsInMemory() + '\n');
+        results.append("     Size of elements: " + getSizeOfElements() + '\n');
+        for (int i = 0; i < getNumberOfElementsInArray(); i++) {
+            results.append("     Element " + i + ": " + HexDump.toHex(getElement(i)) + '\n');
         }
-        results.append("}" + nl);
+        results.append("}" + '\n');
 
         return "propNum: " + getPropertyNumber()
                 + ", propName: " + EscherProperties.getPropertyName( getPropertyNumber() )
                 + ", complex: " + isComplex()
                 + ", blipId: " + isBlipId()
-                + ", data: " + nl + results.toString();
+                + ", data: " + '\n' + results.toString();
     }
 
     /**
@@ -165,38 +145,36 @@ public class EscherArrayProperty
      * @param offset    The offset into the array to start reading from.
      * @return  the number of bytes used by this complex property.
      */
-    public int setArrayData( byte[] data, int offset )
-    {
+    public int setArrayData(byte[] data, int offset) {
         if (emptyComplexPart){
-            complexData = new byte[0];
+            _complexData = new byte[0];
         } else {
             short numElements = LittleEndian.getShort(data, offset);
-            short numReserved = LittleEndian.getShort(data, offset + 2);
+            LittleEndian.getShort(data, offset + 2); // numReserved
             short sizeOfElements = LittleEndian.getShort(data, offset + 4);
 
             int arraySize = getActualSizeOfElements(sizeOfElements) * numElements;
-            if (arraySize == complexData.length) {
+            if (arraySize == _complexData.length) {
                 // The stored data size in the simple block excludes the header size
-                complexData = new byte[arraySize + 6];
+                _complexData = new byte[arraySize + 6];
                 sizeIncludesHeaderSize = false;
             }
-            System.arraycopy(data, offset, complexData, 0, complexData.length );
+            System.arraycopy(data, offset, _complexData, 0, _complexData.length );
         }
-        return complexData.length;
+        return _complexData.length;
     }
 
     /**
      * Serializes the simple part of this property.  ie the first 6 bytes.
-     * 
-     * Needs special code to handle the case when the size doesn't 
+     *
+     * Needs special code to handle the case when the size doesn't
      *  include the size of the header block
      */
-    public int serializeSimplePart( byte[] data, int pos )
-    {
+    public int serializeSimplePart(byte[] data, int pos) {
         LittleEndian.putShort(data, pos, getId());
-        int recordSize = complexData.length;
+        int recordSize = _complexData.length;
         if(!sizeIncludesHeaderSize) {
-        	recordSize -= 6;
+            recordSize -= 6;
         }
         LittleEndian.putInt(data, pos + 2, recordSize);
         return 6;
@@ -206,12 +184,10 @@ public class EscherArrayProperty
      * Sometimes the element size is stored as a negative number.  We
      * negate it and shift it to get the real value.
      */
-    public static int getActualSizeOfElements(short sizeOfElements)
-    {
-        if (sizeOfElements < 0)
+    public static int getActualSizeOfElements(short sizeOfElements) {
+        if (sizeOfElements < 0) {
             return (short) ( ( -sizeOfElements ) >> 2 );
-        else
-            return sizeOfElements;
+        }
+        return sizeOfElements;
     }
-
 }
