@@ -14,7 +14,7 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
+
 package org.apache.poi.hpsf;
 
 import java.util.Iterator;
@@ -32,8 +32,6 @@ import org.apache.poi.hpsf.wellknown.SectionIDMap;
  * @author Drew Varner (Drew.Varner closeTo sc.edu)
  * @author robert_flaherty@hyperion.com
  * @see SummaryInformation
- * @version $Id: DocumentSummaryInformation.java 489730 2006-12-22 19:18:16Z bayard $
- * @since 2002-02-09
  */
 public class DocumentSummaryInformation extends SpecialPropertySet
 {
@@ -45,6 +43,9 @@ public class DocumentSummaryInformation extends SpecialPropertySet
     public static final String DEFAULT_STREAM_NAME =
         "\005DocumentSummaryInformation";
 
+    public PropertyIDMap getPropertySetIDMap() {
+    	return PropertyIDMap.getDocumentSummaryInformationProperties();
+    }
 
 
     /**
@@ -566,9 +567,8 @@ public class DocumentSummaryInformation extends SpecialPropertySet
 
     /**
      * <p>Gets the custom properties.</p>
-     * 
+     *
      * @return The custom properties.
-     * @since 2006-02-09
      */
     public CustomProperties getCustomProperties()
     {
@@ -588,7 +588,7 @@ public class DocumentSummaryInformation extends SpecialPropertySet
                 {
                     propertyCount++;
                     final CustomProperty cp = new CustomProperty(p,
-                            (String) dictionary.get(new Long(id)));
+                            (String) dictionary.get(Long.valueOf(id)));
                     cps.put(cp.getName(), cp);
                 }
             }
@@ -600,9 +600,8 @@ public class DocumentSummaryInformation extends SpecialPropertySet
 
     /**
      * <p>Sets the custom properties.</p>
-     * 
+     *
      * @param customProperties The custom properties
-     * @since 2006-02-07
      */
     public void setCustomProperties(final CustomProperties customProperties)
     {
@@ -649,8 +648,6 @@ public class DocumentSummaryInformation extends SpecialPropertySet
 
     /**
      * <p>Removes the custom properties.</p>
-     * 
-     * @since 2006-02-08
      */
     public void removeCustomProperties()
     {
@@ -673,5 +670,4 @@ public class DocumentSummaryInformation extends SpecialPropertySet
     {
         throw new UnsupportedOperationException(msg + " is not yet implemented.");
     }
-
 }
