@@ -14,7 +14,7 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
+
 package org.apache.poi.hpsf;
 
 import java.io.IOException;
@@ -57,8 +57,6 @@ import org.apache.poi.util.LittleEndian;
  * @author Rainer Klute <a
  * href="mailto:klute@rainer-klute.de">&lt;klute@rainer-klute.de&gt;</a>
  * @author Drew Varner (Drew.Varner hanginIn sc.edu)
- * @version $Id: PropertySet.java 489730 2006-12-22 19:18:16Z bayard $
- * @since 2002-02-09
  */
 public class PropertySet
 {
@@ -387,7 +385,7 @@ public class PropertySet
         o += ClassID.LENGTH;
         final long sectionCount = LittleEndian.getUInt(src, o);
         o += LittleEndian.INT_SIZE;
-        if (sectionCount < 1)
+        if (sectionCount < 0)
             return false;
         return true;
     }
@@ -426,9 +424,9 @@ public class PropertySet
         o += ClassID.LENGTH;
         final int sectionCount = LittleEndian.getInt(src, o);
         o += LittleEndian.INT_SIZE;
-        if (sectionCount <= 0)
+        if (sectionCount < 0)
             throw new HPSFRuntimeException("Section count " + sectionCount +
-                                           " must be greater than 0.");
+                                           " is negative.");
 
         /*
          * Read the sections, which are following the header. They
@@ -468,6 +466,8 @@ public class PropertySet
      */
     public boolean isSummaryInformation()
     {
+        if (sections.size() <= 0)
+            return false;
         return Util.equal(((Section) sections.get(0)).getFormatID().getBytes(),
                           SectionIDMap.SUMMARY_INFORMATION_ID);
     }
@@ -483,6 +483,8 @@ public class PropertySet
      */
     public boolean isDocumentSummaryInformation()
     {
+        if (sections.size() <= 0)
+            return false;
         return Util.equal(((Section) sections.get(0)).getFormatID().getBytes(),
                           SectionIDMap.DOCUMENT_SUMMARY_INFORMATION_ID[0]);
     }
