@@ -14,7 +14,7 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
+
 package org.apache.poi.hpsf;
 
 import java.io.IOException;
@@ -22,6 +22,7 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.List;
 
+import org.apache.poi.hpsf.wellknown.PropertyIDMap;
 import org.apache.poi.poifs.filesystem.DirectoryEntry;
 
 /**
@@ -52,11 +53,14 @@ import org.apache.poi.poifs.filesystem.DirectoryEntry;
  *
  * @author Rainer Klute <a
  * href="mailto:klute@rainer-klute.de">&lt;klute@rainer-klute.de&gt;</a>
- * @version $Id: SpecialPropertySet.java 489730 2006-12-22 19:18:16Z bayard $
- * @since 2002-02-09
  */
 public abstract class SpecialPropertySet extends MutablePropertySet
 {
+	/**
+	 * The id to name mapping of the properties
+	 *  in this set.
+	 */
+	public abstract PropertyIDMap getPropertySetIDMap();
 
     /**
      * <p>The "real" property set <code>SpecialPropertySet</code>
