@@ -15,24 +15,21 @@
    limitations under the License.
 ==================================================================== */
 
-
-/*
- * FormulaViewer.java - finds formulas in a BIFF8 file and attempts to parse them and
- * display info about them.
- *
- * Created on November 18, 2001, 7:58 AM
- */
 package org.apache.poi.hssf.dev;
 
 import java.io.FileInputStream;
-
-//import java.io.*;
 import java.util.List;
 
+import org.apache.poi.hssf.model.HSSFFormulaParser;
+import org.apache.poi.hssf.record.FormulaRecord;
+import org.apache.poi.hssf.record.Record;
+import org.apache.poi.hssf.record.RecordFactory;
+import org.apache.poi.hssf.record.formula.ExpPtg;
+import org.apache.poi.hssf.record.formula.FuncPtg;
+import org.apache.poi.hssf.record.formula.OperationPtg;
+import org.apache.poi.hssf.record.formula.Ptg;
+import org.apache.poi.hssf.usermodel.HSSFWorkbook;
 import org.apache.poi.poifs.filesystem.POIFSFileSystem;
-import org.apache.poi.hssf.record.*;
-import org.apache.poi.hssf.record.formula.*;
-import org.apache.poi.hssf.model.*;
 
 /**
  * FormulaViewer - finds formulas in a BIFF8 file and attempts to read them/display
@@ -86,20 +83,21 @@ public class FormulaViewer
     
     private void listFormula(FormulaRecord record) {
         String sep="~";
-        List tokens= record.getParsedExpression();
-        int numptgs = record.getNumberOfExpressionTokens();
-        Ptg token = null;
-        String name,numArg;
-        if (tokens != null) {
-            token = (Ptg) tokens.get(numptgs-1);
+        Ptg[] tokens= record.getParsedExpression();
+        Ptg token;
+        int numptgs = tokens.length;
+        String numArg;
+            token = tokens[numptgs-1];
             if (token instanceof FuncPtg) {
                 numArg = String.valueOf(numptgs-1);
-            } else { numArg = String.valueOf(-1);}
+            } else { 
+            	numArg = String.valueOf(-1);
+            }
             
             StringBuffer buf = new StringBuffer();
             
             if (token instanceof ExpPtg) return;
-            buf.append(name=((OperationPtg) token).toFormulaString((Workbook)null));
+            buf.append(((OperationPtg) token).toFormulaString());
             buf.append(sep);
             switch (token.getPtgClass()) {
                 case Ptg.CLASS_REF :
@@ -115,7 +113,7 @@ public class FormulaViewer
             
             buf.append(sep);
             if (numptgs>1) {
-                token = (Ptg) tokens.get(numptgs-2);
+                token = tokens[numptgs-2];
                 switch (token.getPtgClass()) {
                     case Ptg.CLASS_REF :
                         buf.append("REF");
@@ -133,9 +131,6 @@ public class FormulaViewer
             buf.append(sep);
             buf.append(numArg);
             System.out.println(buf.toString());
-        } else  {
-            System.out.println("#NAME");
-        }
     }
 
     /**
@@ -154,21 +149,19 @@ public class FormulaViewer
         System.out.println("value = " + record.getValue());
         System.out.print("xf = " + record.getXFIndex());
         System.out.print(", number of ptgs = "
-                           + record.getNumberOfExpressionTokens());
+                           + record.getParsedExpression().length);
         System.out.println(", options = " + record.getOptions());
         System.out.println("RPN List = "+formulaString(record));
         System.out.println("Formula text = "+ composeFormula(record));
     }
 
     private String formulaString(FormulaRecord record) {
-        StringBuffer formula = new StringBuffer("=");
-        int          numptgs = record.getNumberOfExpressionTokens();
-        List         tokens    = record.getParsedExpression();
-        Ptg token;
+
         StringBuffer buf = new StringBuffer();
-           for (int i=0;i<numptgs;i++) {
-           token = (Ptg) tokens.get(i);
-            buf.append( token.toFormulaString((Workbook)null));
+		Ptg[] tokens = record.getParsedExpression();
+		for (int i = 0; i < tokens.length; i++) {
+			Ptg token = tokens[i];
+            buf.append( token.toFormulaString());
             switch (token.getPtgClass()) {
                 case Ptg.CLASS_REF :
                     buf.append("(R)");
@@ -186,9 +179,9 @@ public class FormulaViewer
     }
     
     
-    private String composeFormula(FormulaRecord record)
+    private static String composeFormula(FormulaRecord record)
     {
-       return  org.apache.poi.hssf.model.FormulaParser.toFormulaString((Workbook)null,record.getParsedExpression());
+       return  HSSFFormulaParser.toFormulaString((HSSFWorkbook)null, record.getParsedExpression());
     }
 
     /**
