@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -15,17 +14,13 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
 
-/*
- * LabelRecord.java
- *
- * Created on November 11, 2001, 12:51 PM
- */
 package org.apache.poi.hssf.record;
 
+import org.apache.poi.util.HexDump;
+
 /**
- * Label Record - read only support for strings stored directly in the cell..  Don't
+ * Label Record (0x0204) - read only support for strings stored directly in the cell..  Don't
  * use this (except to read), use LabelSST instead <P>
  * REFERENCE:  PG 325 Microsoft Excel 97 Developer's Kit (ISBN: 1-57231-498-2)<P>
  * @author Andrew C. Oliver (acoliver at apache dot org)
@@ -33,14 +28,10 @@ package org.apache.poi.hssf.record;
  * @version 2.0-pre
  * @see org.apache.poi.hssf.record.LabelSSTRecord
  */
+public final class LabelRecord extends Record implements CellValueRecordInterface {
+    public final static short sid = 0x0204;
 
-public class LabelRecord
-    extends Record
-    implements CellValueRecordInterface
-{
-    public final static short sid = 0x204;
-    //private short             field_1_row;
-    private int             field_1_row;
+    private int               field_1_row;
     private short             field_2_column;
     private short             field_3_xf_index;
     private short             field_4_string_len;
@@ -48,72 +39,34 @@ public class LabelRecord
     private String            field_6_value;
 
     /** Creates new LabelRecord */
-
     public LabelRecord()
     {
     }
 
     /**
-     * Constructs an Label record and sets its fields appropriately.
-     *
      * @param in the RecordInputstream to read the record from
      */
-
     public LabelRecord(RecordInputStream in)
     {
-        super(in);
-    }
-
-    /**
-     * called by constructor, should throw runtime exception in the event of a
-     * record passed with a differing ID.
-     *
-     * @param id alleged id for this record
-     */
-
-    protected void validateSid(short id)
-    {
-        if (id != sid)
-        {
-            throw new RecordFormatException("Not a valid LabelRecord");
-        }
-    }
-
-    /**
-     * @param in the RecordInputstream to read the record from
-     */
-
-    protected void fillFields(RecordInputStream in)
-    {
-        //field_1_row          = LittleEndian.getShort(data, 0 + offset);
         field_1_row          = in.readUShort();
         field_2_column       = in.readShort();
         field_3_xf_index     = in.readShort();
         field_4_string_len   = in.readShort();
         field_5_unicode_flag = in.readByte();
         if (field_4_string_len > 0) {
-          if (isUnCompressedUnicode()) {
-            field_6_value = in.readUnicodeLEString(field_4_string_len);
-          } else {
-            field_6_value = in.readCompressedUnicode(field_4_string_len);
+            if (isUnCompressedUnicode()) {
+                field_6_value = in.readUnicodeLEString(field_4_string_len);
+            } else {
+                field_6_value = in.readCompressedUnicode(field_4_string_len);
+            }
+        } else {
+            field_6_value = "";
         }
-        } else field_6_value = null;
     }
 
-/* READ ONLY ACCESS... THIS IS FOR COMPATIBILITY ONLY...USE LABELSST!
-      public void setRow(short row) {
-        field_1_row = row;
-      }
-
-      public void setColumn(short col) {
-        field_2_column = col;
-      }
-
-      public void setXFIndex(short index) {
-        field_3_xf_index = index;
-      }
-  */
-    //public short getRow()
+/*
+ * READ ONLY ACCESS... THIS IS FOR COMPATIBILITY ONLY...USE LABELSST! public
+ */
     public int getRow()
     {
         return field_1_row;
@@ -133,7 +86,6 @@ public class LabelRecord
      * get the number of characters this string contains
      * @return number of characters
      */
-
     public short getStringLength()
     {
         return field_4_string_len;
@@ -143,7 +95,6 @@ public class LabelRecord
      * is this uncompressed unicode (16bit)?  Or just 8-bit compressed?
      * @return isUnicode - True for 16bit- false for 8bit
      */
-
     public boolean isUnCompressedUnicode()
     {
         return (field_5_unicode_flag == 1);
@@ -155,7 +106,6 @@ public class LabelRecord
      * @return the text string
      * @see #getStringLength()
      */
-
     public String getValue()
     {
         return field_6_value;
@@ -164,11 +114,11 @@ public class LabelRecord
     /**
      * THROWS A RUNTIME EXCEPTION..  USE LABELSSTRecords.  YOU HAVE NO REASON to use LABELRecord!!
      */
-
-    public int serialize(int offset, byte [] data)
-    {
-        throw new RecordFormatException(
-            "Label Records are supported READ ONLY...convert to LabelSST");
+    public int serialize(int offset, byte [] data) {
+        throw new RecordFormatException("Label Records are supported READ ONLY...convert to LabelSST");
+    }
+    public int getRecordSize() {
+        throw new RecordFormatException("Label Records are supported READ ONLY...convert to LabelSST");
     }
 
     public short getSid()
@@ -178,83 +128,21 @@ public class LabelRecord
 
     public String toString()
     {
-        StringBuffer buffer = new StringBuffer();
-        buffer.append("[LABEL]\n");
-        buffer.append("    .row            = ")
-            .append(Integer.toHexString(getRow())).append("\n");
-        buffer.append("    .column         = ")
-            .append(Integer.toHexString(getColumn())).append("\n");
-        buffer.append("    .xfindex        = ")
-            .append(Integer.toHexString(getXFIndex())).append("\n");
-        buffer.append("    .string_len       = ")
-            .append(Integer.toHexString(field_4_string_len)).append("\n");
-        buffer.append("    .unicode_flag       = ")
-            .append(Integer.toHexString(field_5_unicode_flag)).append("\n");
-        buffer.append("    .value       = ")
-            .append(getValue()).append("\n");
-        buffer.append("[/LABEL]\n");
-        return buffer.toString();
-    }
-
-
-    public boolean isBefore(CellValueRecordInterface i)
-    {
-        if (this.getRow() > i.getRow())
-        {
-            return false;
-        }
-        if ((this.getRow() == i.getRow())
-                && (this.getColumn() > i.getColumn()))
-        {
-            return false;
-        }
-        if ((this.getRow() == i.getRow())
-                && (this.getColumn() == i.getColumn()))
-        {
-            return false;
-        }
-        return true;
-    }
-
-    public boolean isAfter(CellValueRecordInterface i)
-    {
-        if (this.getRow() < i.getRow())
-        {
-            return false;
-        }
-        if ((this.getRow() == i.getRow())
-                && (this.getColumn() < i.getColumn()))
-        {
-            return false;
-        }
-        if ((this.getRow() == i.getRow())
-                && (this.getColumn() == i.getColumn()))
-        {
-            return false;
-        }
-        return true;
-    }
-
-    public boolean isEqual(CellValueRecordInterface i)
-    {
-        return ((this.getRow() == i.getRow())
-                && (this.getColumn() == i.getColumn()));
-    }
-
-    public boolean isInValueSection()
-    {
-        return true;
-    }
-
-    public boolean isValue()
-    {
-        return true;
+        StringBuffer sb = new StringBuffer();
+		sb.append("[LABEL]\n");
+		sb.append("    .row       = ").append(HexDump.shortToHex(getRow())).append("\n");
+		sb.append("    .column    = ").append(HexDump.shortToHex(getColumn())).append("\n");
+		sb.append("    .xfindex   = ").append(HexDump.shortToHex(getXFIndex())).append("\n");
+		sb.append("    .string_len= ").append(HexDump.shortToHex(field_4_string_len)).append("\n");
+		sb.append("    .unicode_flag= ").append(HexDump.byteToHex(field_5_unicode_flag)).append("\n");
+		sb.append("    .value       = ").append(getValue()).append("\n");
+		sb.append("[/LABEL]\n");
+        return sb.toString();
     }
 
     /**
-     * NO-OP!
-     */
-
+	 * NO-OP!
+	 */
     public void setColumn(short col)
     {
     }
@@ -262,8 +150,6 @@ public class LabelRecord
     /**
      * NO-OP!
      */
-
-    //public void setRow(short row)
     public void setRow(int row)
     {
     }
@@ -271,7 +157,6 @@ public class LabelRecord
     /**
      * no op!
      */
-
     public void setXFIndex(short xf)
     {
     }
