@@ -19,7 +19,7 @@
 
 package org.apache.poi.hssf.record;
 
-import org.apache.poi.util.LittleEndian;
+import org.apache.poi.util.LittleEndianOutput;
 
 /**
  * Title: MMS Record<P>
@@ -30,8 +30,8 @@ import org.apache.poi.util.LittleEndian;
  * @version 2.0-pre
  */
 
-public class MMSRecord
-    extends Record
+public final class MMSRecord
+    extends StandardRecord
 {
     public final static short sid = 0xC1;
     private byte              field_1_addMenuCount;   // = 0;
@@ -41,25 +41,7 @@ public class MMSRecord
     {
     }
 
-    /**
-     * Constructs a MMS record and sets its fields appropriately.
-     * @param in the RecordInputstream to read the record from
-     */
-
     public MMSRecord(RecordInputStream in)
-    {
-        super(in);
-    }
-
-    protected void validateSid(short id)
-    {
-        if (id != sid)
-        {
-            throw new RecordFormatException("NOT A MMS RECORD");
-        }
-    }
-
-    protected void fillFields(RecordInputStream in)
     {
         field_1_addMenuCount = in.readByte();
         field_2_delMenuCount = in.readByte();
@@ -118,19 +100,13 @@ public class MMSRecord
         return buffer.toString();
     }
 
-    public int serialize(int offset, byte [] data)
-    {
-        LittleEndian.putShort(data, 0 + offset, sid);
-        LittleEndian.putShort(data, 2 + offset,
-                              (( short ) 0x02));   // 2 bytes (6 total)
-        data[ 4 + offset ] = getAddMenuCount();
-        data[ 5 + offset ] = getDelMenuCount();
-        return getRecordSize();
+    public void serialize(LittleEndianOutput out) {
+        out.writeByte(getAddMenuCount());
+        out.writeByte(getDelMenuCount());
     }
 
-    public int getRecordSize()
-    {
-        return 6;
+    protected int getDataSize() {
+        return 2;
     }
 
     public short getSid()
