@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -15,27 +14,23 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
 
 package org.apache.poi.hssf.record;
 
-import org.apache.poi.util.LittleEndian;
+import org.apache.poi.util.LittleEndianOutput;
 import org.apache.poi.util.BitField;
 import org.apache.poi.util.BitFieldFactory;
 
 /**
- * Title:        Print Setup Record<P>
- * Description:  Stores print setup options -- bogus for HSSF (and marked as such)<P>
- * REFERENCE:  PG 385 Microsoft Excel 97 Developer's Kit (ISBN: 1-57231-498-2)<P>
+ * Title:        PAGESETUP (0x00A1)<p/>
+ * Description:  Stores print setup options -- bogus for HSSF (and marked as such)<p/>
+ * REFERENCE:  PG 385 Microsoft Excel 97 Developer's Kit (ISBN: 1-57231-498-2)<p/>
  * @author Andrew C. Oliver (acoliver at apache dot org)
  * @author Jason Height (jheight at chariot dot net dot au)
  * @version 2.0-pre
  */
-
-public class PrintSetupRecord
-    extends Record
-{
-    public final static short     sid = 0xa1;
+public final class PrintSetupRecord extends StandardRecord {
+    public final static short     sid = 0x00A1;
     private short                 field_1_paper_size;
     private short                 field_2_scale;
     private short                 field_3_page_start;
@@ -71,26 +66,7 @@ public class PrintSetupRecord
     {
     }
 
-    /**
-     * Constructs a PrintSetup (SETUP) record and sets its fields appropriately.
-     * @param in the RecordInputstream to read the record from
-     */
-
     public PrintSetupRecord(RecordInputStream in)
-    {
-        super(in);
-    }
-
-    protected void validateSid(short id)
-    {
-        if (id != sid)
-        {
-            throw new RecordFormatException(
-                "NOT A valid PrintSetup record RECORD");
-        }
-    }
-
-    protected void fillFields(RecordInputStream in)
     {
         field_1_paper_size    = in.readShort();
         field_2_scale         = in.readShort();
@@ -346,27 +322,22 @@ public class PrintSetupRecord
         return buffer.toString();
     }
 
-    public int serialize(int offset, byte [] data)
-    {
-        LittleEndian.putShort(data, 0 + offset, sid);
-        LittleEndian.putShort(data, 2 + offset, ( short ) 34);
-        LittleEndian.putShort(data, 4 + offset, getPaperSize());
-        LittleEndian.putShort(data, 6 + offset, getScale());
-        LittleEndian.putShort(data, 8 + offset, getPageStart());
-        LittleEndian.putShort(data, 10 + offset, getFitWidth());
-        LittleEndian.putShort(data, 12 + offset, getFitHeight());
-        LittleEndian.putShort(data, 14 + offset, getOptions());
-        LittleEndian.putShort(data, 16 + offset, getHResolution());
-        LittleEndian.putShort(data, 18 + offset, getVResolution());
-        LittleEndian.putDouble(data, 20 + offset, getHeaderMargin());
-        LittleEndian.putDouble(data, 28 + offset, getFooterMargin());
-        LittleEndian.putShort(data, 36 + offset, getCopies());
-        return getRecordSize();
+    public void serialize(LittleEndianOutput out) {
+        out.writeShort(getPaperSize());
+        out.writeShort(getScale());
+        out.writeShort(getPageStart());
+        out.writeShort(getFitWidth());
+        out.writeShort(getFitHeight());
+        out.writeShort(getOptions());
+        out.writeShort(getHResolution());
+        out.writeShort(getVResolution());
+        out.writeDouble(getHeaderMargin());
+        out.writeDouble(getFooterMargin());
+        out.writeShort(getCopies());
     }
 
-    public int getRecordSize()
-    {
-        return 38;
+    protected int getDataSize() {
+        return 34;
     }
 
     public short getSid()
