@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -15,18 +14,19 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
 
 package org.apache.poi.hssf.record;
 
+import java.util.Iterator;
+
+import org.apache.poi.hssf.record.cont.ContinuableRecord;
+import org.apache.poi.hssf.record.cont.ContinuableRecordOutput;
 import org.apache.poi.util.IntMapper;
 import org.apache.poi.util.LittleEndianConsts;
 
-import java.util.Iterator;
-
 /**
- * Title:        Static String Table Record
- * <P>
+ * Title:        Static String Table Record (0x00FC)<p/>
+ *
  * Description:  This holds all the strings for LabelSSTRecords.
  * <P>
  * REFERENCE:    PG 389 Microsoft Excel 97 Developer's Kit (ISBN:
@@ -39,31 +39,20 @@ import java.util.Iterator;
  * @see org.apache.poi.hssf.record.LabelSSTRecord
  * @see org.apache.poi.hssf.record.ContinueRecord
  */
+public final class SSTRecord extends ContinuableRecord {
+    public static final short sid = 0x00FC;
 
-public class SSTRecord
-        extends Record
-{
-
-      private static UnicodeString EMPTY_STRING = new UnicodeString("");
-
-    /** how big can an SST record be? As big as any record can be: 8228 bytes */
-    static final int MAX_RECORD_SIZE = 8228;
+    private static final UnicodeString EMPTY_STRING = new UnicodeString("");
 
+    // TODO - move these constants to test class (the only consumer)
     /** standard record overhead: two shorts (record id plus data space size)*/
-    static final int STD_RECORD_OVERHEAD =
-            2 * LittleEndianConsts.SHORT_SIZE;
+    static final int STD_RECORD_OVERHEAD = 2 * LittleEndianConsts.SHORT_SIZE;
 
     /** SST overhead: the standard record overhead, plus the number of strings and the number of unique strings -- two ints */
-    static final int SST_RECORD_OVERHEAD =
-            ( STD_RECORD_OVERHEAD + ( 2 * LittleEndianConsts.INT_SIZE ) );
+    static final int SST_RECORD_OVERHEAD = STD_RECORD_OVERHEAD + 2 * LittleEndianConsts.INT_SIZE;
 
     /** how much data can we stuff into an SST record? That would be _max minus the standard SST record overhead */
-    static final int MAX_DATA_SPACE = MAX_RECORD_SIZE - SST_RECORD_OVERHEAD;
-
-    /** overhead for each string includes the string's character count (a short) and the flag describing its characteristics (a byte) */
-    static final int STRING_MINIMAL_OVERHEAD = LittleEndianConsts.SHORT_SIZE + LittleEndianConsts.BYTE_SIZE;
-
-    public static final short sid = 0xfc;
+    static final int MAX_DATA_SPACE = RecordInputStream.MAX_RECORD_DATA_SIZE - 8;
 
     /** union of strings in the SST and EXTSST */
     private int field_1_num_strings;
@@ -79,9 +68,6 @@ public class SSTRecord
     /** Offsets relative the start of the current SST or continue record */
     int[] bucketRelativeOffsets;
 
-    /**
-     * default constructor
-     */
     public SSTRecord()
     {
         field_1_num_strings = 0;
@@ -90,17 +76,6 @@ public class SSTRecord
         deserializer = new SSTDeserializer(field_3_strings);
     }
 
-    /**
-     * Constructs an SST record and sets its fields appropriately.
-     *
-     * @param in the RecordInputstream to read the record from
-     */
-
-    public SSTRecord( RecordInputStream in )
-    {
-        super( in );
-    }
-
     /**
      * Add a string.
      *
@@ -108,8 +83,7 @@ public class SSTRecord
      *
      * @return the index of that string in the table
      */
-
-    public int addString( final UnicodeString string )
+    public int addString(UnicodeString string)
     {
         field_1_num_strings++;
         UnicodeString ucs = ( string == null ) ? EMPTY_STRING
@@ -117,12 +91,9 @@ public class SSTRecord
         int rval;
         int index = field_3_strings.getIndex(ucs);
 
-        if ( index != -1 )
-        {
+        if ( index != -1 ) {
             rval = index;
-        }
-        else
-        {
+        } else {
             // This is a new string -- we didn't see it among the
             // strings we've already collected
             rval = field_3_strings.size();
@@ -135,7 +106,6 @@ public class SSTRecord
     /**
      * @return number of strings
      */
-
     public int getNumStrings()
     {
         return field_1_num_strings;
@@ -144,43 +114,11 @@ public class SSTRecord
     /**
      * @return number of unique strings
      */
-
     public int getNumUniqueStrings()
     {
         return field_2_num_unique_strings;
     }
 
-    /**
-     * USE THIS METHOD AT YOUR OWN PERIL: THE <code>addString</code>
-     * METHODS MANIPULATE THE NUMBER OF STRINGS AS A SIDE EFFECT; YOUR
-     * ATTEMPTS AT MANIPULATING THE STRING COUNT IS LIKELY TO BE VERY
-     * WRONG AND WILL RESULT IN BAD BEHAVIOR WHEN THIS RECORD IS
-     * WRITTEN OUT AND ANOTHER PROCESS ATTEMPTS TO READ THE RECORD
-     *
-     * @param count  number of strings
-     *
-     */
-
-    public void setNumStrings( final int count )
-    {
-        field_1_num_strings = count;
-    }
-
-    /**
-     * USE THIS METHOD AT YOUR OWN PERIL: THE <code>addString</code>
-     * METHODS MANIPULATE THE NUMBER OF UNIQUE STRINGS AS A SIDE
-     * EFFECT; YOUR ATTEMPTS AT MANIPULATING THE UNIQUE STRING COUNT
-     * IS LIKELY TO BE VERY WRONG AND WILL RESULT IN BAD BEHAVIOR WHEN
-     * THIS RECORD IS WRITTEN OUT AND ANOTHER PROCESS ATTEMPTS TO READ
-     * THE RECORD
-     *
-     * @param count  number of strings
-     */
-
-    public void setNumUniqueStrings( final int count )
-    {
-        field_2_num_unique_strings = count;
-    }
 
     /**
      * Get a particular string by its index
@@ -189,26 +127,18 @@ public class SSTRecord
      *
      * @return the desired string
      */
-
-    public UnicodeString getString( final int id )
+    public UnicodeString getString(int id )
     {
         return (UnicodeString) field_3_strings.get( id );
     }
 
-    public boolean isString16bit( final int id )
-    {
-        UnicodeString unicodeString = ( (UnicodeString) field_3_strings.get( id  ) );
-        return ( ( unicodeString.getOptionFlags() & 0x01 ) == 1 );
-    }
 
     /**
      * Return a debugging string representation
      *
      * @return string representation
      */
-
-    public String toString()
-    {
+    public String toString() {
         StringBuffer buffer = new StringBuffer();
 
         buffer.append( "[SST]\n" );
@@ -226,53 +156,10 @@ public class SSTRecord
         return buffer.toString();
     }
 
-    /**
-     * @return sid
-     */
-    public short getSid()
-    {
+    public short getSid() {
         return sid;
     }
 
-    /**
-     * @return hashcode
-     */
-    public int hashCode()
-    {
-        return field_2_num_unique_strings;
-    }
-
-    public boolean equals( Object o )
-    {
-        if ( ( o == null ) || ( o.getClass() != this.getClass() ) )
-        {
-            return false;
-        }
-        SSTRecord other = (SSTRecord) o;
-
-        return ( ( field_1_num_strings == other
-                .field_1_num_strings ) && ( field_2_num_unique_strings == other
-                .field_2_num_unique_strings ) && field_3_strings
-                .equals( other.field_3_strings ) );
-    }
-
-    /**
-     * validate SID
-     *
-     * @param id the alleged SID
-     *
-     * @exception RecordFormatException if validation fails
-     */
-
-    protected void validateSid( final short id )
-            throws RecordFormatException
-    {
-        if ( id != sid )
-        {
-            throw new RecordFormatException( "NOT An SST RECORD" );
-        }
-    }
-
     /**
      * Fill the fields from the data
      * <P>
@@ -351,9 +238,7 @@ public class SSTRecord
      *
      * @param in the RecordInputstream to read the record from
      */
-
-    protected void fillFields( RecordInputStream in )
-    {
+    public SSTRecord(RecordInputStream in) {
         // this method is ALWAYS called after construction -- using
         // the nontrivial constructor, of course -- so this is where
         // we initialize our fields
@@ -369,7 +254,6 @@ public class SSTRecord
      * @return an iterator of the strings we hold. All instances are
      *         UnicodeStrings
      */
-
     Iterator getStrings()
     {
         return field_3_strings.iterator();
@@ -378,40 +262,18 @@ public class SSTRecord
     /**
      * @return count of the strings we hold.
      */
-
-    int countStrings()
-    {
+    int countStrings() {
         return field_3_strings.size();
     }
 
-    /**
-     * called by the class that is responsible for writing this sucker.
-     * Subclasses should implement this so that their data is passed back in a
-     * byte array.
-     *
-     * @return size
-     */
-
-    public int serialize( int offset, byte[] data )
-    {
-        SSTSerializer serializer = new SSTSerializer(
-               field_3_strings, getNumStrings(), getNumUniqueStrings() );
-        int bytes = serializer.serialize( offset, data );
+    protected void serialize(ContinuableRecordOutput out) {
+        SSTSerializer serializer = new SSTSerializer(field_3_strings, getNumStrings(), getNumUniqueStrings() );
+        serializer.serialize(out);
         bucketAbsoluteOffsets = serializer.getBucketAbsoluteOffsets();
         bucketRelativeOffsets = serializer.getBucketRelativeOffsets();
-        return bytes;
     }
 
-
-    public int getRecordSize()
-    {
-        SSTRecordSizeCalculator calculator = new SSTRecordSizeCalculator(field_3_strings);
-        int recordSize = calculator.getRecordSize();
-        return recordSize;
-    }
-
-    SSTDeserializer getDeserializer()
-    {
+    SSTDeserializer getDeserializer() {
         return deserializer;
     }
 
@@ -428,15 +290,14 @@ public class SSTRecord
      *                      SST record.
      * @return  The new SST record.
      */
-    public ExtSSTRecord createExtSSTRecord(int sstOffset)
-    {
+    public ExtSSTRecord createExtSSTRecord(int sstOffset) {
         if (bucketAbsoluteOffsets == null || bucketAbsoluteOffsets == null)
             throw new IllegalStateException("SST record has not yet been serialized.");
 
         ExtSSTRecord extSST = new ExtSSTRecord();
         extSST.setNumStringsPerBucket((short)8);
-        int[] absoluteOffsets = (int[]) bucketAbsoluteOffsets.clone();
-        int[] relativeOffsets = (int[]) bucketRelativeOffsets.clone();
+        int[] absoluteOffsets = bucketAbsoluteOffsets.clone();
+        int[] relativeOffsets = bucketRelativeOffsets.clone();
         for ( int i = 0; i < absoluteOffsets.length; i++ )
             absoluteOffsets[i] += sstOffset;
         extSST.setBucketOffsets(absoluteOffsets, relativeOffsets);
@@ -449,8 +310,7 @@ public class SSTRecord
      *
      * @return  The size of the ExtSST record in bytes.
      */
-    public int calcExtSSTRecordSize()
-    {
+    public int calcExtSSTRecordSize() {
       return ExtSSTRecord.getRecordSizeForStrings(field_3_strings.size());
     }
 }
