@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -16,56 +15,43 @@
    limitations under the License.
 ==================================================================== */
 
-
-/*
- * MemErrPtg.java
- *
- * Created on November 21, 2001, 8:46 AM
- */
 package org.apache.poi.hssf.record.formula;
 
-import org.apache.poi.util.LittleEndian;
-import org.apache.poi.hssf.model.Workbook;
-import org.apache.poi.hssf.record.RecordInputStream;
+import org.apache.poi.util.LittleEndianInput;
+import org.apache.poi.util.LittleEndianOutput;
 
 /**
- *
- * @author  andy
+ * 
+ * @author andy
  * @author Jason Height (jheight at chariot dot net dot au)
  * @author Daniel Noll (daniel at nuix dot com dot au)
  */
+public final class MemErrPtg extends OperandPtg {
+	public final static short sid = 0x27;
+	private final static int SIZE = 7;
+	private int field_1_reserved;
+	private short field_2_subex_len;
 
-public class MemErrPtg
-    extends MemAreaPtg
-{
-    public final static short sid  = 0x27;
+	public MemErrPtg(LittleEndianInput in)  {
+		field_1_reserved = in.readInt();
+		field_2_subex_len = in.readShort();
+	}
 
-    /** Creates new MemErrPtg */
+	public void write(LittleEndianOutput out) {
+		out.writeByte(sid + getPtgClass());
+		out.writeInt(field_1_reserved);
+		out.writeShort(field_2_subex_len);
+	}
 
-    public MemErrPtg()
-    {
-    }
+	public int getSize() {
+		return SIZE;
+	}
 
-    public MemErrPtg(RecordInputStream in)
-    {
-        super(in);
-    }
+	public String toFormulaString() {
+		return "ERR#";
+	}
 
-    public void writeBytes(byte [] array, int offset)
-    {
-        super.writeBytes(array, offset);
-        array[offset] = (byte) (sid + ptgClass);
-    }
-
-    public String toFormulaString(Workbook book)
-    {
-        return "ERR#";
-    }
-
-    public Object clone() {
-      MemErrPtg ptg = new MemErrPtg();
-      ptg.setReserved(getReserved());
-      ptg.setSubexpressionLength(getSubexpressionLength());
-      return ptg;
-    }
+	public byte getDefaultOperandClass() {
+		return Ptg.CLASS_VALUE;
+	}
 }
