@@ -20,222 +20,37 @@ package org.apache.poi.hssf.usermodel;
 
 import org.apache.poi.hssf.model.Workbook;
 import org.apache.poi.hssf.record.ExtendedFormatRecord;
-import org.apache.poi.hssf.record.FormatRecord;
-import org.apache.poi.hssf.util.*;
+import org.apache.poi.hssf.record.FontRecord;
+import org.apache.poi.hssf.record.StyleRecord;
+import org.apache.poi.hssf.util.HSSFColor;
+import org.apache.poi.ss.usermodel.CellStyle;
+import org.apache.poi.ss.usermodel.Font;
 
 /**
  * High level representation of the style of a cell in a sheet of a workbook.
  *
- * @version 1.0-pre
- *
  * @author  Andrew C. Oliver (acoliver at apache dot org)
  * @author Jason Height (jheight at chariot dot net dot au)
  * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#createCellStyle()
  * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getCellStyleAt(short)
  * @see org.apache.poi.hssf.usermodel.HSSFCell#setCellStyle(HSSFCellStyle)
  */
-
-public class HSSFCellStyle
-{
-    private ExtendedFormatRecord format                     = null;
-    private short                index                      = 0;
-
-    /**
-     * general (normal) horizontal alignment
-     */
-
-    public final static short    ALIGN_GENERAL              = 0x0;
-
-    /**
-     * left-justified horizontal alignment
-     */
-
-    public final static short    ALIGN_LEFT                 = 0x1;
-
-    /**
-     * center horizontal alignment
-     */
-
-    public final static short    ALIGN_CENTER               = 0x2;
-
-    /**
-     * right-justified horizontal alignment
-     */
-
-    public final static short    ALIGN_RIGHT                = 0x3;
-
-    /**
-     * fill? horizontal alignment
-     */
-
-    public final static short    ALIGN_FILL                 = 0x4;
-
-    /**
-     * justified horizontal alignment
-     */
-
-    public final static short    ALIGN_JUSTIFY              = 0x5;
-
-    /**
-     * center-selection? horizontal alignment
-     */
-
-    public final static short    ALIGN_CENTER_SELECTION     = 0x6;
-
-    /**
-     * top-aligned vertical alignment
-     */
-
-    public final static short    VERTICAL_TOP               = 0x0;
-
-    /**
-     * center-aligned vertical alignment
-     */
-
-    public final static short    VERTICAL_CENTER            = 0x1;
-
-    /**
-     * bottom-aligned vertical alignment
-     */
-
-    public final static short    VERTICAL_BOTTOM            = 0x2;
-
-    /**
-     * vertically justified vertical alignment
-     */
-
-    public final static short    VERTICAL_JUSTIFY           = 0x3;
-
-    /**
-     * No border
-     */
-
-    public final static short    BORDER_NONE                = 0x0;
-
-    /**
-     * Thin border
-     */
-
-    public final static short    BORDER_THIN                = 0x1;
-
-    /**
-     * Medium border
-     */
-
-    public final static short    BORDER_MEDIUM              = 0x2;
-
-    /**
-     * dash border
-     */
-
-    public final static short    BORDER_DASHED              = 0x3;
-
-    /**
-     * dot border
-     */
-
-    public final static short    BORDER_HAIR              = 0x4;
-
-    /**
-     * Thick border
-     */
-
-    public final static short    BORDER_THICK               = 0x5;
-
-    /**
-     * double-line border
-     */
-
-    public final static short    BORDER_DOUBLE              = 0x6;
-
-    /**
-     * hair-line border
-     */
-
-    public final static short    BORDER_DOTTED                = 0x7;
-
-    /**
-     * Medium dashed border
-     */
-
-    public final static short    BORDER_MEDIUM_DASHED       = 0x8;
-
-    /**
-     * dash-dot border
-     */
-
-    public final static short    BORDER_DASH_DOT            = 0x9;
-
-    /**
-     * medium dash-dot border
-     */
-
-    public final static short    BORDER_MEDIUM_DASH_DOT     = 0xA;
-
-    /**
-     * dash-dot-dot border
-     */
-
-    public final static short    BORDER_DASH_DOT_DOT        = 0xB;
-
-    /**
-     * medium dash-dot-dot border
-     */
-
-    public final static short    BORDER_MEDIUM_DASH_DOT_DOT = 0xC;
-
-    /**
-     * slanted dash-dot border
-     */
-
-    public final static short    BORDER_SLANTED_DASH_DOT    = 0xD;
-
-    /**  No background */
-    public final static short     NO_FILL             = 0  ;
-    /**  Solidly filled */
-    public final static short     SOLID_FOREGROUND    = 1  ;
-    /**  Small fine dots */
-    public final static short     FINE_DOTS           = 2  ;
-    /**  Wide dots */
-    public final static short     ALT_BARS            = 3  ;
-    /**  Sparse dots */
-    public final static short     SPARSE_DOTS         = 4  ;
-    /**  Thick horizontal bands */
-    public final static short     THICK_HORZ_BANDS    = 5  ;
-    /**  Thick vertical bands */
-    public final static short     THICK_VERT_BANDS    = 6  ;
-    /**  Thick backward facing diagonals */
-    public final static short     THICK_BACKWARD_DIAG = 7  ;
-    /**  Thick forward facing diagonals */
-    public final static short     THICK_FORWARD_DIAG  = 8  ;
-    /**  Large spots */
-    public final static short     BIG_SPOTS           = 9  ;
-    /**  Brick-like layout */
-    public final static short     BRICKS              = 10 ;
-    /**  Thin horizontal bands */
-    public final static short     THIN_HORZ_BANDS     = 11 ;
-    /**  Thin vertical bands */
-    public final static short     THIN_VERT_BANDS     = 12 ;
-    /**  Thin backward diagonal */
-    public final static short     THIN_BACKWARD_DIAG  = 13 ;
-    /**  Thin forward diagonal */
-    public final static short     THIN_FORWARD_DIAG   = 14 ;
-    /**  Squares */
-    public final static short     SQUARES             = 15 ;
-    /**  Diamonds */
-    public final static short     DIAMONDS            = 16 ;
-    /**  Less Dots */
-    public final static short     LESS_DOTS           = 17 ;
-    /**  Least Dots */
-    public final static short     LEAST_DOTS          = 18 ;
+public final class HSSFCellStyle implements CellStyle {
+    private ExtendedFormatRecord _format                     = null;
+    private short                _index                      = 0;
+    private Workbook             _workbook                   = null;
 
 
     /** Creates new HSSFCellStyle why would you want to do this?? */
-
-    protected HSSFCellStyle(short index, ExtendedFormatRecord rec)
+    protected HSSFCellStyle(short index, ExtendedFormatRecord rec, HSSFWorkbook workbook)
     {
-        this.index = index;
-        format     = rec;
+    	this(index, rec, workbook.getWorkbook());
+    }
+    protected HSSFCellStyle(short index, ExtendedFormatRecord rec, Workbook workbook)
+    {
+        _workbook = workbook;
+        _index = index;
+        _format     = rec;
     }
 
     /**
@@ -243,20 +58,34 @@ public class HSSFCellStyle
      * @return unique index number of the underlying record this style represents (probably you don't care
      *  unless you're comparing which one is which)
      */
-
     public short getIndex()
     {
-        return index;
+        return _index;
+    }
+
+    /**
+     * Return the parent style for this cell style.
+     * In most cases this will be null, but in a few
+     *  cases there'll be a fully defined parent.
+     */
+    public HSSFCellStyle getParentStyle() {
+    	if(_format.getParentIndex() == 0) {
+    		return null;
+    	}
+    	return new HSSFCellStyle(
+    			_format.getParentIndex(),
+    			_workbook.getExFormatAt(_format.getParentIndex()),
+    			_workbook
+    	);
     }
 
     /**
      * set the data format (must be a valid format)
      * @see org.apache.poi.hssf.usermodel.HSSFDataFormat
      */
-
     public void setDataFormat(short fmt)
     {
-        format.setFormatIndex(fmt);
+        _format.setFormatIndex(fmt);
     }
 
     /**
@@ -266,17 +95,39 @@ public class HSSFCellStyle
 
     public short getDataFormat()
     {
-        return format.getFormatIndex();
+        return _format.getFormatIndex();
+    }
+
+    /**
+     * Get the contents of the format string, by looking up
+     *  the DataFormat against the bound workbook
+     * @see org.apache.poi.hssf.usermodel.HSSFDataFormat
+     * @return the format string or "General" if not found
+     */
+    public String getDataFormatString() {
+        return getDataFormatString(_workbook);
     }
-    
     /**
      * Get the contents of the format string, by looking up
      *  the DataFormat against the supplied workbook
      * @see org.apache.poi.hssf.usermodel.HSSFDataFormat
+     *
+     * @return the format string or "General" if not found
      */
-    public String getDataFormatString(Workbook workbook) {
-    	HSSFDataFormat format = new HSSFDataFormat(workbook);
-    	
+    public String getDataFormatString(org.apache.poi.ss.usermodel.Workbook workbook) {
+    	HSSFDataFormat format = new HSSFDataFormat( ((HSSFWorkbook)workbook).getWorkbook() );
+
+        int idx = getDataFormat();
+        return idx == -1 ? "General" : format.getFormat(getDataFormat());
+    }
+    /**
+     * Get the contents of the format string, by looking up
+     *  the DataFormat against the supplied low level workbook
+     * @see org.apache.poi.hssf.usermodel.HSSFDataFormat
+     */
+    public String getDataFormatString(org.apache.poi.hssf.model.Workbook workbook) {
+    	HSSFDataFormat format = new HSSFDataFormat( workbook );
+
         return format.getFormat(getDataFormat());
     }
 
@@ -286,12 +137,13 @@ public class HSSFCellStyle
      * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#createFont()
      * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getFontAt(short)
      */
-
-    public void setFont(HSSFFont font)
-    {
-        format.setIndentNotParentFont(true);
+    public void setFont(Font font) {
+		setFont((HSSFFont)font);
+	}
+	public void setFont(HSSFFont font) {
+        _format.setIndentNotParentFont(true);
         short fontindex = font.getIndex();
-        format.setFontIndex(fontindex);
+        _format.setFontIndex(fontindex);
     }
 
     /**
@@ -300,59 +152,55 @@ public class HSSFCellStyle
      */
     public short getFontIndex()
     {
-        return format.getFontIndex();
+        return _format.getFontIndex();
     }
-    
+
     /**
      * gets the font for this style
      * @param parentWorkbook The HSSFWorkbook that this style belongs to
      * @see org.apache.poi.hssf.usermodel.HSSFCellStyle#getFontIndex()
      * @see org.apache.poi.hssf.usermodel.HSSFWorkbook#getFontAt(short)
      */
-    public HSSFFont getFont(HSSFWorkbook parentWorkbook) {
-    	return parentWorkbook.getFontAt(getFontIndex());
+    public HSSFFont getFont(org.apache.poi.ss.usermodel.Workbook parentWorkbook) {
+    	return ((HSSFWorkbook) parentWorkbook).getFontAt(getFontIndex());
     }
 
     /**
      * set the cell's using this style to be hidden
      * @param hidden - whether the cell using this style should be hidden
      */
-
     public void setHidden(boolean hidden)
     {
-        format.setIndentNotParentCellOptions(true);
-        format.setHidden(hidden);
+        _format.setIndentNotParentCellOptions(true);
+        _format.setHidden(hidden);
     }
 
     /**
      * get whether the cell's using this style are to be hidden
      * @return hidden - whether the cell using this style should be hidden
      */
-
     public boolean getHidden()
     {
-        return format.isHidden();
+        return _format.isHidden();
     }
 
     /**
      * set the cell's using this style to be locked
      * @param locked - whether the cell using this style should be locked
      */
-
     public void setLocked(boolean locked)
     {
-        format.setIndentNotParentCellOptions(true);
-        format.setLocked(locked);
+        _format.setIndentNotParentCellOptions(true);
+        _format.setLocked(locked);
     }
 
     /**
      * get whether the cell's using this style are to be locked
      * @return hidden - whether the cell using this style should be locked
      */
-
     public boolean getLocked()
     {
-        return format.isLocked();
+        return _format.isLocked();
     }
 
     /**
@@ -366,11 +214,10 @@ public class HSSFCellStyle
      * @see #ALIGN_JUSTIFY
      * @see #ALIGN_CENTER_SELECTION
      */
-
     public void setAlignment(short align)
     {
-        format.setIndentNotParentAlignment(true);
-        format.setAlignment(align);
+        _format.setIndentNotParentAlignment(true);
+        _format.setAlignment(align);
     }
 
     /**
@@ -384,53 +231,28 @@ public class HSSFCellStyle
      * @see #ALIGN_JUSTIFY
      * @see #ALIGN_CENTER_SELECTION
      */
-
     public short getAlignment()
     {
-        return format.getAlignment();
+        return _format.getAlignment();
     }
 
-    /**
-     * get whether this cell is to be part of a merged block of cells
-     *
-     * @returns merged or not
-     */
-
-//    public boolean getMergeCells()
-//    {
-//        return format.getMergeCells();
-//    }
-
-    /**
-     * set whether this cell is to be part of a merged block of cells
-     *
-     * @param merge  merged or not
-     */
-
-//    public void setMergeCells(boolean merge)
-//    {
-//        format.setMergeCells(merge);
-//    }
-
     /**
      * set whether the text should be wrapped
      * @param wrapped  wrap text or not
      */
-
     public void setWrapText(boolean wrapped)
     {
-        format.setIndentNotParentAlignment(true);
-        format.setWrapText(wrapped);
+        _format.setIndentNotParentAlignment(true);
+        _format.setWrapText(wrapped);
     }
 
     /**
      * get whether the text should be wrapped
      * @return wrap text or not
      */
-
     public boolean getWrapText()
     {
-        return format.getWrapText();
+        return _format.getWrapText();
     }
 
     /**
@@ -441,10 +263,9 @@ public class HSSFCellStyle
      * @see #VERTICAL_BOTTOM
      * @see #VERTICAL_JUSTIFY
      */
-
     public void setVerticalAlignment(short align)
     {
-        format.setVerticalAlignment(align);
+        _format.setVerticalAlignment(align);
     }
 
     /**
@@ -455,17 +276,15 @@ public class HSSFCellStyle
      * @see #VERTICAL_BOTTOM
      * @see #VERTICAL_JUSTIFY
      */
-
     public short getVerticalAlignment()
     {
-        return format.getVerticalAlignment();
+        return _format.getVerticalAlignment();
     }
 
     /**
      * set the degree of rotation for the text in the cell
      * @param rotation degrees (between -90 and 90 degrees)
      */
-
     public void setRotation(short rotation)
     {
       if ((rotation < 0)&&(rotation >= -90)) {
@@ -476,17 +295,16 @@ public class HSSFCellStyle
       else if ((rotation < -90)  ||(rotation > 90))
         //Do not allow an incorrect rotation to be set
         throw new IllegalArgumentException("The rotation must be between -90 and 90 degrees");
-        format.setRotation(rotation);
+        _format.setRotation(rotation);
     }
 
     /**
      * get the degree of rotation for the text in the cell
      * @return rotation degrees (between -90 and 90 degrees)
      */
-
     public short getRotation()
     {
-      short rotation = format.getRotation();
+      short rotation = _format.getRotation();
       if (rotation > 90)
         //This is actually the 4th quadrant
         rotation = (short)(90-rotation);
@@ -497,20 +315,18 @@ public class HSSFCellStyle
      * set the number of spaces to indent the text in the cell
      * @param indent - number of spaces
      */
-
     public void setIndention(short indent)
     {
-        format.setIndent(indent);
+        _format.setIndent(indent);
     }
 
     /**
      * get the number of spaces to indent the text in the cell
      * @return indent - number of spaces
      */
-
     public short getIndention()
     {
-        return format.getIndent();
+        return _format.getIndent();
     }
 
     /**
@@ -531,11 +347,10 @@ public class HSSFCellStyle
      * @see #BORDER_MEDIUM_DASH_DOT_DOT
      * @see #BORDER_SLANTED_DASH_DOT
      */
-
     public void setBorderLeft(short border)
     {
-        format.setIndentNotParentBorder(true);
-        format.setBorderLeft(border);
+        _format.setIndentNotParentBorder(true);
+        _format.setBorderLeft(border);
     }
 
     /**
@@ -556,10 +371,9 @@ public class HSSFCellStyle
      * @see #BORDER_MEDIUM_DASH_DOT_DOT
      * @see #BORDER_SLANTED_DASH_DOT
      */
-
     public short getBorderLeft()
     {
-        return format.getBorderLeft();
+        return _format.getBorderLeft();
     }
 
     /**
@@ -580,11 +394,10 @@ public class HSSFCellStyle
      * @see #BORDER_MEDIUM_DASH_DOT_DOT
      * @see #BORDER_SLANTED_DASH_DOT
      */
-
     public void setBorderRight(short border)
     {
-        format.setIndentNotParentBorder(true);
-        format.setBorderRight(border);
+        _format.setIndentNotParentBorder(true);
+        _format.setBorderRight(border);
     }
 
     /**
@@ -605,10 +418,9 @@ public class HSSFCellStyle
      * @see #BORDER_MEDIUM_DASH_DOT_DOT
      * @see #BORDER_SLANTED_DASH_DOT
      */
-
     public short getBorderRight()
     {
-        return format.getBorderRight();
+        return _format.getBorderRight();
     }
 
     /**
@@ -629,11 +441,10 @@ public class HSSFCellStyle
      * @see #BORDER_MEDIUM_DASH_DOT_DOT
      * @see #BORDER_SLANTED_DASH_DOT
      */
-
     public void setBorderTop(short border)
     {
-        format.setIndentNotParentBorder(true);
-        format.setBorderTop(border);
+        _format.setIndentNotParentBorder(true);
+        _format.setBorderTop(border);
     }
 
     /**
@@ -654,10 +465,9 @@ public class HSSFCellStyle
      * @see #BORDER_MEDIUM_DASH_DOT_DOT
      * @see #BORDER_SLANTED_DASH_DOT
      */
-
     public short getBorderTop()
     {
-        return format.getBorderTop();
+        return _format.getBorderTop();
     }
 
     /**
@@ -678,11 +488,10 @@ public class HSSFCellStyle
      * @see #BORDER_MEDIUM_DASH_DOT_DOT
      * @see #BORDER_SLANTED_DASH_DOT
      */
-
     public void setBorderBottom(short border)
     {
-        format.setIndentNotParentBorder(true);
-        format.setBorderBottom(border);
+        _format.setIndentNotParentBorder(true);
+        _format.setBorderBottom(border);
     }
 
     /**
@@ -705,7 +514,7 @@ public class HSSFCellStyle
      */
     public short getBorderBottom()
     {
-        return format.getBorderBottom();
+        return _format.getBorderBottom();
     }
 
     /**
@@ -714,17 +523,17 @@ public class HSSFCellStyle
      */
     public void setLeftBorderColor(short color)
     {
-        format.setLeftBorderPaletteIdx(color);
+        _format.setLeftBorderPaletteIdx(color);
     }
 
     /**
      * get the color to use for the left border
      * @see org.apache.poi.hssf.usermodel.HSSFPalette#getColor(short)
-     * @param color The index of the color definition
+     * @return The index of the color definition
      */
     public short getLeftBorderColor()
     {
-        return format.getLeftBorderPaletteIdx();
+        return _format.getLeftBorderPaletteIdx();
     }
 
     /**
@@ -733,17 +542,17 @@ public class HSSFCellStyle
      */
     public void setRightBorderColor(short color)
     {
-        format.setRightBorderPaletteIdx(color);
+        _format.setRightBorderPaletteIdx(color);
     }
 
     /**
      * get the color to use for the left border
      * @see org.apache.poi.hssf.usermodel.HSSFPalette#getColor(short)
-     * @param color The index of the color definition
+     * @return The index of the color definition
      */
     public short getRightBorderColor()
     {
-        return format.getRightBorderPaletteIdx();
+        return _format.getRightBorderPaletteIdx();
     }
 
     /**
@@ -752,17 +561,17 @@ public class HSSFCellStyle
      */
     public void setTopBorderColor(short color)
     {
-        format.setTopBorderPaletteIdx(color);
+        _format.setTopBorderPaletteIdx(color);
     }
 
     /**
      * get the color to use for the top border
      * @see org.apache.poi.hssf.usermodel.HSSFPalette#getColor(short)
-     * @param color The index of the color definition
+     * @return The index of the color definition
      */
     public short getTopBorderColor()
     {
-        return format.getTopBorderPaletteIdx();
+        return _format.getTopBorderPaletteIdx();
     }
 
     /**
@@ -771,17 +580,17 @@ public class HSSFCellStyle
      */
     public void setBottomBorderColor(short color)
     {
-        format.setBottomBorderPaletteIdx(color);
+        _format.setBottomBorderPaletteIdx(color);
     }
 
     /**
      * get the color to use for the left border
      * @see org.apache.poi.hssf.usermodel.HSSFPalette#getColor(short)
-     * @param color The index of the color definition
+     * @return The index of the color definition
      */
     public short getBottomBorderColor()
     {
-        return format.getBottomBorderPaletteIdx();
+        return _format.getBottomBorderPaletteIdx();
     }
 
     /**
@@ -810,19 +619,18 @@ public class HSSFCellStyle
      */
     public void setFillPattern(short fp)
     {
-        format.setAdtlFillPattern(fp);
+        _format.setAdtlFillPattern(fp);
     }
 
     /**
      * get the fill pattern (??) - set to 1 to fill with foreground color
      * @return fill pattern
      */
-
     public short getFillPattern()
     {
-        return format.getAdtlFillPattern();
+        return _format.getAdtlFillPattern();
     }
-    
+
     /**
      * Checks if the background and foreground fills are set correctly when one
      * or the other is set to the default color.
@@ -831,18 +639,18 @@ public class HSSFCellStyle
      * <p>NONE         AUTOMATIC</p>
      * <p>0x41         0x40</p>
      * <p>NONE         RED/ANYTHING</p>
-     * <p>0x40         0xSOMETHING</p> 
+     * <p>0x40         0xSOMETHING</p>
      */
     private void checkDefaultBackgroundFills() {
-      if (format.getFillForeground() == org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index) {
+      if (_format.getFillForeground() == org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index) {
     	  //JMH: Why +1, hell why not. I guess it made some sense to someone at the time. Doesnt
     	  //to me now.... But experience has shown that when the fore is set to AUTOMATIC then the
     	  //background needs to be incremented......
-    	  if (format.getFillBackground() != (org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index+1))
+    	  if (_format.getFillBackground() != (org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index+1))
     		  setFillBackgroundColor((short)(org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index+1));
-      } else if (format.getFillBackground() == org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index+1)
+      } else if (_format.getFillBackground() == org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index+1)
     	  //Now if the forground changes to a non-AUTOMATIC color the background resets itself!!!
-    	  if (format.getFillForeground() != org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index)
+    	  if (_format.getFillForeground() != org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index)
     		  setFillBackgroundColor(org.apache.poi.hssf.util.HSSFColor.AUTOMATIC.index);
     }
 
@@ -852,14 +660,14 @@ public class HSSFCellStyle
      * For example:
      * <pre>
      * cs.setFillPattern(HSSFCellStyle.FINE_DOTS );
-     * cs.setFillBackgroundColor(new HSSFColor.RED().getIndex()); 
+     * cs.setFillBackgroundColor(new HSSFColor.RED().getIndex());
      * </pre>
      * optionally a Foreground and background fill can be applied:
      * <i>Note: Ensure Foreground color is set prior to background</i>
      * <pre>
      * cs.setFillPattern(HSSFCellStyle.FINE_DOTS );
      * cs.setFillForegroundColor(new HSSFColor.BLUE().getIndex());
-     * cs.setFillBackgroundColor(new HSSFColor.RED().getIndex()); 
+     * cs.setFillBackgroundColor(new HSSFColor.RED().getIndex());
      * </pre>
      * or, for the special case of SOLID_FILL:
      * <pre>
@@ -871,26 +679,28 @@ public class HSSFCellStyle
      *
      * @param bg  color
      */
-
     public void setFillBackgroundColor(short bg)
-    {    	
-        format.setFillBackground(bg);
+    {
+        _format.setFillBackground(bg);
         checkDefaultBackgroundFills();
     }
 
     /**
-     * get the background fill color
+     * Get the background fill color.
+     * Note - many cells are actually filled with a foreground
+     *  fill, not a background fill - see {@link #getFillForegroundColor()}
      * @see org.apache.poi.hssf.usermodel.HSSFPalette#getColor(short)
      * @return fill color
      */
     public short getFillBackgroundColor()
     {
-    	short result = format.getFillBackground();
+    	short result = _format.getFillBackground();
     	//JMH: Do this ridiculous conversion, and let HSSFCellStyle
     	//internally migrate back and forth
-    	if (result == (HSSFColor.AUTOMATIC.index+1))
-    		return HSSFColor.AUTOMATIC.index;
-    	else return result;
+    	if (result == (HSSFColor.AUTOMATIC.index+1)) {
+			return HSSFColor.AUTOMATIC.index;
+		}
+    	return result;
     }
 
     /**
@@ -900,17 +710,137 @@ public class HSSFCellStyle
      */
     public void setFillForegroundColor(short bg)
     {
-        format.setFillForeground(bg);
+        _format.setFillForeground(bg);
         checkDefaultBackgroundFills();
     }
 
     /**
-     * get the foreground fill color
+     * Get the foreground fill color.
+     * Many cells are filled with this, instead of a
+     *  background color ({@link #getFillBackgroundColor()})
      * @see org.apache.poi.hssf.usermodel.HSSFPalette#getColor(short)
      * @return fill color
      */
     public short getFillForegroundColor()
     {
-        return format.getFillForeground();
+        return _format.getFillForeground();
     }
+
+    /**
+     * Gets the name of the user defined style.
+     * Returns null for built in styles, and
+     *  styles where no name has been defined
+     */
+    public String getUserStyleName() {
+    	StyleRecord sr = _workbook.getStyleRecord(_index);
+    	if(sr == null) {
+    		return null;
+    	}
+    	if(sr.isBuiltin()) {
+    		return null;
+    	}
+    	return sr.getName();
+    }
+
+    /**
+     * Sets the name of the user defined style.
+     * Will complain if you try this on a built in style.
+     */
+    public void setUserStyleName(String styleName) {
+    	StyleRecord sr = _workbook.getStyleRecord(_index);
+    	if(sr == null) {
+    		sr = _workbook.createStyleRecord(_index);
+    	}
+    	if(sr.isBuiltin()) {
+    		throw new IllegalArgumentException("Unable to set user specified style names for built in styles!");
+    	}
+    	sr.setName(styleName);
+    }
+
+    /**
+     * Verifies that this style belongs to the supplied Workbook.
+     * Will throw an exception if it belongs to a different one.
+     * This is normally called when trying to assign a style to a
+     *  cell, to ensure the cell and the style are from the same
+     *  workbook (if they're not, it won't work)
+     * @throws IllegalArgumentException if there's a workbook mis-match
+     */
+    public void verifyBelongsToWorkbook(HSSFWorkbook wb) {
+		if(wb.getWorkbook() != _workbook) {
+			throw new IllegalArgumentException("This Style does not belong to the supplied Workbook. Are you trying to assign a style from one workbook to the cell of a differnt workbook?");
+		}
+	}
+
+    /**
+     * Clones all the style information from another
+     *  HSSFCellStyle, onto this one. This
+     *  HSSFCellStyle will then have all the same
+     *  properties as the source, but the two may
+     *  be edited independently.
+     * Any stylings on this HSSFCellStyle will be lost!
+     *
+     * The source HSSFCellStyle could be from another
+     *  HSSFWorkbook if you like. This allows you to
+     *  copy styles from one HSSFWorkbook to another.
+     */
+    public void cloneStyleFrom(CellStyle source) {
+		if(source instanceof HSSFCellStyle) {
+			this.cloneStyleFrom((HSSFCellStyle)source);
+		} else {
+		    throw new IllegalArgumentException("Can only clone from one HSSFCellStyle to another, not between HSSFCellStyle and XSSFCellStyle");
+		}
+	}
+    public void cloneStyleFrom(HSSFCellStyle source) {
+    	// First we need to clone the extended format
+    	//  record
+    	_format.cloneStyleFrom(source._format);
+
+    	// Handle matching things if we cross workbooks
+    	if(_workbook != source._workbook) {
+			// Then we need to clone the format string,
+			//  and update the format record for this
+    		short fmt = (short)_workbook.createFormat(source.getDataFormatString() );
+    		setDataFormat(fmt);
+
+			// Finally we need to clone the font,
+			//  and update the format record for this
+    		FontRecord fr = _workbook.createNewFont();
+    		fr.cloneStyleFrom(
+    				source._workbook.getFontRecordAt(
+    						source.getFontIndex()
+    				)
+    		);
+
+    		HSSFFont font = new HSSFFont(
+    				(short)_workbook.getFontIndex(fr), fr
+    		);
+    		setFont(font);
+    	}
+    }
+
+
+	public int hashCode() {
+		final int prime = 31;
+		int result = 1;
+		result = prime * result + ((_format == null) ? 0 : _format.hashCode());
+		result = prime * result + _index;
+		return result;
+	}
+
+	public boolean equals(Object obj) {
+		if (this == obj) return true;
+		if (obj == null) return false;
+		if (obj instanceof HSSFCellStyle) {
+			final HSSFCellStyle other = (HSSFCellStyle) obj;
+			if (_format == null) {
+				if (other._format != null)
+					return false;
+			} else if (!_format.equals(other._format))
+				return false;
+			if (_index != other._index)
+				return false;
+			return true;
+		}
+		return false;
+	}
 }
