@@ -17,7 +17,7 @@
 
 package org.apache.poi.hssf.usermodel;
 
-
+import org.apache.poi.ss.usermodel.ClientAnchor;
 
 
 /**
@@ -26,9 +26,7 @@ package org.apache.poi.hssf.usermodel;
  *
  * @author Glen Stampoultzis (glens at apache.org)
  */
-public class HSSFClientAnchor
-        extends HSSFAnchor
-{
+public final class HSSFClientAnchor extends HSSFAnchor implements ClientAnchor {
     short col1;
     int row1;
     short col2;
@@ -108,10 +106,10 @@ public class HSSFClientAnchor
     private float getRowHeightInPoints(HSSFSheet sheet, int rowNum)
     {
         HSSFRow row = sheet.getRow(rowNum);
-        if (row == null)
+        if (row == null) {
             return sheet.getDefaultRowHeightInPoints();
-        else
-            return row.getHeightInPoints();
+        }
+        return row.getHeightInPoints();
     }
 
     public short getCol1()
@@ -124,6 +122,9 @@ public class HSSFClientAnchor
         checkRange(col1, 0, 255, "col1");
         this.col1 = col1;
     }
+    public void setCol1( int col1 ){
+        setCol1((short)col1);
+    }
 
     public short getCol2()
     {
@@ -136,6 +137,10 @@ public class HSSFClientAnchor
         this.col2 = col2;
     }
 
+    public void setCol2( int col2 ){
+        setCol2((short)col2);
+    }
+
     public int getRow1()
     {
         return row1;
@@ -197,10 +202,10 @@ public class HSSFClientAnchor
      */
     public boolean isHorizontallyFlipped()
     {
-        if (col1 == col2)
+        if (col1 == col2) {
             return dx1 > dx2;
-        else
-            return col1 > col2;
+        }
+        return col1 > col2;
     }
 
     /**
@@ -208,10 +213,10 @@ public class HSSFClientAnchor
      */
     public boolean isVerticallyFlipped()
     {
-        if (row1 == row2)
+        if (row1 == row2) {
             return dy1 > dy2;
-        else
-            return row1 > row2;
+        }
+        return row1 > row2;
     }
 
     /**
