@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -15,18 +14,16 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
-
 
 package org.apache.poi.hdf.extractor;
 
 /**
  * Comment me
  *
- * @author Ryan Ackley 
+ * @author Ryan Ackley
  */
 
-public class TC
+public final class TC
 {
 
   boolean _fFirstMerged;
