@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -15,8 +14,6 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
-
 
 package org.apache.poi.hslf;
 
@@ -29,6 +26,7 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.List;
@@ -37,14 +35,10 @@ import org.apache.poi.POIDocument;
 import org.apache.poi.hslf.exceptions.CorruptPowerPointFileException;
 import org.apache.poi.hslf.exceptions.EncryptedPowerPointFileException;
 import org.apache.poi.hslf.exceptions.HSLFException;
-import org.apache.poi.hslf.record.CurrentUserAtom;
-import org.apache.poi.hslf.record.ExOleObjStg;
-import org.apache.poi.hslf.record.PersistPtrHolder;
-import org.apache.poi.hslf.record.PositionDependentRecord;
-import org.apache.poi.hslf.record.Record;
-import org.apache.poi.hslf.record.UserEditAtom;
+import org.apache.poi.hslf.record.*;
 import org.apache.poi.hslf.usermodel.ObjectData;
 import org.apache.poi.hslf.usermodel.PictureData;
+import org.apache.poi.poifs.filesystem.DirectoryNode;
 import org.apache.poi.poifs.filesystem.DocumentEntry;
 import org.apache.poi.poifs.filesystem.DocumentInputStream;
 import org.apache.poi.poifs.filesystem.POIFSFileSystem;
@@ -53,18 +47,14 @@ import org.apache.poi.util.POILogFactory;
 import org.apache.poi.util.POILogger;
 
 /**
- * This class contains the main functionality for the Powerpoint file 
+ * This class contains the main functionality for the Powerpoint file
  * "reader". It is only a very basic class for now
  *
  * @author Nick Burch
  */
-
-public class HSLFSlideShow extends POIDocument
-{
+public final class HSLFSlideShow extends POIDocument {
     // For logging
-    protected POILogger logger = POILogFactory.getLogger(this.getClass());
-
-	private InputStream istream;
+    private POILogger logger = POILogFactory.getLogger(this.getClass());
 
 	// Holds metadata on where things are in our document
 	private CurrentUserAtom currentUser;
@@ -76,7 +66,7 @@ public class HSLFSlideShow extends POIDocument
 	private Record[] _records;
 
 	// Raw Pictures contained in the pictures stream
-	private PictureData[] _pictures;
+	private List<PictureData> _pictures;
 
     // Embedded objects stored in storage records in the document stream, lazily populated.
     private ObjectData[] _objects;
@@ -90,7 +80,7 @@ public class HSLFSlideShow extends POIDocument
 	}
 
 	/**
-	 * Constructs a Powerpoint document from fileName. Parses the document 
+	 * Constructs a Powerpoint document from fileName. Parses the document
 	 * and places all the important stuff into data structures.
 	 *
 	 * @param fileName The name of the file to read.
@@ -100,23 +90,21 @@ public class HSLFSlideShow extends POIDocument
 	{
 		this(new FileInputStream(fileName));
 	}
-  
+
 	/**
-	 * Constructs a Powerpoint document from an input stream. Parses the 
+	 * Constructs a Powerpoint document from an input stream. Parses the
 	 * document and places all the important stuff into data structures.
 	 *
 	 * @param inputStream the source of the data
 	 * @throws IOException if there is a problem while parsing the document.
 	 */
-	public HSLFSlideShow(InputStream inputStream) throws IOException
-	{
+	public HSLFSlideShow(InputStream inputStream) throws IOException {
 		//do Ole stuff
 		this(new POIFSFileSystem(inputStream));
-		istream = inputStream;
 	}
 
 	/**
-	 * Constructs a Powerpoint document from a POIFS Filesystem. Parses the 
+	 * Constructs a Powerpoint document from a POIFS Filesystem. Parses the
 	 * document and places all the important stuff into data structures.
 	 *
 	 * @param filesystem the POIFS FileSystem to read from
@@ -124,16 +112,30 @@ public class HSLFSlideShow extends POIDocument
 	 */
 	public HSLFSlideShow(POIFSFileSystem filesystem) throws IOException
 	{
-		this.filesystem = filesystem;
-		
+		this(filesystem.getRoot(), filesystem);
+	}
+
+	/**
+	 * Constructs a Powerpoint document from a specific point in a
+	 *  POIFS Filesystem. Parses the document and places all the
+	 *  important stuff into data structures.
+	 *
+	 * @param dir the POIFS directory to read from
+	 * @param filesystem the POIFS FileSystem to read from
+	 * @throws IOException if there is a problem while parsing the document.
+	 */
+	public HSLFSlideShow(DirectoryNode dir, POIFSFileSystem filesystem) throws IOException
+	{
+		super(dir, filesystem);
+
 		// First up, grab the "Current User" stream
 		// We need this before we can detect Encrypted Documents
 		readCurrentUserStream();
-		
-		// Next up, grab the data that makes up the 
+
+		// Next up, grab the data that makes up the
 		//  PowerPoint stream
 		readPowerPointStream();
-		
+
 		// Check to see if we have an encrypted document,
 		//  bailing out if we do
 		boolean encrypted = EncryptedSlideShow.checkIfEncrypted(this);
@@ -144,41 +146,30 @@ public class HSLFSlideShow extends POIDocument
 		// Now, build records based on the PowerPoint stream
 		buildRecords();
 
-		// Look for Property Streams:
-		readProperties();
-		
 		// Look for any other streams
 		readOtherStreams();
 
 		// Look for Picture Streams:
 		readPictures();
 	}
-
 	/**
 	 * Constructs a new, empty, Powerpoint document.
 	 */
-	public HSLFSlideShow() throws IOException 
-	{
-		this(HSLFSlideShow.class.getResourceAsStream("/org/apache/poi/hslf/data/empty.ppt"));
-	}
-
-	/**
-	 * Shuts things down. Closes underlying streams etc
-	 *
-	 * @throws IOException
-	 */
-	public void close() throws IOException
-	{
-		if(istream != null) {
-			istream.close();
+	public static final HSLFSlideShow create() {
+		InputStream is = HSLFSlideShow.class.getResourceAsStream("data/empty.ppt");
+		if (is == null) {
+			throw new RuntimeException("Missing resource 'empty.ppt'");
+		}
+		try {
+			return new HSLFSlideShow(is);
+		} catch (IOException e) {
+			throw new RuntimeException(e);
 		}
-		filesystem = null;
 	}
 
-
 	/**
-	 * Extracts the main PowerPoint document stream from the 
-	 *  POI file, ready to be passed 
+	 * Extracts the main PowerPoint document stream from the
+	 *  POI file, ready to be passed
 	 *
 	 * @throws IOException
 	 */
@@ -186,15 +177,15 @@ public class HSLFSlideShow extends POIDocument
 	{
 		// Get the main document stream
 		DocumentEntry docProps =
-			(DocumentEntry)filesystem.getRoot().getEntry("PowerPoint Document");
+			(DocumentEntry)directory.getEntry("PowerPoint Document");
 
 		// Grab the document stream
 		_docstream = new byte[docProps.getSize()];
-		filesystem.createDocumentInputStream("PowerPoint Document").read(_docstream);
+		directory.createDocumentInputStream("PowerPoint Document").read(_docstream);
 	}
-	
+
 	/**
-	 * Builds the list of records, based on the contents  
+	 * Builds the list of records, based on the contents
 	 *  of the PowerPoint stream
 	 */
 	private void buildRecords()
@@ -212,7 +203,7 @@ public class HSLFSlideShow extends POIDocument
 		//      <xx xx yy yy zz zz zz zz dd dd dd dd dd dd dd>
 		// All lengths given exclude the 8 byte record header
 		// (Data records are known as Atoms)
-	
+
 		// Document should start with:
 		//   0F 00 E8 03 ## ## ## ##
 	    //     (type 1000 = document, info 00 0f is normal, rest is document length)
@@ -222,9 +213,9 @@ public class HSLFSlideShow extends POIDocument
 		//   05 00 00 00 0A 00 00 00 xx xx xx
 		//     (the contents of the document atom, not sure what it means yet)
 		//   (records then follow)
-	
+
 		// When parsing a document, look to see if you know about that type
-		//  of the current record. If you know it's a type that has children, 
+		//  of the current record. If you know it's a type that has children,
 		//  process the record's data area looking for more records
 		// If you know about the type and it doesn't have children, either do
 		//  something with the data (eg TextRun) or skip over it
@@ -237,19 +228,21 @@ public class HSLFSlideShow extends POIDocument
 
     private Record[] read(byte[] docstream, int usrOffset){
         ArrayList lst = new ArrayList();
+        HashMap offset2id = new HashMap();
         while (usrOffset != 0){
             UserEditAtom usr = (UserEditAtom) Record.buildRecordAtOffset(docstream, usrOffset);
-            lst.add(new Integer(usrOffset));
+            lst.add(Integer.valueOf(usrOffset));
             int psrOffset = usr.getPersistPointersOffset();
 
             PersistPtrHolder ptr = (PersistPtrHolder)Record.buildRecordAtOffset(docstream, psrOffset);
-            lst.add(new Integer(psrOffset));
+            lst.add(Integer.valueOf(psrOffset));
             Hashtable entries = ptr.getSlideLocationsLookup();
             for (Iterator it = entries.keySet().iterator(); it.hasNext(); ) {
                 Integer id = (Integer)it.next();
                 Integer offset = (Integer)entries.get(id);
 
                 lst.add(offset);
+                offset2id.put(offset, id);
             }
 
             usrOffset = usr.getLastUserEditAtomOffset();
@@ -261,26 +254,31 @@ public class HSLFSlideShow extends POIDocument
         Record[] rec = new Record[lst.size()];
         for (int i = 0; i < a.length; i++) {
             Integer offset = (Integer)a[i];
-            rec[i] = (Record)Record.buildRecordAtOffset(docstream, offset.intValue());
+            rec[i] = Record.buildRecordAtOffset(docstream, offset.intValue());
+            if(rec[i] instanceof PersistRecord) {
+                PersistRecord psr = (PersistRecord)rec[i];
+                Integer id = (Integer)offset2id.get(offset);
+                psr.setPersistId(id.intValue());
+            }
         }
 
         return rec;
     }
 
 	/**
-	 * Find the "Current User" stream, and load it 
+	 * Find the "Current User" stream, and load it
 	 */
 	private void readCurrentUserStream() {
 		try {
-			currentUser = new CurrentUserAtom(filesystem);
+			currentUser = new CurrentUserAtom(directory);
 		} catch(IOException ie) {
 			logger.log(POILogger.ERROR, "Error finding Current User Atom:\n" + ie);
 			currentUser = new CurrentUserAtom();
 		}
 	}
-	
+
 	/**
-	 * Find any other streams from the filesystem, and load them 
+	 * Find any other streams from the filesystem, and load them
 	 */
 	private void readOtherStreams() {
 		// Currently, there aren't any
@@ -290,22 +288,22 @@ public class HSLFSlideShow extends POIDocument
 	 * Find and read in pictures contained in this presentation
 	 */
 	private void readPictures() throws IOException {
+        _pictures = new ArrayList<PictureData>();
+
 		byte[] pictstream;
 
 		try {
-			DocumentEntry entry = (DocumentEntry)filesystem.getRoot().getEntry("Pictures");
+			DocumentEntry entry = (DocumentEntry)directory.getEntry("Pictures");
 			pictstream = new byte[entry.getSize()];
-			DocumentInputStream is = filesystem.createDocumentInputStream("Pictures");
+			DocumentInputStream is = directory.createDocumentInputStream("Pictures");
 			is.read(pictstream);
 		} catch (FileNotFoundException e){
-			// Silently catch exceptions if the presentation doesn't 
+			// Silently catch exceptions if the presentation doesn't
 			//  contain pictures - will use a null set instead
 			return;
 		}
 
-        List p = new ArrayList();
         int pos = 0;
-
 		// An empty picture record (length 0) will take up 8 bytes
         while (pos <= (pictstream.length-8)) {
             int offset = pos;
@@ -324,7 +322,7 @@ public class HSLFSlideShow extends POIDocument
 			// (0 is allowed, but odd, since we do wind on by the header each
 			//  time, so we won't get stuck)
 			if(imgsize < 0) {
-				throw new CorruptPowerPointFileException("The file contains a picture, at position " + p.size() + ", which has a negatively sized data length, so we can't trust any of the picture data");
+				throw new CorruptPowerPointFileException("The file contains a picture, at position " + _pictures.size() + ", which has a negatively sized data length, so we can't trust any of the picture data");
 			}
 
 			// If they type (including the bonus 0xF018) is 0, skip it
@@ -332,27 +330,24 @@ public class HSLFSlideShow extends POIDocument
 				logger.log(POILogger.ERROR, "Problem reading picture: Invalid image type 0, on picture with length " + imgsize + ".\nYou document will probably become corrupted if you save it!");
 				logger.log(POILogger.ERROR, "" + pos);
 			} else {
-	            // Copy the data, ready to pass to PictureData
-	            byte[] imgdata = new byte[imgsize];
-	            if(imgsize > 0) {
-	            	System.arraycopy(pictstream, pos, imgdata, 0, imgdata.length);
-	            }
-	            
 				// Build the PictureData object from the data
 				try {
 					PictureData pict = PictureData.create(type - 0xF018);
-					pict.setRawData(imgdata);
-					pict.setOffset(offset);
-					p.add(pict);
+
+                    // Copy the data, ready to pass to PictureData
+                    byte[] imgdata = new byte[imgsize];
+                    System.arraycopy(pictstream, pos, imgdata, 0, imgdata.length);
+                    pict.setRawData(imgdata);
+
+                    pict.setOffset(offset);
+					_pictures.add(pict);
 				} catch(IllegalArgumentException e) {
 					logger.log(POILogger.ERROR, "Problem reading picture: " + e + "\nYou document will probably become corrupted if you save it!");
 				}
 			}
-            
+
             pos += imgsize;
         }
-
-		_pictures = (PictureData[])p.toArray(new PictureData[p.size()]);
 	}
 
 
@@ -385,7 +380,7 @@ public class HSLFSlideShow extends POIDocument
 
         // The list of entries we've written out
         List writtenEntries = new ArrayList(1);
-        
+
         // Write out the Property Streams
         writeProperties(outFS, writtenEntries);
 
@@ -406,7 +401,7 @@ public class HSLFSlideShow extends POIDocument
                 int oldPos = pdr.getLastOnDiskOffset();
                 int newPos = baos.size();
                 pdr.setLastOnDiskOffset(newPos);
-                oldToNewPositions.put(new Integer(oldPos),new Integer(newPos));
+                oldToNewPositions.put(Integer.valueOf(oldPos),Integer.valueOf(newPos));
                 //System.out.println(oldPos + " -> " + newPos);
             }
 
@@ -443,7 +438,7 @@ public class HSLFSlideShow extends POIDocument
 
         // Update and write out the Current User atom
         int oldLastUserEditAtomPos = (int)currentUser.getCurrentEditOffset();
-        Integer newLastUserEditAtomPos = (Integer)oldToNewPositions.get(new Integer(oldLastUserEditAtomPos));
+        Integer newLastUserEditAtomPos = (Integer)oldToNewPositions.get(Integer.valueOf(oldLastUserEditAtomPos));
         if(newLastUserEditAtomPos == null) {
             throw new HSLFException("Couldn't find the new location of the UserEditAtom that used to be at " + oldLastUserEditAtomPos);
         }
@@ -451,19 +446,19 @@ public class HSLFSlideShow extends POIDocument
         currentUser.writeToFS(outFS);
         writtenEntries.add("Current User");
 
-	
+
         // Write any pictures, into another stream
-        if (_pictures != null) {
+        if (_pictures.size() > 0) {
             ByteArrayOutputStream pict = new ByteArrayOutputStream();
-            for (int i = 0; i < _pictures.length; i++ ) {
-                _pictures[i].write(pict);
+            for (PictureData p : _pictures) {
+                p.write(pict);
             }
             outFS.createDocument(
                 new ByteArrayInputStream(pict.toByteArray()), "Pictures"
             );
             writtenEntries.add("Pictures");
         }
-        
+
         // If requested, write out any other streams we spot
         if(preserveNodes) {
         	copyNodes(filesystem, outFS, writtenEntries);
@@ -500,23 +495,23 @@ public class HSLFSlideShow extends POIDocument
 		_records = r;
 		return addedAt;
 	}
-	
+
 	/**
-	 *  Add a new picture to this presentation.
+	 * Add a new picture to this presentation.
+     *
+     * @return offset of this picture in the Pictures stream
 	 */
-	public void addPicture(PictureData img) {
-		// Copy over the existing pictures, into an array one bigger
-		PictureData[] lst;
-		if(_pictures == null) {
-			lst = new PictureData[1];
-		} else {
-			lst = new PictureData[(_pictures.length+1)];
-			System.arraycopy(_pictures,0,lst,0,_pictures.length);
-		}
-		// Add in the new image
-		lst[lst.length - 1] = img;
-		_pictures = lst;
-	}
+	public int addPicture(PictureData img) {
+		int offset = 0;
+
+        if(_pictures.size() > 0){
+            PictureData prev = _pictures.get(_pictures.size() - 1);
+            offset = prev.getOffset() + prev.getRawData().length + 8;
+        }
+        img.setOffset(offset);
+        _pictures.add(img);
+        return offset;
+   }
 
 	/* ******************* fetching methods follow ********************* */
 
@@ -544,7 +539,7 @@ public class HSLFSlideShow extends POIDocument
 	 *  presentation doesn't contain pictures.
 	 */
 	public PictureData[] getPictures() {
-		return _pictures;
+		return _pictures.toArray(new PictureData[_pictures.size()]);
 	}
 
     /**
