@@ -20,6 +20,7 @@ package org.apache.poi.hslf.usermodel;
 import org.apache.poi.hslf.*;
 import org.apache.poi.hslf.blip.*;
 import org.apache.poi.hslf.model.*;
+import org.apache.poi.POIDataSamples;
 import junit.framework.TestCase;
 
 import java.io.*;
@@ -30,13 +31,10 @@ import java.util.Arrays;
  *
  * @author Yegor Kozlov
  */
-public class TestPictures extends TestCase{
+public final class TestPictures extends TestCase{
+    private static POIDataSamples slTests = POIDataSamples.getSlideShowInstance();
 
-    protected File cwd;
-
-    public void setUp() throws Exception {
-        cwd = new File(System.getProperty("HSLF.testdata.path"));
-    }
+    //protected File cwd;
 
     /**
      * Test read/write Macintosh PICT
@@ -45,8 +43,8 @@ public class TestPictures extends TestCase{
         SlideShow ppt = new SlideShow();
 
         Slide slide = ppt.createSlide();
-        File img = new File(cwd, "cow.pict");
-        int idx = ppt.addPicture(img, Picture.PICT);
+        byte[] src_bytes = slTests.readFile("cow.pict");
+        int idx = ppt.addPicture(src_bytes, Picture.PICT);
         Picture pict = new Picture(idx);
         assertEquals(idx, pict.getPictureIndex());
         slide.addShape(pict);
@@ -73,7 +71,6 @@ public class TestPictures extends TestCase{
         assertEquals(Picture.PICT, pictures[0].getType());
         assertTrue(pictures[0] instanceof PICT);
         //compare the content of the initial file with what is stored in the PictureData
-        byte[] src_bytes = read(img);
         byte[] ppt_bytes = pictures[0].getData();
         assertEquals(src_bytes.length, ppt_bytes.length);
         //in PICT the first 512 bytes are MAC specific and may not be preserved, ignore them
@@ -91,8 +88,8 @@ public class TestPictures extends TestCase{
         SlideShow ppt = new SlideShow();
 
         Slide slide = ppt.createSlide();
-        File img = new File(cwd, "santa.wmf");
-        int idx = ppt.addPicture(img, Picture.WMF);
+        byte[] src_bytes = slTests.readFile("santa.wmf");
+        int idx = ppt.addPicture(src_bytes, Picture.WMF);
         Picture pict = new Picture(idx);
         assertEquals(idx, pict.getPictureIndex());
         slide.addShape(pict);
@@ -119,7 +116,6 @@ public class TestPictures extends TestCase{
         assertEquals(Picture.WMF, pictures[0].getType());
         assertTrue(pictures[0] instanceof WMF);
         //compare the content of the initial file with what is stored in the PictureData
-        byte[] src_bytes = read(img);
         byte[] ppt_bytes = pictures[0].getData();
         assertEquals(src_bytes.length, ppt_bytes.length);
         //in WMF the first 22 bytes - is a metafile header
@@ -137,8 +133,9 @@ public class TestPictures extends TestCase{
         SlideShow ppt = new SlideShow();
 
         Slide slide = ppt.createSlide();
-        File img = new File(cwd, "wrench.emf");
-        int idx = ppt.addPicture(img, Picture.EMF);
+        byte[] src_bytes = slTests.readFile("wrench.emf");
+        int idx = ppt.addPicture(src_bytes, Picture.EMF);
+
         Picture pict = new Picture(idx);
         assertEquals(idx, pict.getPictureIndex());
         slide.addShape(pict);
@@ -165,7 +162,6 @@ public class TestPictures extends TestCase{
         assertEquals(Picture.EMF, pictures[0].getType());
         assertTrue(pictures[0] instanceof EMF);
         //compare the content of the initial file with what is stored in the PictureData
-        byte[] src_bytes = read(img);
         byte[] ppt_bytes = pictures[0].getData();
         assertTrue(Arrays.equals(src_bytes, ppt_bytes));
     }
@@ -177,8 +173,8 @@ public class TestPictures extends TestCase{
         SlideShow ppt = new SlideShow();
 
         Slide slide = ppt.createSlide();
-        File img = new File(cwd, "tomcat.png");
-        int idx = ppt.addPicture(img, Picture.PNG);
+        byte[] src_bytes = slTests.readFile("tomcat.png");
+        int idx = ppt.addPicture(src_bytes, Picture.PNG);
         Picture pict = new Picture(idx);
         assertEquals(idx, pict.getPictureIndex());
         slide.addShape(pict);
@@ -205,7 +201,6 @@ public class TestPictures extends TestCase{
         assertEquals(Picture.PNG, pictures[0].getType());
         assertTrue(pictures[0] instanceof PNG);
         //compare the content of the initial file with what is stored in the PictureData
-        byte[] src_bytes = read(img);
         byte[] ppt_bytes = pictures[0].getData();
         assertTrue(Arrays.equals(src_bytes, ppt_bytes));
     }
@@ -217,8 +212,9 @@ public class TestPictures extends TestCase{
         SlideShow ppt = new SlideShow();
 
         Slide slide = ppt.createSlide();
-        File img = new File(cwd, "clock.jpg");
-        int idx = ppt.addPicture(img, Picture.JPEG);
+        byte[] src_bytes = slTests.readFile("clock.jpg");
+        int idx = ppt.addPicture(src_bytes, Picture.JPEG);
+
         Picture pict = new Picture(idx);
         assertEquals(idx, pict.getPictureIndex());
         slide.addShape(pict);
@@ -245,7 +241,6 @@ public class TestPictures extends TestCase{
         assertEquals(Picture.JPEG, pictures[0].getType());
         assertTrue(pictures[0] instanceof JPEG);
         //compare the content of the initial file with what is stored in the PictureData
-        byte[] src_bytes = read(img);
         byte[] ppt_bytes = pictures[0].getData();
         assertTrue(Arrays.equals(src_bytes, ppt_bytes));
     }
@@ -257,13 +252,8 @@ public class TestPictures extends TestCase{
         SlideShow ppt = new SlideShow();
 
         Slide slide = ppt.createSlide();
-        File img = new File(cwd, "sci_cec.dib");
-        
-        // Check we can read the test DIB image
-        assertTrue(img.exists());
-        
-        // Add the image
-        int idx = ppt.addPicture(img, Picture.DIB);
+        byte[] src_bytes = slTests.readFile("sci_cec.dib");
+        int idx = ppt.addPicture(src_bytes, Picture.DIB);
         Picture pict = new Picture(idx);
         assertEquals(idx, pict.getPictureIndex());
         slide.addShape(pict);
@@ -290,22 +280,10 @@ public class TestPictures extends TestCase{
         assertEquals(Picture.DIB, pictures[0].getType());
         assertTrue(pictures[0] instanceof DIB);
         //compare the content of the initial file with what is stored in the PictureData
-        byte[] src_bytes = read(img);
         byte[] ppt_bytes = pictures[0].getData();
         assertTrue(Arrays.equals(src_bytes, ppt_bytes));
     }
 
-    /**
-     * Read file into a byte array
-     */
-    protected byte[] read(File f) throws IOException {
-        byte[] bytes = new byte[(int)f.length()];
-        FileInputStream is = new FileInputStream(f);
-        is.read(bytes);
-        is.close();
-        return bytes;
-    }
-
     /**
      * Read pictures in different formats from a reference slide show
      */
@@ -315,7 +293,7 @@ public class TestPictures extends TestCase{
         Picture pict;
         PictureData pdata;
 
-        SlideShow ppt = new SlideShow(new HSLFSlideShow(new File(cwd, "pictures.ppt").getPath()));
+        SlideShow ppt = new SlideShow(slTests.openResourceAsStream("pictures.ppt"));
         Slide[] slides = ppt.getSlides();
         PictureData[] pictures = ppt.getPictureData();
         assertEquals(5, pictures.length);
@@ -325,7 +303,7 @@ public class TestPictures extends TestCase{
         assertTrue(pdata instanceof JPEG);
         assertEquals(Picture.JPEG, pdata.getType());
         src_bytes = pdata.getData();
-        ppt_bytes = read(new File(cwd, "clock.jpg"));
+        ppt_bytes = slTests.readFile("clock.jpg");
         assertTrue(Arrays.equals(src_bytes, ppt_bytes));
 
         pict = (Picture)slides[1].getShapes()[0]; //the second slide contains PNG
@@ -333,7 +311,7 @@ public class TestPictures extends TestCase{
         assertTrue(pdata instanceof PNG);
         assertEquals(Picture.PNG, pdata.getType());
         src_bytes = pdata.getData();
-        ppt_bytes = read(new File(cwd, "tomcat.png"));
+        ppt_bytes = slTests.readFile("tomcat.png");
         assertTrue(Arrays.equals(src_bytes, ppt_bytes));
 
         pict = (Picture)slides[2].getShapes()[0]; //the third slide contains WMF
@@ -341,7 +319,7 @@ public class TestPictures extends TestCase{
         assertTrue(pdata instanceof WMF);
         assertEquals(Picture.WMF, pdata.getType());
         src_bytes = pdata.getData();
-        ppt_bytes = read(new File(cwd, "santa.wmf"));
+        ppt_bytes = slTests.readFile("santa.wmf");
         assertEquals(src_bytes.length, ppt_bytes.length);
         //ignore the first 22 bytes - it is a WMF metafile header
         b1 = new byte[src_bytes.length-22];
@@ -355,7 +333,7 @@ public class TestPictures extends TestCase{
         assertTrue(pdata instanceof PICT);
         assertEquals(Picture.PICT, pdata.getType());
         src_bytes = pdata.getData();
-        ppt_bytes = read(new File(cwd, "cow.pict"));
+        ppt_bytes = slTests.readFile("cow.pict");
         assertEquals(src_bytes.length, ppt_bytes.length);
         //ignore the first 512 bytes - it is a MAC specific crap
         b1 = new byte[src_bytes.length-512];
@@ -369,17 +347,17 @@ public class TestPictures extends TestCase{
         assertTrue(pdata instanceof EMF);
         assertEquals(Picture.EMF, pdata.getType());
         src_bytes = pdata.getData();
-        ppt_bytes = read(new File(cwd, "wrench.emf"));
+        ppt_bytes = slTests.readFile("wrench.emf");
         assertTrue(Arrays.equals(src_bytes, ppt_bytes));
 
     }
 
 	/**
-	 * Test that on a party corrupt powerpoint document, which has 
+	 * Test that on a party corrupt powerpoint document, which has
 	 *  crazy pictures of type 0, we do our best.
 	 */
 	public void testZeroPictureType() throws Exception {
-		HSLFSlideShow hslf = new HSLFSlideShow(new File(cwd, "PictureTypeZero.ppt").getPath());
+		HSLFSlideShow hslf = new HSLFSlideShow(slTests.openResourceAsStream("PictureTypeZero.ppt"));
 
 		// Should still have 2 real pictures
 		assertEquals(2, hslf.getPictures().length);
@@ -393,48 +371,91 @@ public class TestPictures extends TestCase{
         PictureData[] pictures = ppt.getPictureData();
         assertEquals(12, slides.length);
         assertEquals(2, pictures.length);
-        
+
 		Picture pict;
 		PictureData pdata;
-		
+
         pict = (Picture)slides[0].getShapes()[1]; // 2nd object on 1st slide
         pdata = pict.getPictureData();
         assertTrue(pdata instanceof WMF);
         assertEquals(Picture.WMF, pdata.getType());
-		
+
         pict = (Picture)slides[0].getShapes()[2]; // 3rd object on 1st slide
         pdata = pict.getPictureData();
         assertTrue(pdata instanceof WMF);
         assertEquals(Picture.WMF, pdata.getType());
 	}
-	
+
 	public void testZeroPictureLength() throws Exception {
-		HSLFSlideShow hslf = new HSLFSlideShow(new File(cwd, "PictureLengthZero.ppt").getPath());
+		HSLFSlideShow hslf = new HSLFSlideShow(slTests.openResourceAsStream("PictureLengthZero.ppt"));
 
 		// Should still have 2 real pictures
 		assertEquals(2, hslf.getPictures().length);
 		// Both are real pictures, both WMF
 		assertEquals(Picture.WMF, hslf.getPictures()[0].getType());
 		assertEquals(Picture.WMF, hslf.getPictures()[1].getType());
-		
+
 		// Now test what happens when we use the SlideShow interface
 		SlideShow ppt = new SlideShow(hslf);
         Slide[] slides = ppt.getSlides();
         PictureData[] pictures = ppt.getPictureData();
         assertEquals(27, slides.length);
         assertEquals(2, pictures.length);
-        
+
 		Picture pict;
 		PictureData pdata;
-		
+
         pict = (Picture)slides[6].getShapes()[13];
         pdata = pict.getPictureData();
         assertTrue(pdata instanceof WMF);
         assertEquals(Picture.WMF, pdata.getType());
-		
+
         pict = (Picture)slides[7].getShapes()[13];
         pdata = pict.getPictureData();
         assertTrue(pdata instanceof WMF);
         assertEquals(Picture.WMF, pdata.getType());
-	}
+
+        //add a new picture, it should be correctly appended to the Pictures stream
+        ByteArrayOutputStream out = new ByteArrayOutputStream();
+        for(PictureData p : pictures) p.write(out);
+        out.close();
+
+        int streamSize = out.size();
+
+        PictureData data = PictureData.create(Picture.JPEG);
+        data.setData(new byte[100]);
+        int offset = hslf.addPicture(data);
+        assertEquals(streamSize, offset);
+        assertEquals(3, ppt.getPictureData().length);
+
+    }
+
+    public void testGetPictureName() throws Exception {
+        SlideShow ppt = new SlideShow(slTests.openResourceAsStream("ppt_with_png.ppt"));
+        Slide slide = ppt.getSlides()[0];
+
+        Picture p = (Picture)slide.getShapes()[0]; //the first slide contains JPEG
+        assertEquals("test", p.getPictureName());
+    }
+
+    public void testSetPictureName() throws Exception {
+        SlideShow ppt = new SlideShow();
+
+        Slide slide = ppt.createSlide();
+        byte[] img = slTests.readFile("tomcat.png");
+        int idx = ppt.addPicture(img, Picture.PNG);
+        Picture pict = new Picture(idx);
+        pict.setPictureName("tomcat.png");
+        slide.addShape(pict);
+
+        //serialize and read again
+        ByteArrayOutputStream out = new ByteArrayOutputStream();
+        ppt.write(out);
+        out.close();
+
+        ppt = new SlideShow(new ByteArrayInputStream(out.toByteArray()));
+
+        Picture p = (Picture)ppt.getSlides()[0].getShapes()[0];
+        assertEquals("tomcat.png", p.getPictureName());
+    }
 }
