@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -15,17 +14,15 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
+
 package org.apache.poi.ddf;
 
 import junit.framework.TestCase;
 import org.apache.poi.util.HexDump;
 import org.apache.poi.util.HexRead;
 
-public class TestEscherDgRecord extends TestCase
-{
-    public void testSerialize() throws Exception
-    {
+public final class TestEscherDgRecord extends TestCase {
+    public void testSerialize() {
         EscherDgRecord r = createRecord();
 
         byte[] data = new byte[16];
@@ -35,12 +32,11 @@ public class TestEscherDgRecord extends TestCase
                 "08, F0, " +
                 "08, 00, 00, 00, " +
                 "02, 00, 00, 00, " +     // num shapes in drawing
-                "01, 04, 00, 00, ]",     // The last MSOSPID given to an SP in this DG
+                "01, 04, 00, 00]",     // The last MSOSPID given to an SP in this DG
                 HexDump.toHex( data ) );
     }
 
-    public void testFillFields() throws Exception
-    {
+    public void testFillFields() {
         String hexData = "10 00 " +
                 "08 F0 " +
                 "08 00 00 00 " +
@@ -55,19 +51,16 @@ public class TestEscherDgRecord extends TestCase
         assertEquals( 1025, r.getLastMSOSPID() );
     }
 
-    public void testToString() throws Exception
-    {
-        String nl = System.getProperty("line.separator");
-
-        String expected = "org.apache.poi.ddf.EscherDgRecord:" + nl +
-                "  RecordId: 0xF008" + nl +
-                "  Options: 0x0010" + nl +
-                "  NumShapes: 2" + nl +
-                "  LastMSOSPID: 1025" + nl;
+    public void testToString() {
+        String expected = "org.apache.poi.ddf.EscherDgRecord:" + '\n' +
+                "  RecordId: 0xF008" + '\n' +
+                "  Options: 0x0010" + '\n' +
+                "  NumShapes: 2" + '\n' +
+                "  LastMSOSPID: 1025" + '\n';
         assertEquals( expected, createRecord().toString() );
     }
 
-    private EscherDgRecord createRecord()
+    private static EscherDgRecord createRecord()
     {
         EscherDgRecord r = new EscherDgRecord();
         r.setOptions( (short) 0x0010 );
@@ -76,5 +69,4 @@ public class TestEscherDgRecord extends TestCase
         r.setLastMSOSPID(1025);
         return r;
     }
-
 }
