@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -15,29 +14,23 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
+
 package org.apache.poi.ddf;
 
 import junit.framework.TestCase;
 import org.apache.poi.util.HexRead;
 import org.apache.poi.util.HexDump;
 
-import java.io.IOException;
 import java.util.Arrays;
-import java.util.List;
-import java.util.Iterator;
 
-public class TestEscherOptRecord extends TestCase
-{
+public final class TestEscherOptRecord extends TestCase {
 
-    public void testFillFields() throws Exception
-    {
+    public void testFillFields() {
         checkFillFieldsSimple();
         checkFillFieldsComplex();
     }
 
-    private void checkFillFieldsComplex() throws IOException
-    {
+    private void checkFillFieldsComplex() {
         String dataStr = "33 00 " +
                 "0B F0 " +
                 "14 00 00 00 " +
@@ -60,9 +53,7 @@ public class TestEscherOptRecord extends TestCase
 
     }
 
-    private void checkFillFieldsSimple()
-            throws IOException
-    {
+    private void checkFillFieldsSimple() {
         String dataStr = "33 00 " + // options
                         "0B F0 " + // recordid
                         "12 00 00 00 " + // remaining bytes
@@ -83,8 +74,7 @@ public class TestEscherOptRecord extends TestCase
         assertEquals( prop3, r.getEscherProperty( 2 ) );
     }
 
-    public void testSerialize() throws Exception
-    {
+    public void testSerialize() {
         checkSerializeSimple();
         checkSerializeComplex();
     }
@@ -111,7 +101,7 @@ public class TestEscherOptRecord extends TestCase
                 "BF, 00, 01, 00, 00, 00, " +
                 "01, 80, 02, 00, 00, 00, " +
                 "BF, 00, 01, 00, 00, 00, " +
-                "01, 02, ]";
+                "01, 02]";
         assertEquals( dataStr, HexDump.toHex(data) );
 
     }
@@ -135,13 +125,12 @@ public class TestEscherOptRecord extends TestCase
                 "12, 00, 00, 00, " +
                 "BF, 00, 01, 00, 00, 00, " +
                 "81, 01, 09, 00, 00, 08, " +
-                "C0, 01, 40, 00, 00, 08, ]";
+                "C0, 01, 40, 00, 00, 08]";
         assertEquals( dataStr, HexDump.toHex(data) );
         assertEquals( 26, bytesWritten );
     }
 
-    public void testToString() throws Exception
-    {
+    public void testToString() {
         String nl = System.getProperty("line.separator");
         EscherOptRecord r = new EscherOptRecord();
         r.setOptions((short)0x000F);
@@ -159,93 +148,93 @@ public class TestEscherOptRecord extends TestCase
     }
 
     /**
-     * Test serialisation of a particually complex example 
+     * Test serialisation of a particually complex example
      * This test is currently broken!
      */
-    public void testComplexSerialise() throws Exception {
-    	byte[] data = new byte[] {
-    		0x53, 0x01, 0x0B, 0xF0-256, 0x9C-256, 0x01, 0x00, 0x00, 
+    public void testComplexSerialise() {
+    	byte[] data = {
+    		0x53, 0x01, 0x0B, 0xF0-256, 0x9C-256, 0x01, 0x00, 0x00,
     		// Simple data follows
     		0x42, 0x01,	0x49, 0x00, 0x00, 0x00,          // SP @ 8
     		0x43, 0x01, 0x85-256, 0x00, 0x00, 0x00,      // SP @ 14
     		0x44, 0x01, 0x04, 0x00, 0x00, 0x00,          // SP @ 20
     		0x45, 0xC1-256, 0x88-256, 0x00, 0x00, 0x00,  // SP @ 26
     		0x46, 0xC1-256, 0x90-256, 0x00, 0x00, 0x00,  // SP @ 32
-    		0x7F, 0x01, 0x01, 0x00, 0x01, 0x00, 
-    		0x80-256, 0x01, 0x00, 0x00, 0x00, 0x00, 
-    		0x81-256, 0x01, 0x02, 0x00, 0x00, 0x08, 
-    		0xBF-256, 0x01,	0x10, 0x00, 0x10, 0x00, 
-    		0xC0-256, 0x01, 0x01, 0x00, 0x00, 0x08,      // SP 10 
+    		0x7F, 0x01, 0x01, 0x00, 0x01, 0x00,
+    		0x80-256, 0x01, 0x00, 0x00, 0x00, 0x00,
+    		0x81-256, 0x01, 0x02, 0x00, 0x00, 0x08,
+    		0xBF-256, 0x01,	0x10, 0x00, 0x10, 0x00,
+    		0xC0-256, 0x01, 0x01, 0x00, 0x00, 0x08,      // SP 10
     		0xC1-256, 0x01, 0x00, 0x00, 0x01, 0x00,
-    		0xC4-256, 0x01, 0x00, 0x00, 0x00, 0x00, 
-    		0xCB-256, 0x01, 0x38, 0x63, 0x00, 0x00, 
-    		0xCD-256, 0x01, 0x00, 0x00,	0x00, 0x00, 
+    		0xC4-256, 0x01, 0x00, 0x00, 0x00, 0x00,
+    		0xCB-256, 0x01, 0x38, 0x63, 0x00, 0x00,
+    		0xCD-256, 0x01, 0x00, 0x00,	0x00, 0x00,
     		0xCE-256, 0x01, 0x00, 0x00, 0x00, 0x00,      // SP 15
-    		0xD0-256, 0x01, 0x00, 0x00, 0x00, 0x00, 
-    		0xD1-256, 0x01, 0x00, 0x00, 0x00, 0x00, 
-    		0xD7-256, 0x01, 0x00, 0x00, 0x00, 0x00, 
+    		0xD0-256, 0x01, 0x00, 0x00, 0x00, 0x00,
+    		0xD1-256, 0x01, 0x00, 0x00, 0x00, 0x00,
+    		0xD7-256, 0x01, 0x00, 0x00, 0x00, 0x00,
     		0xFF-256, 0x01, 0x18, 0x00, 0x18, 0x00,
-    		0x01, 0x02, 0x02, 0x00, 0x00, 0x08, 
+    		0x01, 0x02, 0x02, 0x00, 0x00, 0x08,
     		0x3F, 0x02, 0x00, 0x00,	0x02, 0x00,          // SP 21
-    		
+
     		// Complex data follows
-    		
+
     		// Complex data for Array #325
     		// Array header
-    		0x22, 0x00, 0x22, 0x00, 0xF0-256, 0xFF-256, 
+    		0x22, 0x00, 0x22, 0x00, 0xF0-256, 0xFF-256,
     		// Array data
-    		0x18, 0x00, 0x28, 0x00, 0x04, 0x00, 0x34, 
+    		0x18, 0x00, 0x28, 0x00, 0x04, 0x00, 0x34,
     		0x00, 0x04, 0x00, 0x28, 0x00, 0x04, 0x00,
-    		0x1C, 0x00, 0x04, 0x00, 0x10, 0x00, 0x04, 0x00, 0x04, 0x00, 0x10, 
+    		0x1C, 0x00, 0x04, 0x00, 0x10, 0x00, 0x04, 0x00, 0x04, 0x00, 0x10,
     		0x00, 0x00, 0x00, 0x1C, 0x00,
-    		0x04, 0x00, 0x28, 0x00, 0x10, 0x00, 0x34, 0x00, 0x18, 0x00, 0x3C, 
+    		0x04, 0x00, 0x28, 0x00, 0x10, 0x00, 0x34, 0x00, 0x18, 0x00, 0x3C,
     		0x00, 0x24, 0x00, 0x44, 0x00,
-    		0x30, 0x00, 0x48, 0x00, 0x3C, 0x00, 0x44, 0x00, 0x48, 0x00, 0x3C, 
+    		0x30, 0x00, 0x48, 0x00, 0x3C, 0x00, 0x44, 0x00, 0x48, 0x00, 0x3C,
     		0x00, 0x54, 0x00, 0x38, 0x00,
-    		0x60, 0x00, 0x2C, 0x00, 0x70, 0x00, 0x20, 0x00, 0x78, 0x00, 
+    		0x60, 0x00, 0x2C, 0x00, 0x70, 0x00, 0x20, 0x00, 0x78, 0x00,
     		0x14, 0x00, 0x80-256, 0x00, 0x08, 0x00,
-    		0x84-256, 0x00, 0x04, 0x00, 0x78, 0x00, 0x04, 0x00, 0x6C, 0x00, 
+    		0x84-256, 0x00, 0x04, 0x00, 0x78, 0x00, 0x04, 0x00, 0x6C, 0x00,
     		0x04, 0x00, 0x60, 0x00, 0x04, 0x00,
-    		0x54, 0x00, 0x08, 0x00, 0x48, 0x00, 0x0C, 0x00, 0x3C, 0x00, 0x0C, 
+    		0x54, 0x00, 0x08, 0x00, 0x48, 0x00, 0x0C, 0x00, 0x3C, 0x00, 0x0C,
     		0x00, 0x30, 0x00, 0x08, 0x00,
-    		0x3C, 0x00, 0x08, 0x00, 0x48, 0x00, 0x08, 0x00, 0x54, 0x00, 0x00, 
+    		0x3C, 0x00, 0x08, 0x00, 0x48, 0x00, 0x08, 0x00, 0x54, 0x00, 0x00,
     		0x00, 0x48, 0x00, 0x00, 0x00,
     		0x3C, 0x00, 0x00, 0x00, 0x30, 0x00, 0x04, 0x00, 0x24, 0x00,
     		// Complex data for Array #326
     		// Array header
-    		0x45, 0x00, 0x48, 0x00, 0x02, 0x00, 
+    		0x45, 0x00, 0x48, 0x00, 0x02, 0x00,
     		// Array data
-    		0x00, 0x40, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 
+    		0x00, 0x40, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00,
     		0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256,
-    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 
+    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00,
     		0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256,
-    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 
+    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00,
     		0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256,
-    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 
+    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00,
     		0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256,
-    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 
+    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00,
     		0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256,
-    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 
+    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00,
     		0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256,
-    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 
+    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00,
     		0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256,
-    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 
+    		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00,
     		0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256,
     		0x01, 0x00, 0x00, 0xB0-256, 0x01, 0x00, 0x00, 0xB0-256, 0x00, 0x80-256
     	};
-    	
+
     	// Create the record
         EscherOptRecord r = new EscherOptRecord();
         int filled = r.fillFields( data, new DefaultEscherRecordFactory() );
-        
+
         // Check it's the right length
         assertEquals(data.length, filled);
         assertEquals(data.length, r.getRecordSize());
-        
+
         // Serialise it
         byte[] dest = new byte[data.length];
         int written = r.serialize(0, dest);
-        
+
         // Check it serialised it back to the same data
         assertEquals(data.length, written);
         for(int i=0; i<data.length; i++) {
@@ -263,7 +252,7 @@ public class TestEscherOptRecord extends TestCase
      *
      * See Bug 41946 for details.
      */
-    public void test41946() throws IOException {
+    public void test41946() {
         String dataStr1 =
                 "03 08 0B F0 00 03 00 00 81 00 30 65 01 00 82 00 98 B2 00 00 83 00 30 65 01 " +
                 "00 84 00 98 B2 00 00 85 00 00 00 00 00 87 00 01 00 00 00 88 00 00 00 00 00 " +
@@ -315,7 +304,7 @@ public class TestEscherOptRecord extends TestCase
      * Test that EscherOptRecord can properly read/write array properties
      * with empty complex part.
      */
-    public void testEmptyArrayProperty() throws IOException {
+    public void testEmptyArrayProperty() {
         EscherOptRecord r = new EscherOptRecord();
         EscherArrayProperty p = new EscherArrayProperty((short)(EscherProperties.FILL__SHADECOLORS + 0x8000), new byte[0] );
         assertEquals(0, p.getNumberOfElementsInArray());
