@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -15,17 +14,15 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
+
 package org.apache.poi.ddf;
 
 import junit.framework.TestCase;
 import org.apache.poi.util.HexDump;
 import org.apache.poi.util.HexRead;
 
-public class TestEscherSplitMenuColorsRecord extends TestCase
-{
-    public void testSerialize() throws Exception
-    {
+public final class TestEscherSplitMenuColorsRecord extends TestCase {
+    public void testSerialize() {
         EscherSplitMenuColorsRecord r = createRecord();
 
         byte[] data = new byte[24];
@@ -37,12 +34,11 @@ public class TestEscherSplitMenuColorsRecord extends TestCase
                 "02, 04, 00, 00, " +
                 "02, 00, 00, 00, " +
                 "02, 00, 00, 00, " +
-                "01, 00, 00, 00, ]",
+                "01, 00, 00, 00]",
                 HexDump.toHex( data ) );
     }
 
-    public void testFillFields() throws Exception
-    {
+    public void testFillFields() {
         String hexData = "40 00 " +
                 "1E F1 " +
                 "10 00 00 00 " +
@@ -61,22 +57,19 @@ public class TestEscherSplitMenuColorsRecord extends TestCase
         assertEquals( 0x01, r.getColor4() );
     }
 
-    public void testToString() throws Exception
-    {
-        String nl = System.getProperty("line.separator");
-
-        String expected = "org.apache.poi.ddf.EscherSplitMenuColorsRecord:" + nl +
-                "  RecordId: 0xF11E" + nl +
-                "  Options: 0x0040" + nl +
-                "  Color1: 0x00000402" + nl +
-                "  Color2: 0x00000002" + nl +
-                "  Color3: 0x00000002" + nl +
-                "  Color4: 0x00000001" + nl +
+    public void testToString() {
+        String expected = "org.apache.poi.ddf.EscherSplitMenuColorsRecord:" + '\n' +
+                "  RecordId: 0xF11E" + '\n' +
+                "  Options: 0x0040" + '\n' +
+                "  Color1: 0x00000402" + '\n' +
+                "  Color2: 0x00000002" + '\n' +
+                "  Color3: 0x00000002" + '\n' +
+                "  Color4: 0x00000001" + '\n' +
                 "";
         assertEquals( expected, createRecord().toString() );
     }
 
-    private EscherSplitMenuColorsRecord createRecord()
+    private static EscherSplitMenuColorsRecord createRecord()
     {
         EscherSplitMenuColorsRecord r = new EscherSplitMenuColorsRecord();
         r.setOptions( (short) 0x0040 );
@@ -87,5 +80,4 @@ public class TestEscherSplitMenuColorsRecord extends TestCase
         r.setColor4( 0x1 );
         return r;
     }
-
 }
