@@ -14,13 +14,11 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
 
 package org.apache.poi.hpsf.basic;
 
 import java.io.ByteArrayInputStream;
 import java.io.File;
-import java.io.FileFilter;
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
@@ -39,21 +37,17 @@ import org.apache.poi.hpsf.PropertySetFactory;
 import org.apache.poi.hpsf.Section;
 import org.apache.poi.hpsf.SummaryInformation;
 import org.apache.poi.hpsf.wellknown.SectionIDMap;
-
-
+import org.apache.poi.POIDataSamples;
 
 /**
  * <p>Tests the basic HPSF functionality.</p>
  *
  * @author Rainer Klute (klute@rainer-klute.de)
- * @since 2002-07-20
- * @version $Id: TestBasic.java 489730 2006-12-22 19:18:16Z bayard $
  */
-public class TestBasic extends TestCase
-{
+public final class TestBasic extends TestCase {
 
-    static final String POI_FS = "TestGermanWord90.doc";
-    static final String[] POI_FILES = new String[]
+    private static final String POI_FS = "TestGermanWord90.doc";
+    private static final String[] POI_FILES = new String[]
         {
             "\005SummaryInformation",
             "\005DocumentSummaryInformation",
@@ -61,55 +55,39 @@ public class TestBasic extends TestCase
             "\001CompObj",
             "1Table"
         };
-    static final int BYTE_ORDER = 0xfffe;
-    static final int FORMAT     = 0x0000;
-    static final int OS_VERSION = 0x00020A04;
-    static final byte[] CLASS_ID =
+    private static final int BYTE_ORDER = 0xfffe;
+    private static final int FORMAT     = 0x0000;
+    private static final int OS_VERSION = 0x00020A04;
+    private static final byte[] CLASS_ID =
         {
             (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
             (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
             (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00,
             (byte) 0x00, (byte) 0x00, (byte) 0x00, (byte) 0x00
         };
-    static final int[] SECTION_COUNT =
+    private static final int[] SECTION_COUNT =
         {1, 2};
-    static final boolean[] IS_SUMMARY_INFORMATION =
+    private static final boolean[] IS_SUMMARY_INFORMATION =
         {true, false};
-    static final boolean[] IS_DOCUMENT_SUMMARY_INFORMATION =
-        {false, true};            
-
-    POIFile[] poiFiles;
-
-
-
-    /**
-     * <p>Test case constructor.</p>
-     * 
-     * @param name The test case's name.
-     */
-    public TestBasic(final String name)
-    {
-        super(name);
-    }
+    private static final boolean[] IS_DOCUMENT_SUMMARY_INFORMATION =
+        {false, true};
 
+    private POIFile[] poiFiles;
 
 
     /**
      * <p>Read a the test file from the "data" directory.</p>
-     * 
+     *
      * @exception FileNotFoundException if the file to be read does not exist.
      * @exception IOException if any other I/O exception occurs.
      */
-    public void setUp() throws FileNotFoundException, IOException
+    public void setUp() throws IOException
     {
-        final File dataDir =
-            new File(System.getProperty("HPSF.testdata.path"));
-        final File data = new File(dataDir, POI_FS);
+        POIDataSamples samples = POIDataSamples.getHPSFInstance();
+        final File data = samples.getFile(POI_FS);
         poiFiles = Util.readPOIFiles(data);
     }
 
-
-
     /**
      * <p>Checks the names of the files in the POI filesystem. They
      * are expected to be in a certain order.</p>
@@ -121,8 +99,6 @@ public class TestBasic extends TestCase
             Assert.assertEquals(poiFiles[i].getName(), expected[i]);
     }
 
-
-
     /**
      * <p>Tests whether property sets can be created from the POI
      * files in the POI file system. This test case expects the first
@@ -131,9 +107,9 @@ public class TestBasic extends TestCase
      * property sets. In the latter cases a {@link
      * NoPropertySetStreamException} will be thrown when trying to
      * create a {@link PropertySet}.</p>
-     * 
+     *
      * @exception IOException if an I/O exception occurs.
-     * 
+     *
      * @exception UnsupportedEncodingException if a character encoding is not
      * supported.
      */
@@ -169,13 +145,11 @@ public class TestBasic extends TestCase
         }
     }
 
-
-
     /**
      * <p>Tests the {@link PropertySet} methods. The test file has two
      * property sets: the first one is a {@link SummaryInformation},
      * the second one is a {@link DocumentSummaryInformation}.</p>
-     * 
+     *
      * @exception IOException if an I/O exception occurs
      * @exception HPSFException if any HPSF exception occurs
      */
@@ -200,13 +174,11 @@ public class TestBasic extends TestCase
         }
     }
 
-
-
     /**
      * <p>Tests the {@link Section} methods. The test file has two
      * property sets: the first one is a {@link SummaryInformation},
      * the second one is a {@link DocumentSummaryInformation}.</p>
-     * 
+     *
      * @exception IOException if an I/O exception occurs
      * @exception HPSFException if any HPSF exception occurs
      */
@@ -224,61 +196,4 @@ public class TestBasic extends TestCase
         Assert.assertEquals("Titel", s.getProperty(2));
         Assert.assertEquals(1748, s.getSize());
     }
-
-
-
-    /**
-     * <p>This test methods reads all property set streams from all POI
-     * filesystems in the "data" directory.</p>
-     */
-    public void testReadAllFiles()
-    {
-        final File dataDir =
-            new File(System.getProperty("HPSF.testdata.path"));
-        final File[] fileList = dataDir.listFiles(new FileFilter()
-            {
-                public boolean accept(final File f)
-                {
-                    return f.isFile();
-                }
-            });
-        try
-        {
-            for (int i = 0; i < fileList.length; i++)
-            {
-                File f = fileList[i];
-                /* Read the POI filesystem's property set streams: */
-                final POIFile[] psf1 = Util.readPropertySets(f);
-
-                for (int j = 0; j < psf1.length; j++)
-                {
-                    final InputStream in =
-                        new ByteArrayInputStream(psf1[j].getBytes());
-                    PropertySetFactory.create(in);
-                }
-            }
-        }
-        catch (Throwable t)
-        {
-            final String s = org.apache.poi.hpsf.Util.toString(t);
-            fail(s);
-        }
-    }
-
-
-
-    /**
-     * <p>Runs the test cases stand-alone.</p>
-     * 
-     * @param args Command-line arguments (ignored)
-     * 
-     * @exception Throwable if any sort of exception or error occurs
-     */
-    public static void main(final String[] args) throws Throwable
-    {
-        System.setProperty("HPSF.testdata.path",
-                           "./src/testcases/org/apache/poi/hpsf/data");
-        junit.textui.TestRunner.run(TestBasic.class);
-    }
-
 }
