@@ -53,34 +53,19 @@ import org.apache.poi.poifs.filesystem.DirectoryEntry;
 import org.apache.poi.poifs.filesystem.DocumentEntry;
 import org.apache.poi.poifs.filesystem.DocumentInputStream;
 import org.apache.poi.poifs.filesystem.POIFSFileSystem;
-
-
+import org.apache.poi.POIDataSamples;
 
 /**
  * <p>Tests HPSF's high-level writing functionality for the well-known property
  * set "SummaryInformation" and "DocumentSummaryInformation".</p>
- * 
+ *
  * @author Rainer Klute
  *     <a href="mailto:klute@rainer-klute.de">klute@rainer-klute.de</a>
- * @since 2006-02-01
- * @version $Id: TestWriteWellKnown.java 489730 2006-12-22 19:18:16Z bayard $
  */
-public class TestWriteWellKnown extends TestCase
-{
+public class TestWriteWellKnown extends TestCase {
 
     private static final String POI_FS = "TestWriteWellKnown.doc";
 
-    /**
-     * <p>Constructor</p>
-     * 
-     * @param name the test case's name
-     */
-    public TestWriteWellKnown(final String name)
-    {
-        super(name);
-    }
-
-
 
     /**
      * @see TestCase#setUp()
@@ -94,23 +79,18 @@ public class TestWriteWellKnown extends TestCase
 
     /**
      * <p>This test method checks whether DocumentSummary information streams
-     * can be read. This is done by opening all "Test*" files in the directrory
-     * pointed to by the "HPSF.testdata.path" system property, trying to extract
+     * can be read. This is done by opening all "Test*" files in the 'poifs' directrory
+     * pointed to by the "POI.testdata.path" system property, trying to extract
      * the document summary information stream in the root directory and calling
      * its get... methods.</p>
-     * @throws IOException 
-     * @throws FileNotFoundException 
-     * @throws MarkUnsupportedException 
-     * @throws NoPropertySetStreamException 
-     * @throws UnexpectedPropertySetTypeException 
      */
     public void testReadDocumentSummaryInformation()
             throws FileNotFoundException, IOException,
             NoPropertySetStreamException, MarkUnsupportedException,
             UnexpectedPropertySetTypeException
     {
-        final String dataDirName = System.getProperty("HPSF.testdata.path");
-        final File dataDir = new File(dataDirName);
+        POIDataSamples _samples = POIDataSamples.getHPSFInstance();
+        final File dataDir = _samples.getFile("");
         final File[] docs = dataDir.listFiles(new FileFilter()
         {
             public boolean accept(final File file)
@@ -120,7 +100,6 @@ public class TestWriteWellKnown extends TestCase
         for (int i = 0; i < docs.length; i++)
         {
             final File doc = docs[i];
-            System.out.println("Reading file " + doc);
 
             /* Read a test document <em>doc</em> into a POI filesystem. */
             final POIFSFileSystem poifs = new POIFSFileSystem(new FileInputStream(doc));
@@ -147,7 +126,7 @@ public class TestWriteWellKnown extends TestCase
                 final DocumentInputStream dis = new DocumentInputStream(dsiEntry);
                 final PropertySet ps = new PropertySet(dis);
                 final DocumentSummaryInformation dsi = new DocumentSummaryInformation(ps);
-                
+
                 /* Execute the get... methods. */
                 dsi.getByteCount();
                 dsi.getByteOrder();
@@ -175,43 +154,43 @@ public class TestWriteWellKnown extends TestCase
      * <p>This test method test the writing of properties in the well-known
      * property set streams "SummaryInformation" and
      * "DocumentSummaryInformation" by performing the following steps:</p>
-     * 
+     *
      * <ol>
-     * 
+     *
      * <li><p>Read a test document <em>doc1</em> into a POI filesystem.</p></li>
-     * 
+     *
      * <li><p>Read the summary information stream and the document summary
      * information stream from the POI filesystem.</p></li>
-     * 
+     *
      * <li><p>Write all properties supported by HPSF to the summary
      * information (e.g. author, edit date, application name) and to the
      * document summary information (e.g. company, manager).</p></li>
-     * 
+     *
      * <li><p>Write the summary information stream and the document summary
      * information stream to the POI filesystem.</p></li>
-     * 
+     *
      * <li><p>Write the POI filesystem to a (temporary) file <em>doc2</em>
      * and close the latter.</p></li>
-     * 
+     *
      * <li><p>Open <em>doc2</em> for reading and check summary information
      * and document summary information. All properties written before must be
      * found in the property streams of <em>doc2</em> and have the correct
      * values.</p></li>
-     * 
+     *
      * <li><p>Remove all properties supported by HPSF from the summary
      * information (e.g. author, edit date, application name) and from the
      * document summary information (e.g. company, manager).</p></li>
-     * 
+     *
      * <li><p>Write the summary information stream and the document summary
      * information stream to the POI filesystem.</p></li>
-     * 
+     *
      * <li><p>Write the POI filesystem to a (temporary) file <em>doc3</em>
      * and close the latter.</p></li>
-     * 
+     *
      * <li><p>Open <em>doc3</em> for reading and check summary information
      * and document summary information. All properties removed before must not
      * be found in the property streams of <em>doc3</em>.</p></li> </ol>
-     * 
+     *
      * @throws IOException if some I/O error occurred.
      * @throws MarkUnsupportedException
      * @throws NoPropertySetStreamException
@@ -222,20 +201,20 @@ public class TestWriteWellKnown extends TestCase
             NoPropertySetStreamException, MarkUnsupportedException,
             UnexpectedPropertySetTypeException, WritingNotSupportedException
     {
-        final String dataDirName = System.getProperty("HPSF.testdata.path");
-        final File dataDir = new File(dataDirName);
+        POIDataSamples _samples = POIDataSamples.getHPSFInstance();
+        final File dataDir = _samples.getFile("");
         final File doc1 = new File(dataDir, POI_FS);
-    
+
         /* Read a test document <em>doc1</em> into a POI filesystem. */
         POIFSFileSystem poifs = new POIFSFileSystem(new FileInputStream(doc1));
         DirectoryEntry dir = poifs.getRoot();
         DocumentEntry siEntry = (DocumentEntry) dir.getEntry(SummaryInformation.DEFAULT_STREAM_NAME);
         DocumentEntry dsiEntry = (DocumentEntry) dir.getEntry(DocumentSummaryInformation.DEFAULT_STREAM_NAME);
-    
+
         /*
          * Read the summary information stream and the document summary
          * information stream from the POI filesystem.
-         * 
+         *
          * Please note that the result consists of SummaryInformation and
          * DocumentSummaryInformation instances which are in memory only. To
          * make them permanent they have to be written to a POI filesystem
@@ -248,7 +227,7 @@ public class TestWriteWellKnown extends TestCase
         dis = new DocumentInputStream(dsiEntry);
         ps = new PropertySet(dis);
         DocumentSummaryInformation dsi = new DocumentSummaryInformation(ps);
-    
+
         /*
          * Write all properties supported by HPSF to the summary information
          * (e.g. author, edit date, application name) and to the document
@@ -261,7 +240,7 @@ public class TestWriteWellKnown extends TestCase
         final long time2 = cal.getTimeInMillis();
         cal.set(2002, 8, 8, 8, 8, 8);
         final long time3 = cal.getTimeInMillis();
-    
+
         int nr = 4711;
         final String P_APPLICATION_NAME = "ApplicationName";
         final String P_AUTHOR = "Author";
@@ -281,7 +260,7 @@ public class TestWriteWellKnown extends TestCase
         // FIXME (byte array properties not yet implemented): final byte[] P_THUMBNAIL = new byte[123];
         final String P_TITLE = "Title";
         final int    P_WORD_COUNT = ++nr;
-    
+
         final int     P_BYTE_COUNT = ++nr;
         final String  P_CATEGORY = "Category";
         final String  P_COMPANY = "Company";
@@ -312,7 +291,7 @@ public class TestWriteWellKnown extends TestCase
         final Long MIN_LONG = new Long(Long.MIN_VALUE);
         final Double MAX_DOUBLE = new Double(Double.MAX_VALUE);
         final Double MIN_DOUBLE = new Double(Double.MIN_VALUE);
-        
+
         si.setApplicationName(P_APPLICATION_NAME);
         si.setAuthor(P_AUTHOR);
         si.setCharCount(P_CHAR_COUNT);
@@ -331,7 +310,7 @@ public class TestWriteWellKnown extends TestCase
         // FIXME (byte array properties not yet implemented): si.setThumbnail(P_THUMBNAIL);
         si.setTitle(P_TITLE);
         si.setWordCount(P_WORD_COUNT);
-    
+
         dsi.setByteCount(P_BYTE_COUNT);
         dsi.setCategory(P_CATEGORY);
         dsi.setCompany(P_COMPANY);
@@ -351,17 +330,17 @@ public class TestWriteWellKnown extends TestCase
         CustomProperties customProperties = dsi.getCustomProperties();
         if (customProperties == null)
             customProperties = new CustomProperties();
-        customProperties.put("Schlssel ",    "Wert ");
-        customProperties.put("Schlssel ",   "Wert ");
-        customProperties.put("Schlssel ",  "Wert ");
-        customProperties.put("Schlssel ", "Wert ");
+        customProperties.put("Schl\u00fcssel \u00e4",    "Wert \u00e4");
+        customProperties.put("Schl\u00fcssel \u00e4\u00f6",   "Wert \u00e4\u00f6");
+        customProperties.put("Schl\u00fcssel \u00e4\u00f6\u00fc",  "Wert \u00e4\u00f6\u00fc");
+        customProperties.put("Schl\u00fcssel \u00e4\u00f6\u00fc\u00d6", "Wert \u00e4\u00f6\u00fc\u00d6");
         customProperties.put("positive_Integer", POSITIVE_INTEGER);
         customProperties.put("positive_Long", POSITIVE_LONG);
         customProperties.put("positive_Double", POSITIVE_DOUBLE);
         customProperties.put("negative_Integer", NEGATIVE_INTEGER);
         customProperties.put("negative_Long", NEGATIVE_LONG);
         customProperties.put("negative_Double", NEGATIVE_DOUBLE);
-        customProperties.put("Boolean", new Boolean(true));
+        customProperties.put("Boolean", Boolean.TRUE);
         customProperties.put("Date", now);
         customProperties.put("max_Integer", MAX_INTEGER);
         customProperties.put("min_Integer", MIN_INTEGER);
@@ -394,14 +373,14 @@ public class TestWriteWellKnown extends TestCase
         dir = poifs.getRoot();
         siEntry = (DocumentEntry) dir.getEntry(SummaryInformation.DEFAULT_STREAM_NAME);
         dsiEntry = (DocumentEntry) dir.getEntry(DocumentSummaryInformation.DEFAULT_STREAM_NAME);
-    
+
         dis = new DocumentInputStream(siEntry);
         ps = new PropertySet(dis);
         si = new SummaryInformation(ps);
         dis = new DocumentInputStream(dsiEntry);
         ps = new PropertySet(dis);
         dsi = new DocumentSummaryInformation(ps);
-    
+
         assertEquals(P_APPLICATION_NAME, si.getApplicationName());
         assertEquals(P_AUTHOR, si.getAuthor());
         assertEquals(P_CHAR_COUNT, si.getCharCount());
@@ -420,7 +399,7 @@ public class TestWriteWellKnown extends TestCase
         // FIXME (byte array properties not yet implemented): assertEquals(P_THUMBNAIL, si.getThumbnail());
         assertEquals(P_TITLE, si.getTitle());
         assertEquals(P_WORD_COUNT, si.getWordCount());
-    
+
         assertEquals(P_BYTE_COUNT, dsi.getByteCount());
         assertEquals(P_CATEGORY, dsi.getCategory());
         assertEquals(P_COMPANY, dsi.getCompany());
@@ -440,17 +419,17 @@ public class TestWriteWellKnown extends TestCase
         final CustomProperties cps = dsi.getCustomProperties();
         assertEquals(customProperties, cps);
         assertNull(cps.get("No value available"));
-        assertEquals("Wert ", cps.get("Schlssel "));
-        assertEquals("Wert ", cps.get("Schlssel "));
-        assertEquals("Wert ", cps.get("Schlssel "));
-        assertEquals("Wert ", cps.get("Schlssel "));
+        assertEquals("Wert \u00e4", cps.get("Schl\u00fcssel \u00e4"));
+        assertEquals("Wert \u00e4\u00f6", cps.get("Schl\u00fcssel \u00e4\u00f6"));
+        assertEquals("Wert \u00e4\u00f6\u00fc", cps.get("Schl\u00fcssel \u00e4\u00f6\u00fc"));
+        assertEquals("Wert \u00e4\u00f6\u00fc\u00d6", cps.get("Schl\u00fcssel \u00e4\u00f6\u00fc\u00d6"));
         assertEquals(POSITIVE_INTEGER, cps.get("positive_Integer"));
         assertEquals(POSITIVE_LONG, cps.get("positive_Long"));
         assertEquals(POSITIVE_DOUBLE, cps.get("positive_Double"));
         assertEquals(NEGATIVE_INTEGER, cps.get("negative_Integer"));
         assertEquals(NEGATIVE_LONG, cps.get("negative_Long"));
         assertEquals(NEGATIVE_DOUBLE, cps.get("negative_Double"));
-        assertEquals(new Boolean(true), cps.get("Boolean"));
+        assertEquals(Boolean.TRUE, cps.get("Boolean"));
         assertEquals(now, cps.get("Date"));
         assertEquals(MAX_INTEGER, cps.get("max_Integer"));
         assertEquals(MIN_INTEGER, cps.get("min_Integer"));
@@ -480,7 +459,7 @@ public class TestWriteWellKnown extends TestCase
         si.removeThumbnail();
         si.removeTitle();
         si.removeWordCount();
-    
+
         dsi.removeByteCount();
         dsi.removeCategory();
         dsi.removeCompany();
@@ -497,14 +476,14 @@ public class TestWriteWellKnown extends TestCase
         dsi.removePresentationFormat();
         dsi.removeScale();
         dsi.removeSlideCount();
-    
-        /* 
+
+        /*
          * <li><p>Write the summary information stream and the document summary
          * information stream to the POI filesystem. */
         si.write(dir, siEntry.getName());
         dsi.write(dir, dsiEntry.getName());
-    
-        /* 
+
+        /*
          * <li><p>Write the POI filesystem to a (temporary) file <em>doc3</em>
          * and close the latter. */
         final File doc3 = File.createTempFile("POI_HPSF_Test.", ".tmp");
@@ -512,8 +491,8 @@ public class TestWriteWellKnown extends TestCase
         out = new FileOutputStream(doc3);
         poifs.writeFilesystem(out);
         out.close();
-    
-        /* 
+
+        /*
          * Open <em>doc3</em> for reading and check summary information
          * and document summary information. All properties removed before must not
          * be found in the property streams of <em>doc3</em>.
@@ -522,14 +501,14 @@ public class TestWriteWellKnown extends TestCase
         dir = poifs.getRoot();
         siEntry = (DocumentEntry) dir.getEntry(SummaryInformation.DEFAULT_STREAM_NAME);
         dsiEntry = (DocumentEntry) dir.getEntry(DocumentSummaryInformation.DEFAULT_STREAM_NAME);
-    
+
         dis = new DocumentInputStream(siEntry);
         ps = new PropertySet(dis);
         si = new SummaryInformation(ps);
         dis = new DocumentInputStream(dsiEntry);
         ps = new PropertySet(dis);
         dsi = new DocumentSummaryInformation(ps);
-    
+
         assertEquals(null, si.getApplicationName());
         assertEquals(null, si.getAuthor());
         assertEquals(0, si.getCharCount());
@@ -553,7 +532,7 @@ public class TestWriteWellKnown extends TestCase
         assertEquals(null, si.getTitle());
         assertEquals(0, si.getWordCount());
         assertTrue(si.wasNull());
-    
+
         assertEquals(0, dsi.getByteCount());
         assertTrue(dsi.wasNull());
         assertEquals(null, dsi.getCategory());
@@ -627,7 +606,7 @@ public class TestWriteWellKnown extends TestCase
                 else
                     dsi = PropertySetFactory.newDocumentSummaryInformation();
                 final CustomProperties cps = dsi.getCustomProperties();
-                
+
                 if (cps == null)
                     /* The document does not have custom properties. */
                     return;
@@ -642,8 +621,8 @@ public class TestWriteWellKnown extends TestCase
             }
         };
 
-        final String dataDirName = System.getProperty("HPSF.testdata.path");
-        final File dataDir = new File(dataDirName);
+        POIDataSamples _samples = POIDataSamples.getHPSFInstance();
+        final File dataDir = _samples.getFile("");
         final File[] docs = dataDir.listFiles(new FileFilter()
         {
             public boolean accept(final File file)
@@ -665,7 +644,7 @@ public class TestWriteWellKnown extends TestCase
      */
     public void testCustomerProperties()
     {
-        final String KEY = "Schlssel ";
+        final String KEY = "Schl\u00fcssel \u00e4";
         final String VALUE_1 = "Wert 1";
         final String VALUE_2 = "Wert 2";
 
@@ -679,14 +658,14 @@ public class TestWriteWellKnown extends TestCase
         assertEquals(1, cps.size());
         Object v1 = cps.get(KEY);
         assertEquals(VALUE_1, v1);
-        
+
         /* After adding a custom property with the same name the size must still
          * be one. */
         cps.put(KEY, VALUE_2);
         assertEquals(1, cps.size());
         Object v2 = cps.get(KEY);
         assertEquals(VALUE_2, v2);
-        
+
         /* Removing the custom property must return the remove property and
          * reduce the size to 0. */
         cp = (CustomProperty) cps.remove(KEY);
@@ -705,7 +684,7 @@ public class TestWriteWellKnown extends TestCase
     {
         final int ID_1 = 2;
         final int ID_2 = 3;
-        final String NAME_1 = "Schlssel ";
+        final String NAME_1 = "Schl\u00fcssel \u00e4";
         final String VALUE_1 = "Wert 1";
         final Map dictionary = new HashMap();
 
@@ -731,7 +710,7 @@ public class TestWriteWellKnown extends TestCase
         p.setType(Variant.VT_LPWSTR);
         p.setValue(VALUE_1);
         s.setProperty(p);
-        dictionary.put(new Long(ID_1), NAME_1);
+        dictionary.put(Long.valueOf(ID_1), NAME_1);
         s.setDictionary(dictionary);
         cps = dsi.getCustomProperties();
         assertEquals(1, cps.size());
@@ -739,26 +718,10 @@ public class TestWriteWellKnown extends TestCase
 
         /* Add another custom property. */
         s.setProperty(ID_2, Variant.VT_LPWSTR, VALUE_1);
-        dictionary.put(new Long(ID_2), NAME_1);
+        dictionary.put(Long.valueOf(ID_2), NAME_1);
         s.setDictionary(dictionary);
         cps = dsi.getCustomProperties();
         assertEquals(1, cps.size());
         assertFalse(cps.isPure());
     }
-
-
-
-    /**
-     * <p>Runs the test cases stand-alone.</p>
-     * 
-     * @param args The command-line parameters.
-     * @throws Throwable if anything goes wrong.
-     */
-    public static void main(final String[] args) throws Throwable
-    {
-        System.setProperty("HPSF.testdata.path",
-                           "./src/testcases/org/apache/poi/hpsf/data");
-        junit.textui.TestRunner.run(TestWriteWellKnown.class);
-    }
-
 }
