@@ -25,15 +25,14 @@ import java.io.ByteArrayOutputStream;
 
 /**
  * Tests the capabilities of the EscherGraphics class.
- * 
+ *
  * All tests have two escher groups available to them,
  *  one anchored at 0,0,1022,255 and another anchored
- *  at 20,30,500,200 
+ *  at 20,30,500,200
  *
  * @author Glen Stampoultzis (glens at apache.org)
  */
-public class TestEscherGraphics extends TestCase
-{
+public final class TestEscherGraphics extends TestCase {
 	private HSSFWorkbook workbook;
 	private HSSFPatriarch patriarch;
     private HSSFShapeGroup escherGroupA;
@@ -43,7 +42,7 @@ public class TestEscherGraphics extends TestCase
     protected void setUp() throws Exception
     {
         workbook = new HSSFWorkbook();
-        
+
         HSSFSheet sheet = workbook.createSheet("test");
         patriarch = sheet.createDrawingPatriarch();
         escherGroupA = patriarch.createGroup(new HSSFClientAnchor(0,0,1022,255,(short)0,0,(short) 0,0));
@@ -53,15 +52,13 @@ public class TestEscherGraphics extends TestCase
         super.setUp();
     }
 
-    public void testGetFont() throws Exception
-    {
+    public void testGetFont() {
         Font f = graphics.getFont();
         if (f.toString().indexOf("dialog") == -1 && f.toString().indexOf("Dialog") == -1)
             assertEquals("java.awt.Font[family=Arial,name=Arial,style=plain,size=10]", f.toString());
     }
 
-    public void testGetFontMetrics() throws Exception
-    {
+    public void testGetFontMetrics() {
         Font f = graphics.getFont();
         if (f.toString().indexOf("dialog") != -1 || f.toString().indexOf("Dialog") != -1)
             return;
@@ -70,21 +67,18 @@ public class TestEscherGraphics extends TestCase
         assertEquals("java.awt.Font[family=Arial,name=Arial,style=plain,size=10]", fontMetrics.getFont().toString());
     }
 
-    public void testSetFont() throws Exception
-    {
+    public void testSetFont() {
         Font f = new Font("Helvetica", 0, 12);
         graphics.setFont(f);
         assertEquals(f, graphics.getFont());
     }
 
-    public void testSetColor() throws Exception
-    {
+    public void testSetColor() {
         graphics.setColor(Color.red);
         assertEquals(Color.red, graphics.getColor());
     }
 
-    public void testFillRect() throws Exception
-    {
+    public void testFillRect() {
         graphics.fillRect( 10, 10, 20, 20 );
         HSSFSimpleShape s = (HSSFSimpleShape) escherGroupA.getChildren().get(0);
         assertEquals(HSSFSimpleShape.OBJECT_TYPE_RECTANGLE, s.getShapeType());
@@ -94,8 +88,7 @@ public class TestEscherGraphics extends TestCase
         assertEquals(30, s.getAnchor().getDx2());
     }
 
-    public void testDrawString() throws Exception
-    {
+    public void testDrawString() {
         graphics.drawString("This is a test", 10, 10);
         HSSFTextbox t = (HSSFTextbox) escherGroupA.getChildren().get(0);
         assertEquals("This is a test", t.getString().getString().toString());
@@ -105,30 +98,30 @@ public class TestEscherGraphics extends TestCase
     	HSSFSheet s;
     	HSSFShapeGroup s1;
     	HSSFShapeGroup s2;
-    	
+
     	patriarch.setCoordinates(10, 20, 30, 40);
-    	
+
     	ByteArrayOutputStream baos = new ByteArrayOutputStream();
     	workbook.write(baos);
     	workbook = new HSSFWorkbook(new ByteArrayInputStream(baos.toByteArray()));
     	s = workbook.getSheetAt(0);
-    	
+
     	patriarch = s.getDrawingPatriarch();
-    	
+
     	assertNotNull(patriarch);
     	assertEquals(10, patriarch.getX1());
     	assertEquals(20, patriarch.getY1());
     	assertEquals(30, patriarch.getX2());
     	assertEquals(40, patriarch.getY2());
-    	
+
     	// Check the two groups too
     	assertEquals(2, patriarch.countOfAllChildren());
     	assertTrue(patriarch.getChildren().get(0) instanceof HSSFShapeGroup);
     	assertTrue(patriarch.getChildren().get(1) instanceof HSSFShapeGroup);
-    	
+
     	s1 = (HSSFShapeGroup)patriarch.getChildren().get(0);
     	s2 = (HSSFShapeGroup)patriarch.getChildren().get(1);
-    	
+
     	assertEquals(0, s1.getX1());
     	assertEquals(0, s1.getY1());
     	assertEquals(1023, s1.getX2());
@@ -137,7 +130,7 @@ public class TestEscherGraphics extends TestCase
     	assertEquals(0, s2.getY1());
     	assertEquals(1023, s2.getX2());
     	assertEquals(255, s2.getY2());
-    	
+
     	assertEquals(0, s1.getAnchor().getDx1());
     	assertEquals(0, s1.getAnchor().getDy1());
     	assertEquals(1022, s1.getAnchor().getDx2());
@@ -146,29 +139,29 @@ public class TestEscherGraphics extends TestCase
     	assertEquals(30, s2.getAnchor().getDy1());
     	assertEquals(500, s2.getAnchor().getDx2());
     	assertEquals(200, s2.getAnchor().getDy2());
-    	
-    	
+
+
     	// Write and re-load once more, to check that's ok
     	baos = new ByteArrayOutputStream();
     	workbook.write(baos);
     	workbook = new HSSFWorkbook(new ByteArrayInputStream(baos.toByteArray()));
     	s = workbook.getSheetAt(0);
     	patriarch = s.getDrawingPatriarch();
-    	
+
     	assertNotNull(patriarch);
     	assertEquals(10, patriarch.getX1());
     	assertEquals(20, patriarch.getY1());
     	assertEquals(30, patriarch.getX2());
     	assertEquals(40, patriarch.getY2());
-    	
+
     	// Check the two groups too
     	assertEquals(2, patriarch.countOfAllChildren());
     	assertTrue(patriarch.getChildren().get(0) instanceof HSSFShapeGroup);
     	assertTrue(patriarch.getChildren().get(1) instanceof HSSFShapeGroup);
-    	
+
     	s1 = (HSSFShapeGroup)patriarch.getChildren().get(0);
     	s2 = (HSSFShapeGroup)patriarch.getChildren().get(1);
-    	
+
     	assertEquals(0, s1.getX1());
     	assertEquals(0, s1.getY1());
     	assertEquals(1023, s1.getX2());
@@ -177,7 +170,7 @@ public class TestEscherGraphics extends TestCase
     	assertEquals(0, s2.getY1());
     	assertEquals(1023, s2.getX2());
     	assertEquals(255, s2.getY2());
-    	
+
     	assertEquals(0, s1.getAnchor().getDx1());
     	assertEquals(0, s1.getAnchor().getDy1());
     	assertEquals(1022, s1.getAnchor().getDx2());
@@ -186,32 +179,32 @@ public class TestEscherGraphics extends TestCase
     	assertEquals(30, s2.getAnchor().getDy1());
     	assertEquals(500, s2.getAnchor().getDx2());
     	assertEquals(200, s2.getAnchor().getDy2());
-    	
+
     	// Change the positions of the first groups,
     	//  but not of their anchors
     	s1.setCoordinates(2, 3, 1021, 242);
-    	
+
     	baos = new ByteArrayOutputStream();
     	workbook.write(baos);
     	workbook = new HSSFWorkbook(new ByteArrayInputStream(baos.toByteArray()));
     	s = workbook.getSheetAt(0);
     	patriarch = s.getDrawingPatriarch();
-    	
+
     	assertNotNull(patriarch);
     	assertEquals(10, patriarch.getX1());
     	assertEquals(20, patriarch.getY1());
     	assertEquals(30, patriarch.getX2());
     	assertEquals(40, patriarch.getY2());
-    	
+
     	// Check the two groups too
     	assertEquals(2, patriarch.countOfAllChildren());
     	assertEquals(2, patriarch.getChildren().size());
     	assertTrue(patriarch.getChildren().get(0) instanceof HSSFShapeGroup);
     	assertTrue(patriarch.getChildren().get(1) instanceof HSSFShapeGroup);
-    	
+
     	s1 = (HSSFShapeGroup)patriarch.getChildren().get(0);
     	s2 = (HSSFShapeGroup)patriarch.getChildren().get(1);
-    	
+
     	assertEquals(2, s1.getX1());
     	assertEquals(3, s1.getY1());
     	assertEquals(1021, s1.getX2());
@@ -220,7 +213,7 @@ public class TestEscherGraphics extends TestCase
     	assertEquals(0, s2.getY1());
     	assertEquals(1023, s2.getX2());
     	assertEquals(255, s2.getY2());
-    	
+
     	assertEquals(0, s1.getAnchor().getDx1());
     	assertEquals(0, s1.getAnchor().getDy1());
     	assertEquals(1022, s1.getAnchor().getDx2());
@@ -229,8 +222,8 @@ public class TestEscherGraphics extends TestCase
     	assertEquals(30, s2.getAnchor().getDy1());
     	assertEquals(500, s2.getAnchor().getDx2());
     	assertEquals(200, s2.getAnchor().getDy2());
-    	
-    	
+
+
     	// Now add some text to one group, and some more
     	//  to the base, and check we can get it back again
     	HSSFTextbox tbox1 =
@@ -239,37 +232,37 @@ public class TestEscherGraphics extends TestCase
     	HSSFTextbox tbox2 =
     		s2.createTextbox(new HSSFChildAnchor(41,42,43,44));
     	tbox2.setString(new HSSFRichTextString("This is text box 2"));
-    	
+
     	assertEquals(3, patriarch.getChildren().size());
-    	
-    	
+
+
     	baos = new ByteArrayOutputStream();
     	workbook.write(baos);
     	workbook = new HSSFWorkbook(new ByteArrayInputStream(baos.toByteArray()));
     	s = workbook.getSheetAt(0);
-    	
+
     	patriarch = s.getDrawingPatriarch();
-    	
+
     	assertNotNull(patriarch);
     	assertEquals(10, patriarch.getX1());
     	assertEquals(20, patriarch.getY1());
     	assertEquals(30, patriarch.getX2());
     	assertEquals(40, patriarch.getY2());
-    	
+
     	// Check the two groups and the text
     	assertEquals(3, patriarch.countOfAllChildren());
     	assertEquals(2, patriarch.getChildren().size());
-    	
+
     	// Should be two groups and a text
     	assertTrue(patriarch.getChildren().get(0) instanceof HSSFShapeGroup);
     	assertTrue(patriarch.getChildren().get(1) instanceof HSSFTextbox);
 //    	assertTrue(patriarch.getChildren().get(2) instanceof HSSFShapeGroup);
-    	
+
     	s1 = (HSSFShapeGroup)patriarch.getChildren().get(0);
     	tbox1 = (HSSFTextbox)patriarch.getChildren().get(1);
-    	
+
 //    	s2 = (HSSFShapeGroup)patriarch.getChildren().get(1);
-    	
+
     	assertEquals(2, s1.getX1());
     	assertEquals(3, s1.getY1());
     	assertEquals(1021, s1.getX2());
@@ -278,7 +271,7 @@ public class TestEscherGraphics extends TestCase
     	assertEquals(0, s2.getY1());
     	assertEquals(1023, s2.getX2());
     	assertEquals(255, s2.getY2());
-    	
+
     	assertEquals(0, s1.getAnchor().getDx1());
     	assertEquals(0, s1.getAnchor().getDy1());
     	assertEquals(1022, s1.getAnchor().getDx2());
@@ -287,7 +280,7 @@ public class TestEscherGraphics extends TestCase
     	assertEquals(30, s2.getAnchor().getDy1());
     	assertEquals(500, s2.getAnchor().getDx2());
     	assertEquals(200, s2.getAnchor().getDy2());
-    	
+
     	// Not working just yet
     	//assertEquals("I am text box 1", tbox1.getString().getString());
     }
