@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -15,25 +14,25 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
 
 package org.apache.poi.hssf.usermodel;
 
-import junit.framework.TestCase;
-import org.apache.poi.hssf.model.Workbook;
-import org.apache.poi.hssf.record.BackupRecord;
-import org.apache.poi.hssf.record.LabelSSTRecord;
-import org.apache.poi.hssf.record.Record;
-import org.apache.poi.hssf.record.aggregates.ValueRecordsAggregate;
-import org.apache.poi.hssf.util.Region;
-import org.apache.poi.poifs.filesystem.POIFSFileSystem;
-import org.apache.poi.util.TempFile;
-
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileOutputStream;
 import java.io.IOException;
-import java.util.Iterator;
+
+import junit.framework.TestCase;
+
+import org.apache.poi.hssf.HSSFTestDataSamples;
+import org.apache.poi.hssf.model.Workbook;
+import org.apache.poi.hssf.record.BackupRecord;
+import org.apache.poi.hssf.record.LabelSSTRecord;
+import org.apache.poi.hssf.record.Record;
+import org.apache.poi.hssf.record.aggregates.RecordAggregate.RecordVisitor;
+import org.apache.poi.poifs.filesystem.POIFSFileSystem;
+import org.apache.poi.ss.util.CellRangeAddress;
+import org.apache.poi.util.TempFile;
 
 /**
  * Class to test Workbook functionality
@@ -42,10 +41,7 @@ import java.util.Iterator;
  * @author Greg Merrill
  * @author Siggi Cherem
  */
-
-public class TestWorkbook
-    extends TestCase
-{
+public final class TestWorkbook extends TestCase {
     private static final String LAST_NAME_KEY        = "lastName";
     private static final String FIRST_NAME_KEY       = "firstName";
     private static final String SSN_KEY              = "ssn";
@@ -58,15 +54,9 @@ public class TestWorkbook
     private static final String SSN_VALUE            = "555555555";
     private SanityChecker sanityChecker = new SanityChecker();
 
-    /**
-     * Constructor TestWorkbook
-     *
-     * @param name
-     */
 
-    public TestWorkbook(String name)
-    {
-        super(name);
+    private static HSSFWorkbook openSample(String sampleFileName) {
+        return HSSFTestDataSamples.openSampleWorkbook(sampleFileName);
     }
 
     /**
@@ -78,10 +68,7 @@ public class TestWorkbook
      *             HSSFSheet last row or first row is incorrect.             <P>
      *
      */
-
-    public void testWriteSheetSimple()
-        throws IOException
-    {
+    public void testWriteSheetSimple() throws IOException {
         File             file = TempFile.createTempFile("testWriteSheetSimple",
                                                     ".xls");
         FileOutputStream out  = new FileOutputStream(file);
@@ -90,19 +77,16 @@ public class TestWorkbook
         HSSFRow          r    = null;
         HSSFCell         c    = null;
 
-        for (short rownum = ( short ) 0; rownum < 100; rownum++)
-        {
+        for (int rownum = 0; rownum < 100; rownum++) {
             r = s.createRow(rownum);
 
-            // r.setRowNum(( short ) rownum);
-            for (short cellnum = ( short ) 0; cellnum < 50; cellnum += 2)
-            {
+            for (int cellnum = 0; cellnum < 50; cellnum += 2) {
                 c = r.createCell(cellnum);
                 c.setCellValue(rownum * 10000 + cellnum
                                + ((( double ) rownum / 1000)
                                   + (( double ) cellnum / 10000)));
-                c = r.createCell(( short ) (cellnum + 1));
-                c.setCellValue("TEST");
+                c = r.createCell(cellnum + 1);
+                c.setCellValue(new HSSFRichTextString("TEST"));
             }
         }
         wb.write(out);
@@ -110,8 +94,6 @@ public class TestWorkbook
         sanityChecker.checkHSSFWorkbook(wb);
         assertEquals("LAST ROW == 99", 99, s.getLastRowNum());
         assertEquals("FIRST ROW == 0", 0, s.getFirstRowNum());
-
-        // assert((s.getLastRowNum() == 99));
     }
 
     /**
@@ -136,28 +118,23 @@ public class TestWorkbook
         HSSFRow          r    = null;
         HSSFCell         c    = null;
 
-        for (short rownum = ( short ) 0; rownum < 100; rownum++)
-        {
+        for (int rownum = 0; rownum < 100; rownum++) {
             r = s.createRow(rownum);
 
-            // r.setRowNum(( short ) rownum);
-            for (short cellnum = ( short ) 0; cellnum < 50; cellnum += 2)
-            {
+            for (int cellnum = 0; cellnum < 50; cellnum += 2) {
                 c = r.createCell(cellnum);
                 c.setCellValue(rownum * 10000 + cellnum
                                + ((( double ) rownum / 1000)
                                   + (( double ) cellnum / 10000)));
-                c = r.createCell(( short ) (cellnum + 1));
-                c.setCellValue("TEST");
+                c = r.createCell(cellnum + 1);
+                c.setCellValue(new HSSFRichTextString("TEST"));
             }
         }
-        for (short rownum = ( short ) 0; rownum < 25; rownum++)
-        {
+        for (int rownum = 0; rownum < 25; rownum++) {
             r = s.getRow(rownum);
             s.removeRow(r);
         }
-        for (short rownum = ( short ) 75; rownum < 100; rownum++)
-        {
+        for (int rownum = 75; rownum < 100; rownum++) {
             r = s.getRow(rownum);
             s.removeRow(r);
         }
@@ -178,21 +155,12 @@ public class TestWorkbook
      *
      */
 
-    public void testReadSimple()
-        throws IOException
-    {
-        String filename = System.getProperty("HSSF.testdata.path");
+    public void testReadSimple() {
+        HSSFWorkbook workbook = openSample("Simple.xls");
+        HSSFSheet sheet = workbook.getSheetAt(0);
 
-        filename = filename + "/Simple.xls";
-        FileInputStream stream   = new FileInputStream(filename);
-        POIFSFileSystem fs       = new POIFSFileSystem(stream);
-        HSSFWorkbook    workbook = new HSSFWorkbook(fs);
-        HSSFSheet       sheet    = workbook.getSheetAt(0);
-
-        assertEquals(REPLACE_ME,
-                     sheet.getRow(( short ) 0).getCell(( short ) 0)
-                         .getStringCellValue());
-        stream.close();
+        HSSFCell cell = sheet.getRow(0).getCell(0);
+        assertEquals(REPLACE_ME, cell .getRichStringCellValue().getString());
     }
 
     /**
@@ -204,24 +172,15 @@ public class TestWorkbook
      *
      */
 
-    public void testReadSimpleWithDataFormat()
-        throws IOException
-    {
-        String filename = System.getProperty("HSSF.testdata.path");
-
-        filename = filename + "/SimpleWithDataFormat.xls";
-        FileInputStream stream   = new FileInputStream(filename);
-        POIFSFileSystem fs       = new POIFSFileSystem(stream);
-        HSSFWorkbook    workbook = new HSSFWorkbook(fs);
+    public void testReadSimpleWithDataFormat() {
+        HSSFWorkbook workbook = openSample("SimpleWithDataFormat.xls");
         HSSFSheet       sheet    = workbook.getSheetAt(0);
         HSSFDataFormat  format   = workbook.createDataFormat();
-	HSSFCell	cell	 = 
-                     sheet.getRow(( short ) 0).getCell(( short ) 0);
+        HSSFCell cell = sheet.getRow(0).getCell(0);
 
         assertEquals(1.25,cell.getNumericCellValue(), 1e-10);
 
-	assertEquals(format.getFormat(cell.getCellStyle().getDataFormat()), "0.0");
-        stream.close();
+        assertEquals(format.getFormat(cell.getCellStyle().getDataFormat()), "0.0");
     }
 
 /**
@@ -236,23 +195,23 @@ public class TestWorkbook
     public void testWriteDataFormat()
         throws IOException
     {
-	File             file = TempFile.createTempFile("testWriteDataFormat",
+    File             file = TempFile.createTempFile("testWriteDataFormat",
                                                     ".xls");
         FileOutputStream out  = new FileOutputStream(file);
         HSSFWorkbook     wb   = new HSSFWorkbook();
         HSSFSheet        s    = wb.createSheet();
         HSSFRow          r    = null;
         HSSFCell         c    = null;
-	HSSFDataFormat format = wb.createDataFormat();
-	HSSFCellStyle    cs   = wb.createCellStyle();
-	
-	short df = format.getFormat("0.0");
-	cs.setDataFormat(df);
-	
-	r = s.createRow((short)0);
-	c = r.createCell((short)0);
-	c.setCellStyle(cs);
-	c.setCellValue(1.25);
+    HSSFDataFormat format = wb.createDataFormat();
+    HSSFCellStyle    cs   = wb.createCellStyle();
+
+    short df = format.getFormat("0.0");
+    cs.setDataFormat(df);
+
+    r = s.createRow(0);
+    c = r.createCell(0);
+    c.setCellStyle(cs);
+    c.setCellValue(1.25);
 
         wb.write(out);
         out.close();
@@ -261,16 +220,16 @@ public class TestWorkbook
         POIFSFileSystem fs       = new POIFSFileSystem(stream);
         HSSFWorkbook    workbook = new HSSFWorkbook(fs);
         HSSFSheet       sheet    = workbook.getSheetAt(0);
-	HSSFCell	cell	 = 
-                     sheet.getRow(( short ) 0).getCell(( short ) 0);
-	format = workbook.createDataFormat();
+    HSSFCell    cell     =
+                     sheet.getRow(0).getCell(0);
+    format = workbook.createDataFormat();
 
         assertEquals(1.25,cell.getNumericCellValue(), 1e-10);
 
-	assertEquals(format.getFormat(df), "0.0");
+    assertEquals(format.getFormat(df), "0.0");
+
+    assertEquals(format, workbook.createDataFormat());
 
-	assertEquals(format, workbook.createDataFormat());
-	
         stream.close();
     }
 
@@ -283,30 +242,14 @@ public class TestWorkbook
      *
      */
 
-    public void testReadEmployeeSimple()
-        throws IOException
-    {
-        String filename = System.getProperty("HSSF.testdata.path");
-
-        filename = filename + "/Employee.xls";
-        FileInputStream stream   = new FileInputStream(filename);
-        POIFSFileSystem fs       = new POIFSFileSystem(stream);
-        HSSFWorkbook    workbook = new HSSFWorkbook(fs);
+    public void testReadEmployeeSimple() {
+        HSSFWorkbook workbook = openSample("Employee.xls");
         HSSFSheet       sheet    = workbook.getSheetAt(0);
 
-        assertEquals(EMPLOYEE_INFORMATION,
-                     sheet.getRow(1).getCell(( short ) 1)
-                         .getStringCellValue());
-        assertEquals(LAST_NAME_KEY,
-                     sheet.getRow(3).getCell(( short ) 2)
-                         .getStringCellValue());
-        assertEquals(FIRST_NAME_KEY,
-                     sheet.getRow(4).getCell(( short ) 2)
-                         .getStringCellValue());
-        assertEquals(SSN_KEY,
-                     sheet.getRow(5).getCell(( short ) 2)
-                         .getStringCellValue());
-        stream.close();
+        assertEquals(EMPLOYEE_INFORMATION, sheet.getRow(1).getCell(1).getRichStringCellValue().getString());
+        assertEquals(LAST_NAME_KEY, sheet.getRow(3).getCell(2).getRichStringCellValue().getString());
+        assertEquals(FIRST_NAME_KEY, sheet.getRow(4).getCell(2).getRichStringCellValue().getString());
+        assertEquals(SSN_KEY, sheet.getRow(5).getCell(2).getRichStringCellValue().getString());
     }
 
     /**
@@ -322,33 +265,17 @@ public class TestWorkbook
      *
      */
 
-    public void testModifySimple()
-        throws IOException
-    {
-        String filename = System.getProperty("HSSF.testdata.path");
+    public void testModifySimple() {
+        HSSFWorkbook workbook = openSample("Simple.xls");
+        HSSFSheet sheet = workbook.getSheetAt(0);
+        HSSFCell cell = sheet.getRow(0).getCell(0);
 
-        filename = filename + "/Simple.xls";
-        FileInputStream instream = new FileInputStream(filename);
-        POIFSFileSystem fsin     = new POIFSFileSystem(instream);
-        HSSFWorkbook    workbook = new HSSFWorkbook(fsin);
-        HSSFSheet       sheet    = workbook.getSheetAt(0);
-        HSSFCell        cell     =
-            sheet.getRow(( short ) 0).getCell(( short ) 0);
+        cell.setCellValue(new HSSFRichTextString(REPLACED));
 
-        cell.setCellValue(REPLACED);
-        File             destination = TempFile.createTempFile("SimpleResult",
-                                           ".xls");
-        FileOutputStream outstream   = new FileOutputStream(destination);
-
-        workbook.write(outstream);
-        instream.close();
-        outstream.close();
-        instream = new FileInputStream(destination);
-        workbook = new HSSFWorkbook(new POIFSFileSystem(instream));
+        workbook = HSSFTestDataSamples.writeOutAndReadBack(workbook);
         sheet    = workbook.getSheetAt(0);
-        cell     = sheet.getRow(( short ) 0).getCell(( short ) 0);
-        assertEquals(REPLACED, cell.getStringCellValue());
-        instream.close();
+        cell     = sheet.getRow(0).getCell(0);
+        assertEquals(REPLACED, cell.getRichStringCellValue().getString());
     }
 
     /**
@@ -364,42 +291,26 @@ public class TestWorkbook
      *             or is incorrect. <P>
      *
      */
+    public void testModifySimpleWithSkip() {
+        HSSFWorkbook workbook = openSample("SimpleWithSkip.xls");
+        HSSFSheet sheet = workbook.getSheetAt(0);
+        HSSFCell cell = sheet.getRow(0).getCell(1);
 
-    public void testModifySimpleWithSkip()
-        throws IOException
-    {
-        String filename = System.getProperty("HSSF.testdata.path");
+        cell.setCellValue(new HSSFRichTextString(REPLACED));
+        cell = sheet.getRow(1).getCell(0);
+        cell.setCellValue(new HSSFRichTextString(REPLACED));
 
-        filename = filename + "/SimpleWithSkip.xls";
-        FileInputStream instream = new FileInputStream(filename);
-        POIFSFileSystem fsin     = new POIFSFileSystem(instream);
-        HSSFWorkbook    workbook = new HSSFWorkbook(fsin);
-        HSSFSheet       sheet    = workbook.getSheetAt(0);
-        HSSFCell        cell     =
-            sheet.getRow(( short ) 0).getCell(( short ) 1);
+        workbook = HSSFTestDataSamples.writeOutAndReadBack(workbook);
 
-        cell.setCellValue(REPLACED);
-        cell = sheet.getRow(( short ) 1).getCell(( short ) 0);
-        cell.setCellValue(REPLACED);
-        File             destination =
-            TempFile.createTempFile("SimpleWithSkipResult", ".xls");
-        FileOutputStream outstream   = new FileOutputStream(destination);
-
-        workbook.write(outstream);
-        instream.close();
-        outstream.close();
-        instream = new FileInputStream(destination);
-        workbook = new HSSFWorkbook(new POIFSFileSystem(instream));
         sheet    = workbook.getSheetAt(0);
-        cell     = sheet.getRow(( short ) 0).getCell(( short ) 1);
-        assertEquals(REPLACED, cell.getStringCellValue());
-        cell = sheet.getRow(( short ) 0).getCell(( short ) 0);
-        assertEquals(DO_NOT_REPLACE, cell.getStringCellValue());
-        cell = sheet.getRow(( short ) 1).getCell(( short ) 0);
-        assertEquals(REPLACED, cell.getStringCellValue());
-        cell = sheet.getRow(( short ) 1).getCell(( short ) 1);
-        assertEquals(DO_NOT_REPLACE, cell.getStringCellValue());
-        instream.close();
+        cell     = sheet.getRow(0).getCell(1);
+        assertEquals(REPLACED, cell.getRichStringCellValue().getString());
+        cell = sheet.getRow(0).getCell(0);
+        assertEquals(DO_NOT_REPLACE, cell.getRichStringCellValue().getString());
+        cell = sheet.getRow(1).getCell(0);
+        assertEquals(REPLACED, cell.getRichStringCellValue().getString());
+        cell = sheet.getRow(1).getCell(1);
+        assertEquals(DO_NOT_REPLACE, cell.getRichStringCellValue().getString());
     }
 
     /**
@@ -415,41 +326,26 @@ public class TestWorkbook
      *             is incorrect or has not been replaced. <P>
      *
      */
-
-    public void testModifySimpleWithStyling()
-        throws IOException
-    {
-        String filename = System.getProperty("HSSF.testdata.path");
-
-        filename = filename + "/SimpleWithStyling.xls";
-        FileInputStream instream = new FileInputStream(filename);
-        POIFSFileSystem fsin     = new POIFSFileSystem(instream);
-        HSSFWorkbook    workbook = new HSSFWorkbook(fsin);
+    public void testModifySimpleWithStyling() {
+        HSSFWorkbook workbook = openSample("SimpleWithStyling.xls");
         HSSFSheet       sheet    = workbook.getSheetAt(0);
 
         for (int k = 0; k < 4; k++)
         {
-            HSSFCell cell = sheet.getRow(( short ) k).getCell(( short ) 0);
+            HSSFCell cell = sheet.getRow(k).getCell(0);
 
-            cell.setCellValue(REPLACED);
+            cell.setCellValue(new HSSFRichTextString(REPLACED));
         }
-        File             destination =
-            TempFile.createTempFile("SimpleWithStylingResult", ".xls");
-        FileOutputStream outstream   = new FileOutputStream(destination);
 
-        workbook.write(outstream);
-        instream.close();
-        outstream.close();
-        instream = new FileInputStream(destination);
-        workbook = new HSSFWorkbook(new POIFSFileSystem(instream));
+
+        workbook = HSSFTestDataSamples.writeOutAndReadBack(workbook);
         sheet    = workbook.getSheetAt(0);
         for (int k = 0; k < 4; k++)
         {
-            HSSFCell cell = sheet.getRow(( short ) k).getCell(( short ) 0);
+            HSSFCell cell = sheet.getRow(k).getCell(0);
 
-            assertEquals(REPLACED, cell.getStringCellValue());
+            assertEquals(REPLACED, cell.getRichStringCellValue().getString());
         }
-        instream.close();
     }
 
     /**
@@ -465,48 +361,23 @@ public class TestWorkbook
      *             is incorrect or has not been replaced. <P>
      *
      */
-
-    public void testModifyEmployee()
-        throws IOException
-    {
-        String filename = System.getProperty("HSSF.testdata.path");
-
-        filename = filename + "/Employee.xls";
-        FileInputStream instream = new FileInputStream(filename);
-        POIFSFileSystem fsin     = new POIFSFileSystem(instream);
-        HSSFWorkbook    workbook = new HSSFWorkbook(fsin);
+    public void testModifyEmployee() {
+        HSSFWorkbook workbook = openSample("Employee.xls");
         HSSFSheet       sheet    = workbook.getSheetAt(0);
-        HSSFCell        cell     =
-            sheet.getRow(( short ) 3).getCell(( short ) 2);
+        HSSFCell        cell     = sheet.getRow(3).getCell(2);
 
-        cell.setCellValue(LAST_NAME_VALUE);
-        cell = sheet.getRow(( short ) 4).getCell(( short ) 2);
-        cell.setCellValue(FIRST_NAME_VALUE);
-        cell = sheet.getRow(( short ) 5).getCell(( short ) 2);
-        cell.setCellValue(SSN_VALUE);
-        File             destination = TempFile.createTempFile("EmployeeResult",
-                                           ".xls");
-        FileOutputStream outstream   = new FileOutputStream(destination);
+        cell.setCellValue(new HSSFRichTextString(LAST_NAME_VALUE));
+        cell = sheet.getRow(4).getCell(2);
+        cell.setCellValue(new HSSFRichTextString(FIRST_NAME_VALUE));
+        cell = sheet.getRow(5).getCell(2);
+        cell.setCellValue(new HSSFRichTextString(SSN_VALUE));
 
-        workbook.write(outstream);
-        instream.close();
-        outstream.close();
-        instream = new FileInputStream(destination);
-        workbook = new HSSFWorkbook(new POIFSFileSystem(instream));
+        workbook = HSSFTestDataSamples.writeOutAndReadBack(workbook);
         sheet    = workbook.getSheetAt(0);
-        assertEquals(EMPLOYEE_INFORMATION,
-                     sheet.getRow(1).getCell(( short ) 1)
-                         .getStringCellValue());
-        assertEquals(LAST_NAME_VALUE,
-                     sheet.getRow(3).getCell(( short ) 2)
-                         .getStringCellValue());
-        assertEquals(FIRST_NAME_VALUE,
-                     sheet.getRow(4).getCell(( short ) 2)
-                         .getStringCellValue());
-        assertEquals(SSN_VALUE,
-                     sheet.getRow(5).getCell(( short ) 2)
-                         .getStringCellValue());
-        instream.close();
+        assertEquals(EMPLOYEE_INFORMATION, sheet.getRow(1).getCell(1).getRichStringCellValue().getString());
+        assertEquals(LAST_NAME_VALUE, sheet.getRow(3).getCell(2).getRichStringCellValue().getString());
+        assertEquals(FIRST_NAME_VALUE, sheet.getRow(4).getCell(2).getRichStringCellValue().getString());
+        assertEquals(SSN_VALUE, sheet.getRow(5).getCell(2).getRichStringCellValue().getString());
     }
 
     /**
@@ -517,21 +388,10 @@ public class TestWorkbook
      * FAILURE:    HSSF does not read a sheet or excepts.  HSSF incorrectly indentifies the cell<P>
      *
      */
-
-    public void testReadSheetWithRK()
-        throws IOException
-    {
-        String filename = System.getProperty("HSSF.testdata.path");
-
-        filename = filename + "/rk.xls";
-
-        // a.xls has a value on position (0,0)
-        FileInputStream in = new FileInputStream(filename);
-        POIFSFileSystem fs = new POIFSFileSystem(in);
-        HSSFWorkbook    h  = new HSSFWorkbook(fs);
+    public void testReadSheetWithRK() {
+        HSSFWorkbook h = openSample("rk.xls");
         HSSFSheet       s  = h.getSheetAt(0);
-        HSSFRow         r  = s.getRow(0);
-        HSSFCell        c  = r.getCell(( short ) 0);
+        HSSFCell        c  = s.getRow(0).getCell(0);
         int             a  = c.getCellType();
 
         assertEquals(a, c.CELL_TYPE_NUMERIC);
@@ -547,70 +407,49 @@ public class TestWorkbook
      *             HSSFSheet last row or first row is incorrect.             <P>
      *
      */
-
-    public void testWriteModifySheetMerged()
-        throws IOException
-    {
-        File             file = TempFile.createTempFile("testWriteSheetMerged",
-                                                    ".xls");
-        FileOutputStream out  = new FileOutputStream(file);
-        FileInputStream  in   = null;
+    public void testWriteModifySheetMerged() {
         HSSFWorkbook     wb   = new HSSFWorkbook();
         HSSFSheet        s    = wb.createSheet();
-        HSSFRow          r    = null;
-        HSSFCell         c    = null;
 
-        for (short rownum = ( short ) 0; rownum < 100; rownum++)
-        {
-            r = s.createRow(rownum);
+        for (int rownum = 0; rownum < 100; rownum++) {
+            HSSFRow r = s.createRow(rownum);
 
-            // r.setRowNum(( short ) rownum);
-            for (short cellnum = ( short ) 0; cellnum < 50; cellnum += 2)
-            {
-                c = r.createCell(cellnum);
+            for (int cellnum = 0; cellnum < 50; cellnum += 2) {
+                HSSFCell c = r.createCell(cellnum);
                 c.setCellValue(rownum * 10000 + cellnum
                                + ((( double ) rownum / 1000)
                                   + (( double ) cellnum / 10000)));
-                c = r.createCell(( short ) (cellnum + 1));
-                c.setCellValue("TEST");
+                c = r.createCell(cellnum + 1);
+                c.setCellValue(new HSSFRichTextString("TEST"));
             }
         }
-        s.addMergedRegion(new Region(( short ) 0, ( short ) 0, ( short ) 10,
-                                     ( short ) 10));
-        s.addMergedRegion(new Region(( short ) 30, ( short ) 5, ( short ) 40,
-                                     ( short ) 15));
-        wb.write(out);
-        out.close();
+        s.addMergedRegion(new CellRangeAddress(0, 10, 0, 10));
+        s.addMergedRegion(new CellRangeAddress(30, 40, 5, 15));
         sanityChecker.checkHSSFWorkbook(wb);
-        in = new FileInputStream(file);
-        wb = new HSSFWorkbook(new POIFSFileSystem(in));
+        wb = HSSFTestDataSamples.writeOutAndReadBack(wb);
+
         s  = wb.getSheetAt(0);
-        Region r1 = s.getMergedRegionAt(0);
-        Region r2 = s.getMergedRegionAt(1);
+        CellRangeAddress r1 = s.getMergedRegion(0);
+        CellRangeAddress r2 = s.getMergedRegion(1);
 
-        in.close();
+        confirmRegion(new CellRangeAddress(0, 10, 0, 10), r1);
+        confirmRegion(new CellRangeAddress(30, 40,5, 15), r2);
+    }
 
-        // System.out.println(file.length());
-        // assertEquals("FILE LENGTH == 87552",file.length(), 87552);
-        // System.out.println(s.getLastRowNum());
-        assertEquals("REGION1 = 0,0,10,10", 0,
-                     new Region(( short ) 0, ( short ) 0, ( short ) 10,
-                                ( short ) 10).compareTo(r1));
-        assertEquals("REGION2 == 30,5,40,15", 0,
-                     new Region(( short ) 30, ( short ) 5, ( short ) 40,
-                                ( short ) 15).compareTo(r2));
+    private static void confirmRegion(CellRangeAddress ra, CellRangeAddress rb) {
+        assertEquals(ra.getFirstRow(), rb.getFirstRow());
+        assertEquals(ra.getLastRow(), rb.getLastRow());
+        assertEquals(ra.getFirstColumn(), rb.getFirstColumn());
+        assertEquals(ra.getLastColumn(), rb.getLastColumn());
     }
 
     /**
      * Test the backup field gets set as expected.
      */
-
-    public void testBackupRecord()
-        throws Exception
-    {
-        HSSFWorkbook wb       = new HSSFWorkbook();
-        wb.createSheet();
-        Workbook     workbook = wb.getWorkbook();
+    public void testBackupRecord() {
+        HSSFWorkbook wb = new HSSFWorkbook();
+		wb.createSheet();
+		Workbook workbook = wb.getWorkbook();
         BackupRecord record   = workbook.getBackupRecord();
 
         assertEquals(0, record.getBackup());
@@ -618,118 +457,92 @@ public class TestWorkbook
         assertEquals(1, record.getBackup());
     }
 
+    private static final class RecordCounter implements RecordVisitor {
+        private int _count;
+
+        public RecordCounter() {
+            _count=0;
+        }
+        public int getCount() {
+            return _count;
+        }
+        public void visitRecord(Record r) {
+            if (r instanceof LabelSSTRecord) {
+                _count++;
+            }
+        }
+    }
+
     /**
      * This tests is for bug [ #506658 ] Repeating output.
      *
      * We need to make sure only one LabelSSTRecord is produced.
      */
-
-    public void testRepeatingBug()
-        throws Exception
-    {
+    public void testRepeatingBug() {
         HSSFWorkbook workbook = new HSSFWorkbook();
         HSSFSheet    sheet    = workbook.createSheet("Design Variants");
-        HSSFRow      row      = sheet.createRow(( short ) 2);
-        HSSFCell     cell     = row.createCell(( short ) 1);
+        HSSFRow      row      = sheet.createRow(2);
+        HSSFCell     cell     = row.createCell(1);
 
-        cell.setCellValue("Class");
-        cell = row.createCell(( short ) 2);
+        cell.setCellValue(new HSSFRichTextString("Class"));
+        cell = row.createCell(2);
 
-        // workbook.write(new FileOutputStream("/a2.xls"));
-        ValueRecordsAggregate valueAggregate =
-            ( ValueRecordsAggregate ) sheet.getSheet()
-                .findFirstRecordBySid(ValueRecordsAggregate.sid);
-        int                   sstRecords     = 0;
-        Iterator              iterator       = valueAggregate.getIterator();
-
-        while (iterator.hasNext())
-        {
-            if ((( Record ) iterator.next()).getSid() == LabelSSTRecord.sid)
-            {
-                sstRecords++;
-            }
-        }
-        assertEquals(1, sstRecords);
+        RecordCounter rc = new RecordCounter();
+        sheet.getSheet().visitContainedRecords(rc, 0);
+        assertEquals(1, rc.getCount());
     }
 
 
-    public void testManyRows()
-        throws Exception
-    {
-        String testName = "TestManyRows";
-        File file = TempFile.createTempFile(testName, ".xls");
-        FileOutputStream out  = new FileOutputStream(file);
+    /**
+     * Test for row indexes beyond {@link Short#MAX_VALUE}.
+     * This bug was first fixed in svn r352609.
+     */
+    public void testRowIndexesBeyond32768() {
         HSSFWorkbook workbook = new HSSFWorkbook();
         HSSFSheet sheet = workbook.createSheet();
-        HSSFRow row = null;
-        HSSFCell cell = null;
-        int i, j;
-        for ( i = 0, j = 32771; j > 0; i++, j-- )
-        {
+        HSSFRow row;
+        HSSFCell cell;
+        for (int i = 32700; i < 32771; i++) {
             row = sheet.createRow(i);
-            cell = row.createCell((short) 0);
+            cell = row.createCell(0);
             cell.setCellValue(i);
         }
-        workbook.write(out);
-        out.close();
         sanityChecker.checkHSSFWorkbook(workbook);
         assertEquals("LAST ROW == 32770", 32770, sheet.getLastRowNum());
+        cell = sheet.getRow(32770).getCell(0);
         double lastVal = cell.getNumericCellValue();
 
-        FileInputStream in      = new FileInputStream(file);
-        POIFSFileSystem fs       = new POIFSFileSystem(in);
-        HSSFWorkbook    wb = new HSSFWorkbook(fs);
+        HSSFWorkbook    wb = HSSFTestDataSamples.writeOutAndReadBack(workbook);
         HSSFSheet       s    = wb.getSheetAt(0);
         row = s.getRow(32770);
-        cell = row.getCell(( short ) 0);
+        cell = row.getCell(0);
         assertEquals("Value from last row == 32770", lastVal, cell.getNumericCellValue(), 0);
         assertEquals("LAST ROW == 32770", 32770, s.getLastRowNum());
-        in.close();
-        file.deleteOnExit();
     }
-    
+
     /**
      * Generate a file to visually/programmatically verify repeating rows and cols made it
      */
     public void testRepeatingColsRows() throws IOException
     {
-		HSSFWorkbook workbook = new HSSFWorkbook();        
-		HSSFSheet sheet = workbook.createSheet("Test Print Titles");                
-		String sheetName = workbook.getSheetName(0);
-	     
-	    HSSFRow row = sheet.createRow(0);
-	    
-	    HSSFCell cell = row.createCell((short)1);
-	    cell.setCellValue("hi");
-	     
-	     
-		workbook.setRepeatingRowsAndColumns(0, 0, 1, 0, 0); 
-	     
-		File file = TempFile.createTempFile("testPrintTitles",".xls");        
-	     
-		FileOutputStream fileOut = new FileOutputStream(file);
-		workbook.write(fileOut);
-		fileOut.close();
-	     
-		assertTrue("file exists",file.exists());
-	     
-    	
-    }
-  
-    
-    public static void main(String [] ignored_args)
-    {
-        String filename = System.getProperty("HSSF.testdata.path");
+        HSSFWorkbook workbook = new HSSFWorkbook();
+        HSSFSheet sheet = workbook.createSheet("Test Print Titles");
 
-        // assume this is relative to basedir
-        if (filename == null)
-        {
-            System.setProperty(
-                "HSSF.testdata.path",
-                "src/testcases/org/apache/poi/hssf/data");
-        }
-        System.out
-            .println("Testing org.apache.poi.hssf.usermodel.HSSFWorkbook");
-        junit.textui.TestRunner.run(TestWorkbook.class);
+        HSSFRow row = sheet.createRow(0);
+
+        HSSFCell cell = row.createCell(1);
+        cell.setCellValue(new HSSFRichTextString("hi"));
+
+
+        workbook.setRepeatingRowsAndColumns(0, 0, 1, 0, 0);
+
+        File file = TempFile.createTempFile("testPrintTitles",".xls");
+
+        FileOutputStream fileOut = new FileOutputStream(file);
+        workbook.write(fileOut);
+        fileOut.close();
+
+        assertTrue("file exists",file.exists());
     }
+
 }
