@@ -1,4 +1,3 @@
-
 /* ====================================================================
    Licensed to the Apache Software Foundation (ASF) under one or more
    contributor license agreements.  See the NOTICE file distributed with
@@ -15,7 +14,6 @@
    See the License for the specific language governing permissions and
    limitations under the License.
 ==================================================================== */
-        
 
 package org.apache.poi.util;
 
@@ -27,66 +25,32 @@ import junit.framework.*;
  * @author Marc Johnson
  * @author Glen Stampoultzis (gstamp@iprimus.com.au)
  */
-
-public class TestBitField
-    extends TestCase
-{
+public final class TestBitField extends TestCase {
     private static BitField bf_multi  = BitFieldFactory.getInstance(0x3F80);
     private static BitField bf_single = BitFieldFactory.getInstance(0x4000);
 
-    /**
-     * Constructor TestBitField
-     *
-     * @param name
-     */
-
-    public TestBitField(String name)
-    {
-        super(name);
-    }
-
-    /**
-     * test the getValue() method
-     */
-
-    public void testGetValue()
-    {
+    public void testGetValue() {
         assertEquals(bf_multi.getValue(-1), 127);
         assertEquals(bf_multi.getValue(0), 0);
         assertEquals(bf_single.getValue(-1), 1);
         assertEquals(bf_single.getValue(0), 0);
     }
 
-    /**
-     * test the getShortValue() method
-     */
-
-    public void testGetShortValue()
-    {
+    public void testGetShortValue() {
         assertEquals(bf_multi.getShortValue(( short ) -1), ( short ) 127);
         assertEquals(bf_multi.getShortValue(( short ) 0), ( short ) 0);
         assertEquals(bf_single.getShortValue(( short ) -1), ( short ) 1);
         assertEquals(bf_single.getShortValue(( short ) 0), ( short ) 0);
     }
 
-    /**
-     * test the getRawValue() method
-     */
-
-    public void testGetRawValue()
-    {
+    public void testGetRawValue() {
         assertEquals(bf_multi.getRawValue(-1), 0x3F80);
         assertEquals(bf_multi.getRawValue(0), 0);
         assertEquals(bf_single.getRawValue(-1), 0x4000);
         assertEquals(bf_single.getRawValue(0), 0);
     }
 
-    /**
-     * test the getShortRawValue() method
-     */
-
-    public void testGetShortRawValue()
-    {
+    public void testGetShortRawValue() {
         assertEquals(bf_multi.getShortRawValue(( short ) -1),
                      ( short ) 0x3F80);
         assertEquals(bf_multi.getShortRawValue(( short ) 0), ( short ) 0);
@@ -95,12 +59,7 @@ public class TestBitField
         assertEquals(bf_single.getShortRawValue(( short ) 0), ( short ) 0);
     }
 
-    /**
-     * test the isSet() method
-     */
-
-    public void testIsSet()
-    {
+    public void testIsSet() {
         assertTrue(!bf_multi.isSet(0));
         for (int j = 0x80; j <= 0x3F80; j += 0x80)
         {
@@ -110,12 +69,7 @@ public class TestBitField
         assertTrue(bf_single.isSet(0x4000));
     }
 
-    /**
-     * test the isAllSet() method
-     */
-
-    public void testIsAllSet()
-    {
+    public void testIsAllSet() {
         for (int j = 0; j < 0x3F80; j += 0x80)
         {
             assertTrue(!bf_multi.isAllSet(j));
@@ -125,12 +79,7 @@ public class TestBitField
         assertTrue(bf_single.isAllSet(0x4000));
     }
 
-    /**
-     * test the setValue() method
-     */
-
-    public void testSetValue()
-    {
+    public void testSetValue() {
         for (int j = 0; j < 128; j++)
         {
             assertEquals(bf_multi.getValue(bf_multi.setValue(0, j)), j);
@@ -149,12 +98,7 @@ public class TestBitField
         assertEquals(bf_single.setValue(0x4000, 2), 0);
     }
 
-    /**
-     * test the setShortValue() method
-     */
-
-    public void testSetShortValue()
-    {
+    public void testSetShortValue() {
         for (int j = 0; j < 128; j++)
         {
             assertEquals(bf_multi
@@ -181,8 +125,7 @@ public class TestBitField
                      ( short ) 0);
     }
 
-    public void testByte()
-    {
+    public void testByte() {
         assertEquals(1, BitFieldFactory.getInstance(1).setByteBoolean(( byte ) 0, true));
         assertEquals(2, BitFieldFactory.getInstance(2).setByteBoolean(( byte ) 0, true));
         assertEquals(4, BitFieldFactory.getInstance(4).setByteBoolean(( byte ) 0, true));
@@ -208,64 +151,34 @@ public class TestBitField
         assertEquals(false, BitFieldFactory.getInstance(0x40).isSet(clearedBit));
     }
 
-    /**
-     * test the clear() method
-     */
-
-    public void testClear()
-    {
+    public void testClear() {
         assertEquals(bf_multi.clear(-1), 0xFFFFC07F);
         assertEquals(bf_single.clear(-1), 0xFFFFBFFF);
     }
 
-    /**
-     * test the clearShort() method
-     */
-
-    public void testClearShort()
-    {
+    public void testClearShort() {
         assertEquals(bf_multi.clearShort(( short ) -1), ( short ) 0xC07F);
         assertEquals(bf_single.clearShort(( short ) -1), ( short ) 0xBFFF);
     }
 
-    /**
-     * test the set() method
-     */
-
-    public void testSet()
-    {
+    public void testSet() {
         assertEquals(bf_multi.set(0), 0x3F80);
         assertEquals(bf_single.set(0), 0x4000);
     }
 
-    /**
-     * test the setShort() method
-     */
-
-    public void testSetShort()
-    {
+    public void testSetShort() {
         assertEquals(bf_multi.setShort(( short ) 0), ( short ) 0x3F80);
         assertEquals(bf_single.setShort(( short ) 0), ( short ) 0x4000);
     }
 
-    /**
-     * test the setBoolean() method
-     */
-
-    public void testSetBoolean()
-    {
+    public void testSetBoolean() {
         assertEquals(bf_multi.set(0), bf_multi.setBoolean(0, true));
         assertEquals(bf_single.set(0), bf_single.setBoolean(0, true));
         assertEquals(bf_multi.clear(-1), bf_multi.setBoolean(-1, false));
         assertEquals(bf_single.clear(-1), bf_single.setBoolean(-1, false));
     }
 
-    /**
-     * test the setShortBoolean() method
-     */
-
-    public void testSetShortBoolean()
-    {
+    public void testSetShortBoolean() {
         assertEquals(bf_multi.setShort(( short ) 0),
                      bf_multi.setShortBoolean(( short ) 0, true));
         assertEquals(bf_single.setShort(( short ) 0),
@@ -275,16 +188,4 @@ public class TestBitField
         assertEquals(bf_single.clearShort(( short ) -1),
                      bf_single.setShortBoolean(( short ) -1, false));
     }
-
-    /**
-     * main method to run the unit tests
-     *
-     * @param ignored_args
-     */
-
-    public static void main(String [] ignored_args)
-    {
-        System.out.println("Testing util.BitField functionality");
-        junit.textui.TestRunner.run(TestBitField.class);
-    }
 }
